@@ -31,7 +31,7 @@
 #include "fit_gsl.h"
 #include <Table.h>
 #include <Matrix.h>
-#include <QwtErrorPlotCurve.h>
+#include <ErrorBarsCurve.h>
 #include <FunctionCurve.h>
 #include <MultiLayer.h>
 #include <ColorBox.h>
@@ -163,7 +163,7 @@ gsl_multifit_fdfsolver * Fit::fitGSL(gsl_multifit_function_fdf f, int &iteration
 
 gsl_multimin_fminimizer * Fit::fitSimplex(gsl_multimin_function f, int &iterations, int &status)
 {
-	const gsl_multimin_fminimizer_type *T = gsl_multimin_fminimizer_nmsimplex;
+	const gsl_multimin_fminimizer_type *T = gsl_multimin_fminimizer_nmsimplex2;
 
 	//size of the simplex
 	gsl_vector *ss;
@@ -258,9 +258,8 @@ void Fit::setDataCurve(QwtPlotCurve *curve, double start, double end)
 
     if (d_graph && d_curve && ((PlotCurve *)d_curve)->type() != Graph::Function)
     {
-        QList<DataCurve *> lst = ((DataCurve *)d_curve)->errorBarsList();
-        foreach (DataCurve *c, lst){
-            QwtErrorPlotCurve *er = (QwtErrorPlotCurve *)c;
+		QList<ErrorBarsCurve *> lst = ((DataCurve *)d_curve)->errorBarsList();
+		foreach (ErrorBarsCurve *er, lst){
             if (!er->xErrors()){
                 d_weighting = Instrumental;
                 for (int i=0; i<d_n; i++){
@@ -460,11 +459,10 @@ bool Fit::setWeightingData(WeightingMethod w, const QString& colName)
 				}
 
 				bool error = true;
-				QwtErrorPlotCurve *er = 0;
+				ErrorBarsCurve *er = 0;
 				if (((PlotCurve *)d_curve)->type() != Graph::Function){
-					QList<DataCurve *> lst = ((DataCurve *)d_curve)->errorBarsList();
-                	foreach (DataCurve *c, lst){
-                    	er = (QwtErrorPlotCurve *)c;
+					QList<ErrorBarsCurve *> lst = ((DataCurve *)d_curve)->errorBarsList();
+					foreach (ErrorBarsCurve *er, lst){
                     	if (!er->xErrors()){
                         	weighting_dataset = er->title().text();
                         	error = false;
