@@ -2,7 +2,7 @@
 	File                 : BaselineDialog.cpp
     Project              : QtiPlot
     --------------------------------------------------------------------
-	Copyright            : (C) 2010 by Ion Vasilief
+	Copyright            : (C) 2010 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
 	Description          : Subtract baseline dialog
 
@@ -34,6 +34,7 @@
 #include <FunctionCurve.h>
 #include <Interpolation.h>
 #include <DataPickerTool.h>
+#include <RangeSelectorTool.h>
 
 #include <QGroupBox>
 #include <QSpinBox>
@@ -224,7 +225,7 @@ void BaselineDialog::createBaseline()
 	disableBaselineTool();
 
 	if (btnAutomatic->isChecked()){
-		Interpolation *i = new Interpolation(app, graph, boxInputName->currentText(), boxInterpolationMethod->currentIndex());
+		Interpolation *i = new Interpolation(app, graph->curve(boxInputName->currentIndex()), boxInterpolationMethod->currentIndex());
 		i->setOutputPoints(boxPoints->value());
 		i->run();
 		delete i;
@@ -233,7 +234,7 @@ void BaselineDialog::createBaseline()
 	} else if (btnEquation->isChecked()){
 		double start = graph->axisScaleDiv(QwtPlot::xBottom)->lowerBound();
 		double end = graph->axisScaleDiv(QwtPlot::xBottom)->upperBound();
-		DataCurve *c = graph->dataCurve(graph->curveIndex(boxInputName->currentText()));
+		DataCurve *c = graph->dataCurve(boxInputName->currentIndex());
 		if (c){
 			start = c->minXValue();
 			end = c->maxXValue();
@@ -278,8 +279,7 @@ void BaselineDialog::subtractBaseline(bool add)
 	if (!graph)
 		return;
 
-	int index = graph->curveIndex(boxInputName->currentText());
-	DataCurve *c = graph->dataCurve(index);
+	DataCurve *c = graph->dataCurve(boxInputName->currentIndex());
 	if (!c)
 		return;
 
@@ -291,9 +291,13 @@ void BaselineDialog::subtractBaseline(bool add)
 	if (!inputTable)
 		return;
 
-	int inputPoints = inputTable->numRows();
-	QString xColName = c->xColumnName();
-	int xCol = inputTable->colIndex(xColName);
+	int startRow = c->startRow(), endRow = c->endRow();
+	if (startRow < 0)
+		startRow = 0;
+	if (endRow < 0)
+		endRow = c->dataSize() - 1;
+
+	int xCol = inputTable->colIndex(c->xColumnName());
 	int yCol = inputTable->colIndex(c->title().text());
 
 	int refPoints = d_baseline->dataSize();
@@ -346,7 +350,7 @@ void BaselineDialog::subtractBaseline(bool add)
 	gsl_spline *interp = gsl_spline_alloc(gsl_interp_linear, refPoints);
 	gsl_spline_init (interp, xtemp, ytemp, refPoints);
 
-	for (int i = 0; i < inputPoints; i++){
+	for (int i = startRow; i <= endRow; i++){
 		if (!inputTable->text(i, yCol).isEmpty() && !inputTable->text(i, xCol).isEmpty())
 			inputTable->setCell(i, yCol, combineValues(inputTable->cell(i, yCol), gsl_spline_eval(interp, inputTable->cell(i, xCol), acc), add));
 	}
@@ -399,10 +403,8 @@ void BaselineDialog::setGraph(Graph *g)
 		boxPoints->setValue(c->dataSize());
 
 	boxInputName->addItems(g->analysableCurvesList());
-
-	QString selectedCurve = g->selectedCurveTitle();
-	if (!selectedCurve.isEmpty())
-		boxInputName->setCurrentIndex(boxInputName->findText(selectedCurve));
+	if (g->rangeSelectorsEnabled())
+		boxInputName->setCurrentIndex(g->curveIndex(g->rangeSelectorTool()->selectedCurve()));
 
 	connect (graph, SIGNAL(destroyed()), this, SLOT(close()));
 	connect (graph, SIGNAL(modifiedGraph()), this, SLOT(updateGraphCurves()));
