@@ -2,7 +2,7 @@
     File                 : FitDialog.cpp
     Project              : QtiPlot
     --------------------------------------------------------------------
-	Copyright            : (C) 2004-2010 by Ion Vasilief
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Fit Wizard
 
@@ -41,6 +41,7 @@
 #include <DoubleSpinBox.h>
 #include <FunctionCurve.h>
 #include <ScriptEdit.h>
+#include <RangeSelectorTool.h>
 
 #include <QListWidget>
 #include <QTableWidget>
@@ -66,13 +67,16 @@
 
 using namespace std;
 
-FitDialog::FitDialog(Graph *g, QWidget* parent, Qt::WFlags fl )
-: QDialog( parent, fl )
+FitDialog::FitDialog(Graph *g, QWidget* parent)
+: QDialog(parent)
 {
-    setObjectName("FitDialog");
+	setObjectName("FitDialog");
 	setWindowTitle(tr("QtiPlot - Fit Wizard"));
 	setSizeGripEnabled(true);
 	setAttribute(Qt::WA_DeleteOnClose);
+#ifdef Q_OS_WIN
+	setWindowFlags(windowFlags() | Qt::WindowMinimizeButtonHint);
+#endif
 
 	d_param_table = 0;
 	d_current_fit = 0;
@@ -104,9 +108,7 @@ FitDialog::FitDialog(Graph *g, QWidget* parent, Qt::WFlags fl )
 
 	QString modelsPath = app->fitModelsPath;
 	QFileInfo fim(modelsPath);
-	if (modelsPath.isEmpty() || !fim.isDir() || !fim.isWritable())
-		chooseFitModelsFolder();
-	else
+	if (!modelsPath.isEmpty() && fim.isDir() && fim.isWritable())
     	loadUserFunctions();
 
 	if (d_user_functions.size())
@@ -383,7 +385,7 @@ void FitDialog::initFitPage()
     fitPage->setLayout(vbox1);
     tw->addWidget(fitPage);
 
-	connect( boxCurve, SIGNAL( activated(const QString&) ), this, SLOT( activateCurve(const QString&) ) );
+	connect( boxCurve, SIGNAL(activated(int)), this, SLOT( activateCurve(int)));
 	connect( buttonOk, SIGNAL( clicked() ), this, SLOT(accept()));
 	connect( buttonCancel1, SIGNAL( clicked() ), this, SLOT(close()));
 	connect( buttonEdit, SIGNAL( clicked() ), this, SLOT(showEditPage()));
@@ -833,25 +835,23 @@ void FitDialog::setGraph(Graph *g)
 
 	boxCurve->clear();
 	boxCurve->addItems(d_graph->analysableCurvesList());
+	if (g->rangeSelectorsEnabled())
+		boxCurve->setCurrentIndex(g->curveIndex(g->rangeSelectorTool()->selectedCurve()));
 
-	QString selectedCurve = g->selectedCurveTitle();
-	if (!selectedCurve.isEmpty())
-		boxCurve->setCurrentIndex(boxCurve->findText (selectedCurve));
-
-	activateCurve(boxCurve->currentText());
+	activateCurve(boxCurve->currentIndex());
 
 	connect (d_graph, SIGNAL(closedGraph()), this, SLOT(close()));
 	connect (d_graph, SIGNAL(dataRangeChanged()), this, SLOT(changeDataRange()));
 };
 
-void FitDialog::activateCurve(const QString& curveName)
+void FitDialog::activateCurve(int curveIndex)
 {
-	QwtPlotCurve *c = d_graph->curve(curveName);
+	QwtPlotCurve *c = d_graph->curve(curveIndex);
 	if (!c)
 		return;
 
 	double start, end;
-    d_graph->range(curveName, &start, &end);
+	d_graph->range(c, &start, &end);
     boxFrom->setValue(QMIN(start, end));
     boxTo->setValue(QMAX(start, end));
 	//Set the same color as the data curve chosen for fit (Feature Request #4031)
@@ -888,9 +888,9 @@ void FitDialog::saveUserFunction()
 
 	QString name = boxName->text();
     QStringList lst = userFunctionNames();
-	QString formula = parseFormula(editBox->text().simplified());
+	QString formula = parseFormula(editBox->text().simplified().remove(QRegExp("\\s")));
 	if (lst.contains(name)){
-		int index = lst.findIndex(name);
+		int index = lst.indexOf(name);
 		d_current_fit = (NonLinearFit *)d_user_functions[index];
         if (d_current_fit->setFormula(formula))
         	d_current_fit->save(d_current_fit->fileName());
@@ -969,7 +969,7 @@ void FitDialog::removeUserFunction()
 
 void FitDialog::showFitPage()
 {
-	QString formula = editBox->text().simplified();
+	QString formula = editBox->text().simplified().remove(QRegExp("\\s"));
 	if (formula.isEmpty()){
 		QMessageBox::critical(this, tr("QtiPlot - Input function error"), tr("Please enter a valid function!"));
 		editBox->setFocus();
@@ -1263,14 +1263,11 @@ void FitDialog::setCurrentFit(int function)
 			if (d_user_functions.size() > function)
 				d_current_fit = d_user_functions[function];
 		break;
-
 		case 1:
 			d_current_fit = d_built_in_functions[function];
 		break;
-
 		case 2:
 		break;
-
 		case 3:
 			if (d_plugins.size() > 0)
 		    	d_current_fit = d_plugins[function];
@@ -1287,35 +1284,41 @@ void FitDialog::showExpression(int function)
 	if (!d_current_fit)
 		return;
 
-	if (categoryBox->currentRow() == 2)
-		explainBox->setText(MyParser::explainFunction(function));
-	else if (categoryBox->currentRow() == 1){
-		polynomOrderLabel->hide();
-		polynomOrderBox->hide();
-		if (funcBox->currentItem()->text() == tr("Gauss") ||
-			funcBox->currentItem()->text() == tr("Lorentz")){
-			polynomOrderLabel->setText(tr("Peaks"));
-			polynomOrderLabel->show();
-			polynomOrderBox->show();
-		} else if (funcBox->currentItem()->text() == tr("Polynomial")){
-			polynomOrderLabel->setText(tr("Polynomial Order"));
-			polynomOrderLabel->show();
-			polynomOrderBox->show();
-		}
-		explainBox->setText(d_current_fit->formula());
-		setFunction(boxUseBuiltIn->isChecked());
-	} else if (categoryBox->currentRow() == 0){
-		if (d_user_functions.size() > function)
-			explainBox->setText(d_current_fit->formula());
-		else
-			explainBox->clear();
-		setFunction(boxUseBuiltIn->isChecked());
-	} else if (categoryBox->currentRow() == 3){
-		if (d_plugins.size() > 0){
+	switch(categoryBox->currentRow()){
+		case 0:
+			if (d_user_functions.size() > function)
+				explainBox->setText(d_current_fit->formula());
+			else
+				explainBox->clear();
+			setFunction(boxUseBuiltIn->isChecked());
+		break;
+		case 1:
+			polynomOrderLabel->hide();
+			polynomOrderBox->hide();
+			if (qobject_cast<MultiPeakFit *>(d_current_fit) || qobject_cast<PolynomialFit *>(d_current_fit)){
+				if (qobject_cast<MultiPeakFit *>(d_current_fit)){
+					polynomOrderLabel->setText(tr("Peaks"));
+					((MultiPeakFit *)d_current_fit)->setNumPeaks(polynomOrderBox->value());
+				} else {
+					polynomOrderLabel->setText(tr("Polynomial Order"));
+					((PolynomialFit *)d_current_fit)->setOrder(polynomOrderBox->value());
+				}
+				polynomOrderLabel->show();
+				polynomOrderBox->show();
+			}
 			explainBox->setText(d_current_fit->formula());
 			setFunction(boxUseBuiltIn->isChecked());
-		} else
-			explainBox->clear();
+		break;
+		case 2:
+			explainBox->setText(MyParser::explainFunction(function));
+		break;
+		case 3:
+			if (d_plugins.size() > 0){
+				explainBox->setText(d_current_fit->formula());
+				setFunction(boxUseBuiltIn->isChecked());
+			} else
+				explainBox->clear();
+		break;
 	}
 }
 
@@ -1348,8 +1351,8 @@ void FitDialog::accept()
 	ApplicationWindow *app = (ApplicationWindow *)this->parent();
 
 	QString curve = boxCurve->currentText();
-	QStringList curvesList = d_graph->curveNamesList();
-	if (curvesList.contains(curve) <= 0){
+	QStringList curvesList = d_graph->analysableCurvesList();
+	if (!curvesList.contains(curve)){
 		QMessageBox::critical(app, tr("QtiPlot - Warning"),
 				tr("The curve <b> %1 </b> doesn't exist anymore! Operation aborted!").arg(curve));
 		boxCurve->clear();
@@ -1445,9 +1448,9 @@ void FitDialog::accept()
 
 		d_current_fit->setInitialGuesses(paramsInit);
 
-		if (!d_current_fit->setDataFromCurve(curve, start, end) ||
+		if (!d_current_fit->setDataFromCurve(d_graph->curve(boxCurve->currentIndex()), start, end) ||
 			!d_current_fit->setWeightingData ((Fit::WeightingMethod)boxWeighting->currentIndex(),
-					       tableNamesBox->currentText()+"_"+colNamesBox->currentText())) return;
+						   tableNamesBox->currentText() + "_" + colNamesBox->currentText())) return;
 
 		if (btnParamRange->isEnabled()){
 			for (int i=0; i<n; i++)
@@ -1622,15 +1625,12 @@ void FitDialog::initBuiltInFunctions()
 
 void FitDialog::setNumPeaks(int peaks)
 {
-	if (d_current_fit->objectName() == tr("Gauss") ||
-		d_current_fit->objectName() == tr("Lorentz"))
+	if (qobject_cast<MultiPeakFit *>(d_current_fit))
 		((MultiPeakFit *)d_current_fit)->setNumPeaks(peaks);
-	else if (d_current_fit->objectName() == tr("Polynomial"))
+	else if (qobject_cast<PolynomialFit *>(d_current_fit))
 		((PolynomialFit *)d_current_fit)->setOrder(peaks);
 
-	int index = funcBox->currentRow();
-	d_built_in_functions[index] = d_current_fit;
-	showExpression(index);
+	showExpression(funcBox->currentRow());
 }
 
 QStringList FitDialog::builtInFunctionNames()
@@ -1677,6 +1677,7 @@ void FitDialog::loadUserFunctions()
         }
     }
 
+	funcBox->clear();
     if (d_user_functions.size() > 0){
         funcBox->addItems(names);
         funcBox->setCurrentRow(0);
@@ -1721,10 +1722,19 @@ void FitDialog::saveInitialGuesses()
             if (!baseName.contains("."))
                 fn.append(".fit");
 
-            if (d_current_fit->save(fn))
-                d_user_functions.append(d_current_fit);
-          }
-    }
+			QString name = boxName->text();
+			bool rename = (qobject_cast<NonLinearFit*>(d_current_fit) && !name.isEmpty() && d_current_fit->objectName() != name);
+			if (rename)
+				d_current_fit->setObjectName(name);
+
+			if (d_current_fit->save(fn)){
+				if (rename)
+					loadUserFunctions();
+				else
+					d_user_functions.append(d_current_fit);
+			}
+		}
+	}
 }
 
 void FitDialog::loadInitialGuesses()
