@@ -2,7 +2,7 @@
     File                 : FitDialog.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2004-2007 by Ion Vasilief
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Fit Wizard
 
@@ -29,7 +29,7 @@
 #ifndef FITDIALOG_H
 #define FITDIALOG_H
 
-#include "../../plot2D/Graph.h"
+#include <Graph.h>
 #include <QDoubleSpinBox>
 #include <QCheckBox>
 
@@ -59,7 +59,7 @@ class FitDialog : public QDialog
     Q_OBJECT
 
 public:
-    FitDialog(Graph *g, QWidget* parent = 0, Qt::WFlags fl = 0 );
+	FitDialog(Graph *g, QWidget* parent = 0);
 
     void setSrcTables(QList<MdiSubWindow*> tables);
 
@@ -87,7 +87,7 @@ private slots:
 	void saveUserFunction();
 	void removeUserFunction();
 	void setGraph(Graph *g);
-	void activateCurve(const QString& curveName);
+	void activateCurve(int curveIndex);
 	void chooseFolder();
 	void changeDataRange();
 	void selectSrcTable(int tabnr);
