@@ -13,7 +13,7 @@ int IMIN(int ia, int ib)
 		return ib;
 	}
 
-void nrerror(char error_text[])
+void nrerror(const char error_text[])
 {//Numerical Recipes standard error handler
 fprintf(stderr,"Numerical Recipes run-time error...\n");
 fprintf(stderr,"%s\n",error_text);
@@ -250,40 +250,3 @@ for (i=n;i>=1;i--)
 	b[i]=sum/a[i][i];
 	}
 }
-
-void polint(double xa[], double ya[], int n, double x, double *y, double *dy)
-{
-int i,m,ns=1;
-double den,dif,dift,ho,hp,w;
-double *c, *d;
-dif=fabs(x-xa[1]);
-c=vector(1,n);
-d=vector(1,n);
-for(i=1;i<=n;i++)
-	{
-	if ((dift=fabs(x-xa[i]))<dif)
-		{
-		ns=i;
-		dif=dift;
-		}
-	c[i]=ya[i];
-	d[i]=ya[i];
-	}
-*y=ya[ns--];
-for(m=1;m<n;m++)
-	{
-	for(i=1;i<=n-m;i++)
-		{
-		ho=xa[i]-x;
-		hp=xa[i+m]-x;
-		w=c[i+1]-d[i];
-		den=ho-hp;
-		den=w/den;
-		d[i]=hp*den;
-		c[i]=ho*den;
-		}
-	*y+=(*dy=(2*ns<(n-m)?c[ns+1]:d[ns--]));
-	}
-free_vector(d,1,n);
-free_vector(c,1,n);
-}
