@@ -59,10 +59,6 @@
 #include <qt_windows.h>
 #endif
 
-#ifdef HAS_EXCEL
-	#include <QAxObject>
-#endif
-
 class QPixmap;
 class QCloseEvent;
 class QDropEvent;
@@ -82,6 +78,7 @@ class QLocale;
 class QMdiArea;
 class QUndoView;
 class QCompleter;
+class QFileInfo;
 
 class Matrix;
 class Table;
@@ -103,6 +100,7 @@ class AssociationsDialog;
 class ScriptEdit;
 class ExportDialog;
 class Grid;
+class ImportExportPlugin;
 
 /**
  * \brief QtiPlot's main window.
@@ -227,7 +225,7 @@ public:
 	bool isMdiAreaEnabled(){return d_mdi_windows_area;};
 
 	void displayInfo(const QString& text){info->setText(text);};
-	QLineEdit *displayInfoLineEdit(){return info;};
+	QLineEdit *infoLineEdit(){return info;};
 
 	QList<QColor> indexedColors(){return d_indexed_colors;};
 	void setIndexedColors(const QList<QColor>& lst){d_indexed_colors = lst;};
@@ -240,15 +238,21 @@ public:
 
 	void connectScriptEditor(ScriptEdit *);
 
+	//! \name Import/Export Plugins
+	//@{
+	ImportExportPlugin* exportPlugin(const QString& suffix);
+	ImportExportPlugin* importPlugin(const QString& fileName);
+	//@}
+
+	bool isFileReadable(const QString&);
+
 public slots:
 	//! \name Projects and Project Files
 	//@{
 	void open();
 	ApplicationWindow* open(const QString& fn, bool factorySettings = false, bool newProject = true);
 	ApplicationWindow* openProject(const QString& fn, bool factorySettings = false, bool newProject = true);
-#ifdef OPJ_IMPORT
 	ApplicationWindow* importOPJ(const QString& fn, bool factorySettings = false, bool newProject = true);
-#endif
 	void closeProject();
 
 	/**
@@ -269,6 +273,7 @@ public slots:
 	ApplicationWindow * loadScript(const QString& fn, bool execute = false, bool noGui = false);
 
 	QList<MdiSubWindow *> windowsList();
+	QStringList windowsNameList();
 	void updateWindowLists(MdiSubWindow *w);
 	/*!
     Arranges all the visible project windows in a cascade pattern.
@@ -349,8 +354,6 @@ public slots:
 	//@{
 	Graph3D* newPlot3D(const QString& title = QString());
 	Graph3D* plotXYZ(Table* table,const QString& zColName, int type);
-	Graph3D* addRibbon(const QString& caption, const QString& formula,
-						double xl, double xr, double yl, double yr, double zl, double zr);
 	//@}
 
 	//! \name Surface Plots
@@ -409,7 +412,14 @@ public slots:
 	Matrix* matrix(const QString& name);
 	Matrix* convertTableToMatrix();
 	Matrix* tableToMatrix(Table* t);
-	Matrix* convertTableToMatrixRegularXYZ();
+	Matrix* tableToMatrixRegularXYZ(Table* t = 0, const QString& colName = QString::null);
+#ifdef HAVE_ALGLIB
+	void convertTableToMatrixRandomXYZ();
+	void expandMatrix();
+	void shrinkMatrix();
+	void smoothMatrix();
+	void showMatrixResamplingDialog(bool shrink = false);
+#endif
 	void showBinMatrixDialog();
 	void initMatrix(Matrix* m, const QString& caption);
 	void transposeMatrix();
@@ -472,17 +482,14 @@ public slots:
 	Table* importOdfSpreadsheet(const QString& = QString::null, int sheet = -1);
 
 	Table* importExcel(const QString& = QString::null, int sheet = -1);
-#ifdef HAS_EXCEL
-	static bool isExcelInstalled();
-	Table* importUsingExcel(const QString& = QString::null, int sheet = -1);
-	void importExcelCharts(QAxObject* ws, const QString& fn = QString::null);
-	MultiLayer *importExcelChart(QAxObject* chart, const QString& fn = QString::null, const QString& name = QString::null);
-#endif
-#ifdef XLS_IMPORT
-	Table* importExcelCrossplatform(const QString& = QString::null, int sheet = -1);
-	void exportExcel();
+#ifdef Q_OS_WIN
+	bool isExcelInstalled(){return d_has_excel;};
 #endif
 
+	void exportExcel();
+	void exportOds();
+
+	Table* importDatabase(const QString& = QString::null, int sheet = -1);
 	Table* importWaveFile();
 	void importASCII(const QString& fileName = QString::null);
 	void importASCII(const QStringList& files, int import_mode, const QString& local_column_separator, int local_ignored_lines, bool local_rename_columns,
@@ -494,8 +501,7 @@ public slots:
 	//! recalculate selected cells of current table
 	void recalculateTable();
 
-	TableStatistics *newTableStatistics(Table *base, int type, QList<int>,
-	    const QString &caption=QString::null);
+	TableStatistics *newTableStatistics(Table *base, int type, QList<int>, int start = 0, int end = -1, const QString &caption = QString::null);
 	//@}
 
 	//! \name Graphs
@@ -522,7 +528,7 @@ public slots:
 	MultiLayer* plotHistogram(Matrix *m);
 	void plotVectXYXY();
 	void plotVectXYAM();
-	void plotBoxDiagram();
+	void plotBox();
 	void plotDoubleYAxis();
 	void zoomRectanglePlot();
 	QString stemPlot(Table *t = 0, const QString& colName = QString(), int power = 0, int startRow = 0, int endRow = -1);
@@ -550,7 +556,9 @@ public slots:
 	void exportLayer();
 	void exportGraph(const QString& exportFilter = QString::null);
 	void exportAllGraphs();
+#if QT_VERSION >= 0x040500
 	void exportPresentationODF();
+#endif
 	void exportPDF();
 	void print();
 	void printPreview();
@@ -668,6 +676,14 @@ public slots:
 	void moveTableRowUp();
 	void moveTableRowDown();
 	void adjustColumnWidth();
+	void showChiSquareTestDialog();
+	void showStudentTestDialog(bool twoSamples = false);
+	void showTwoSampleStudentTestDialog(){return showStudentTestDialog(true);};
+	void testNormality();
+#ifdef HAVE_TAMUANOVA
+	void showANOVADialog(bool twoWay = false);
+	void showTwoWayANOVADialog(){return showANOVADialog(true);};
+#endif
 	//@}
 
 	//! \name Plot Tools
@@ -717,13 +733,11 @@ public slots:
 	void integrate();
 	void differentiate();
 	void analysis(Analysis operation);
-	void analyzeCurve(Graph *g, Analysis operation, const QString& curveTitle);
+	void analyzeCurve(Graph *g, QwtPlotCurve *c, Analysis operation);
 	void showDataSetDialog(Analysis operation);
 	//@}
 
 	void addErrorBars();
-	void defineErrorBars(const QString& name, int type, double percent, int direction);
-	void defineErrorBars(const QString& curveName, const QString& errColumnName, int direction);
 	void movePoints(bool wholeCurve = false);
 	void removePoints();
 
@@ -837,6 +851,7 @@ public slots:
 
 	void setAscValues();
 	void setRandomValues();
+	void setNormalRandomValues();
 	void setXCol();
 	void setYCol();
 	void setZCol();
@@ -897,9 +912,7 @@ public slots:
 	void receivedVersionFile(bool error);
 	//!  called when the user presses the actionCheckUpdates
 	void searchForUpdates();
-#ifdef QTIPLOT_SUPPORT
 	void showDonationDialog();
-#endif
 	//! Open support page in external browser
 	void showSupportPage();
 	//! Open donation page in external browser
@@ -914,10 +927,9 @@ public slots:
 	void downloadManual();
 	//! Show translations page in external browser
 	void downloadTranslation();
-#ifdef QTIPLOT_DEMO
 	//! Shown when the user tries to save the project.
 	void showDemoVersionMessage();
-#endif
+	void showProVersionMessage();
 
 	void parseCommandLineArguments(const QStringList& args);
 	void createLanguagesList();
@@ -1092,6 +1104,7 @@ public slots:
 
 	void showToolBarsMenu();
 	void setFormatBarFont(const QFont &);
+	void setFormatBarColor(const QColor&);
 
 signals:
 	void modified();
@@ -1112,12 +1125,15 @@ private:
 	virtual QMenu * createPopupMenu(){return NULL;};
 	void updateCompleter(const QString& windowName, bool remove = false, const QString& newName = QString::null);
 	QMessageBox::StandardButton showSaveProjectMessage();
-	QString getSaveProjectName(const QString& fileName, bool *compress = 0);
+	QString getSaveProjectName(const QString& fileName, bool *compress = 0, int scope = 0);
 	void goToParentFolder();
 	bool isProjectFile(const QString& fn);
 	void initSearchForUpdates();
 
 private slots:
+	void addColumnNameToCompleter(const QString& colName, bool remove = false);
+	void removeColumnNameFromCompleter(const QString& colName){addColumnNameToCompleter(colName, true);};
+
 	void disableActions();
 	void customColumnActions();
 	void disableToolbars();
@@ -1151,6 +1167,7 @@ private slots:
     void insertGreekSymbol();
     void insertGreekMajSymbol();
     void insertMathSymbol();
+	void setTextColor();
 	//@}
 
 	void showCustomActionDialog();
@@ -1165,10 +1182,21 @@ private slots:
 
 #ifdef SCRIPTING_PYTHON
     void openQtDesignerUi();
+	void executeStartupScripts();
 #endif
 
 // TODO: a lot of this stuff should be private
 public:
+	bool d_show_table_paste_dialog;
+	double d_stats_significance_level;
+	bool d_stats_result_table;
+	bool d_stats_result_log;
+	bool d_stats_result_notes;
+	bool d_stats_confidence;
+	bool d_stats_power;
+	bool d_stats_output;
+	bool d_descriptive_stats;
+	bool d_confirm_modif_2D_points;
 	bool d_ask_web_connection;
 	bool d_open_last_project;
 	int d_curve_max_antialising_size;
@@ -1183,6 +1211,9 @@ public:
 	bool d_synchronize_graph_scales;
 	int d_latex_compiler;
 	QString d_latex_compiler_path;
+	QString d_java_path;
+	QString d_soffice_path;
+	QString d_jodconverter_path;
 	//! Last selected filter in open project dialog
     QString d_open_project_filter;
 	//! Default geometry unit to be displayed in the EnrichmentDialog.
@@ -1201,6 +1232,8 @@ public:
     //! Flag telling if line numbers are displayed in note windows
     bool d_note_line_numbers;
 	QString d_python_config_folder;
+	//! Scripts in this folder are executed at startup if default script language is Python
+	QString d_startup_scripts_folder;
 	QString d_translations_folder;
 	//! Flag telling if the application is opening a project file or not
 	bool d_opening_file;
@@ -1375,6 +1408,12 @@ public:
 	//@}
 
 private:
+#ifdef Q_OS_WIN
+	void detectExcel();
+#endif
+	void loadPlugins();
+	QList<ImportExportPlugin *> d_import_export_plugins;
+
 	bool d_mdi_windows_area;
 	MdiSubWindow *d_active_window;
     TextEditor *d_text_editor;
@@ -1426,12 +1465,8 @@ private:
     QAction *actionNewSurfacePlot, *actionNewMatrix, *actionNewGraph, *actionNewFolder;
     QAction *actionOpen, *actionLoadImage, *actionSaveProject, *actionSaveProjectAs, *actionImportImage;
 	QAction *actionLoad, *actionUndo, *actionRedo, *actionImportSound;
-#ifdef ODS_IMPORT
-	QAction *actionOpenOds;
-#endif
-#ifdef XLS_IMPORT
-	QAction *actionOpenExcel, *actionExportExcel;
-#endif
+	QAction *actionImportDatabase, *actionOpenOds;
+	QAction *actionExportExcel, *actionExportOds, *actionOpenExcel;
     QAction *actionCopyWindow, *actionShowAllColumns, *actionHideSelectedColumns;
     QAction *actionCutSelection, *actionCopySelection, *actionPasteSelection, *actionClearSelection;
     QAction *actionShowExplorer, *actionShowLog, *actionAddLayer, *actionShowLayerDialog, *actionAutomaticLayout;
@@ -1461,7 +1496,10 @@ private:
     QAction *actionTableRecalculate, *actionExtractGraphs, *actionExtractLayers;
     QAction *actionAbout, *actionShowHelp, *actionChooseHelpFolder;
     QAction *actionRename, *actionCloseWindow;
-    QAction *actionConvertTableDirect, *actionConvertTableBinning, *actionConvertTableRegularXYZ;
+	QAction *actionConvertTableDirect, *actionConvertTableBinning, *actionConvertTableRegularXYZ;
+#ifdef HAVE_ALGLIB
+	QAction *actionConvertTableRandomXYZ, *actionExpandMatrix, *actionShrinkMatrix, *actionSmoothMatrix;
+#endif
     QAction *actionAddColToTable, *actionDeleteLayer, *actionInterpolate;
     QAction *actionResizeActiveWindow, *actionHideActiveWindow;
     QAction *actionShowMoreWindows, *actionPixelLineProfile, *actionIntensityTable;
@@ -1477,7 +1515,7 @@ private:
 	QAction *actionLowPassFilter, *actionHighPassFilter, *actionBandPassFilter, *actionBandBlockFilter;
 	QAction *actionSortTable, *actionSortSelection, *actionNormalizeSelection;
 	QAction *actionNormalizeTable, *actionConvolute, *actionDeconvolute, *actionCorrelate, *actionAutoCorrelate;
-	QAction *actionTranslateHor, *actionTranslateVert, *actionSetAscValues, *actionSetRandomValues;
+	QAction *actionTranslateHor, *actionTranslateVert, *actionSetAscValues, *actionSetRandomValues, *actionSetRandomNormalValues;
 	QAction *actionSetXCol, *actionSetYCol, *actionSetZCol, *actionSetLabelCol, *actionDisregardCol, *actionSetXErrCol, *actionSetYErrCol;
 	QAction *actionBoxPlot, *actionMultiPeakGauss, *actionMultiPeakLorentz, *actionCheckUpdates;
 	QAction *actionDonate, *actionHomePage, *actionDownloadManual, *actionTechnicalSupport, *actionTranslations;
@@ -1486,6 +1524,7 @@ private:
 	QAction *actionNextWindow, *actionPrevWindow;
 	QAction *actionScriptingLang, *actionRestartScripting, *actionClearTable, *actionGoToRow, *actionGoToColumn;
 	QAction *actionNoteExecute, *actionNoteExecuteAll, *actionNoteEvaluate, *actionSaveNote, *actionFrequencyCount;
+	QAction *actionOneSampletTest, *actionTwoSampletTest, *actionShapiroWilk, *actionChiSquareTest;
 	QAction *actionAnimate, *actionPerspective, *actionFitFrame, *actionResetRotation;
     QAction *actionDeleteRows, *actionDrawPoints, *actionAddZoomPlot;
 	QAction *btnCursor, *btnSelect, *btnPicker, *btnRemovePoints, *btnMovePoints, *actionDragCurve;
@@ -1495,7 +1534,7 @@ private:
     QAction *actionMatrixGrayScale, *actionMatrixRainbowScale, *actionMatrixCustomScale, *actionRotateMatrixMinus;
     QAction *actionMatrixXY, *actionMatrixColumnRow, *actionImagePlot, *actionToolBars, *actionImageProfilesPlot;
     QAction *actionMatrixFFTDirect, *actionMatrixFFTInverse;
-	QAction *actionFontBold, *actionFontItalic, *actionFontBox, *actionFontSize;
+	QAction *actionFontBold, *actionFontItalic, *actionFontBox, *actionFontSize, *actionTextColor;
 	QAction *actionSuperscript, *actionSubscript, *actionUnderline, *actionGreekSymbol, *actionCustomActionDialog;
 	QAction *actionGreekMajSymbol, *actionMathSymbol;
 	QAction *Box, *Frame, *None;
@@ -1505,7 +1544,10 @@ private:
     QActionGroup *coord, *floorstyle, *grids, *plotstyle, *dataTools;
 	QAction *actionMagnify, *actionFindWindow, *actionWaterfallPlot, *actionMagnifyHor, *actionMagnifyVert;
     QAction *actionMoveRowUp, *actionMoveRowDown, *actionAdjustColumnWidth;
-    QAction *actionPresentationODF, *actionRenameNoteTab, *actionAddNoteTab, *actionCloseNoteTab;
+#if QT_VERSION >= 0x040500
+	QAction *actionPresentationODF;
+#endif
+	QAction *actionRenameNoteTab, *actionAddNoteTab, *actionCloseNoteTab;
     QAction *actionIncreaseIndent, *actionDecreaseIndent, *actionFind, *actionFindNext, *actionFindPrev, *actionReplace;
     QAction *actionIncreasePrecision, *actionDecreasePrecision, *actionPrintPreview;
 	QAction *actionVertSharedAxisLayers, *actionHorSharedAxisLayers, *actionSharedAxesLayers, *actionStackSharedAxisLayers;
@@ -1519,5 +1561,11 @@ private:
 	QList<QColor> d_indexed_colors;
 	QStringList d_indexed_color_names;
 	QList<int> d_symbols_list;
+#ifdef HAVE_TAMUANOVA
+	QAction *actionOneWayANOVA, *actionTwoWayANOVA;
+#endif
+#ifdef Q_OS_WIN
+	bool d_has_excel;
+#endif
 };
 #endif
