@@ -4,7 +4,7 @@
     --------------------------------------------------------------------
 	Copyright            : (C) 2004 - 2010 by Ion Vasilief,
 						   (C) 2006 - June 2007 by Knut Franke
-    Email (use @ for *)  : ion_vasilief*yahoo.fr, knut.franke*gmx.de
+	Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Import ASCII file(s) dialog
 
  ***************************************************************************/
@@ -516,11 +516,6 @@ void ImportASCIIDialog::changePreviewFile(const QString& path)
 	if (path.isEmpty())
 		return;
 
-	if (d_current_path.isEmpty()){//avoid importing the first file which is by default selected in the file dialog
-		d_current_path = path;
-		return;
-	}
-
 	QFileInfo fi(path);
 	if (!fi.exists() || fi.isDir() || !fi.isFile())
 		return;
@@ -709,7 +704,7 @@ void PreviewTable::importASCII(const QString &fname, const QString &sep, int ign
 			s = s.simplifyWhiteSpace();
 		else if (stripSpaces)
 			s = s.stripWhiteSpace();
-		line = s.split(sep, QString::SkipEmptyParts);
+		line = s.split(sep, QString::KeepEmptyParts);
 		for (int i=0; i<line.size(); i++){
 			int aux = startCol + i;
 			if (aux < comments.size())
