@@ -42,19 +42,13 @@ OpenProjectDialog::OpenProjectDialog(QWidget *parent, bool extended, Qt::WFlags
 	QStringList filters;
 	filters << tr("QtiPlot project") + " (*.qti)"
 		<< tr("Compressed QtiPlot project") + " (*.qti.gz)"
-#ifdef OPJ_IMPORT
 		<< tr("Origin project") + " (*.opj *.OPJ)"
 		<< tr("Origin matrix") + " (*.ogm *.OGM)"
 		<< tr("Origin worksheet") + " (*.ogw *.OGW)"
 		<< tr("Origin graph") + " (*.ogg *.OGG)"
-#endif
 		<< tr("Backup files") + " (*.qti~)"
-#ifdef XLS_IMPORT
 		<< tr("Excel") + " (*.xls)"
-#endif
-#ifdef ODS_IMPORT
 		<< tr("ODF Spreadsheet") + " (*.ods)"
-#endif
 		<< tr("All files") + " (*)";
 	setFilters(filters);
 
@@ -88,7 +82,8 @@ OpenProjectDialog::OpenProjectDialog(QWidget *parent, bool extended, Qt::WFlags
 
 void OpenProjectDialog::updateAdvancedOptions (const QString & filter)
 {
-	if (filter.contains("*.ogm") || filter.contains("*.ogw") || filter.contains("*.xls")) {
+	if (filter.contains("*.ogm") || filter.contains("*.ogw") ||
+		filter.contains("*.xls") || filter.contains("*.xlsx")){
 		d_extension_toggle->setChecked(false);
 		d_extension_toggle->setEnabled(false);
 		return;
