@@ -33,6 +33,8 @@
 #include <muParserScript.h>
 #include <ScriptingEnv.h>
 #include <ColorMapEditor.h>
+#include <ExcelFileConverter.h>
+#include <ImportExportPlugin.h>
 
 #include <QtGlobal>
 #include <QTextStream>
@@ -56,8 +58,11 @@
 #include <QImageWriter>
 #include <QSvgGenerator>
 #include <QFile>
+#include <QFileInfo>
 #include <QUndoStack>
+#if QT_VERSION >= 0x040500
 #include <QTextDocumentWriter>
+#endif
 #include <QTextTable>
 
 #include <stdlib.h>
@@ -66,15 +71,6 @@
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_linalg.h>
 
-#ifdef EMF_OUTPUT
-#include <EmfEngine.h>
-#endif
-
-#ifdef XLS_IMPORT
-    #include <ExcelFormat.h>
-    using namespace ExcelFormat;
-#endif
-
 Matrix::Matrix(ScriptingEnv *env, int r, int c, const QString& label, ApplicationWindow* parent, const QString& name, Qt::WFlags f)
 : MdiSubWindow(label, parent, name, f), scripted(env)
 {
@@ -245,12 +241,12 @@ void Matrix::save(const QString &fn, const QString &info, bool saveAsTemplate)
 			for(int j = 0; j < cols; j++){
 				double val = d_data[aux + j];
 				if (gsl_finite(val))
-					t << QString::number(val, 'e', 16);
+					t << QString::number(val, 'g', 16);
 				t << "\t";
 			}
 			double val = d_data[aux + cols];
 			if (gsl_finite(val))
-				t << QString::number(val, 'e', 16);
+				t << QString::number(val, 'g', 16);
 			t << "\n";
 		}
 		t << "</data>\n";
@@ -493,6 +489,58 @@ void Matrix::rotate90(bool clockwise)
 		d_undo_stack->push(new MatrixSymmetryOperation(d_matrix_model, RotateCounterClockwise, tr("Rotate -90")));
 }
 
+void Matrix::resample(int rows, int cols, const ResamplingMethod& method)
+{
+#ifdef HAVE_ALGLIB
+	int r = numRows();
+	int c = numCols();
+	if (rows == r && cols == c)
+		return;
+
+	if(rows*cols > r*c && !d_matrix_model->canResize(rows, cols))
+		return;
+
+	QString explain = tr("Resample") + " " + QString::number(rows) + "x" + QString::number(cols) + ", ";
+	if (method == Bilinear)
+		explain += tr("bilinear");
+	else
+		explain += tr("bicubic");
+
+	double *buffer = d_matrix_model->dataCopy();
+	MatrixResampleCommand *com = new MatrixResampleCommand(d_matrix_model, QSize(r, c), QSize(rows, cols), (int)method, buffer, explain);
+	if (buffer)
+		d_undo_stack->push(com);
+	else if (ignoreUndo()){
+		com->redo();
+		delete com;
+	}
+
+	emit modifiedWindow(this);
+	modifiedData(this);
+#else
+	QMessageBox::critical(this, tr("QtiPlot"), tr("QtiPlot was built without support for ALGLIB, resampling is not possible!"));
+#endif
+}
+
+void Matrix::smooth()
+{
+#ifdef HAVE_ALGLIB
+	double *buffer = d_matrix_model->dataCopy();
+	MatrixSmoothCommand *com = new MatrixSmoothCommand(d_matrix_model, buffer, tr("Smoothed"));
+	if (buffer)
+		d_undo_stack->push(com);
+	else if (ignoreUndo()){
+		com->redo();
+		delete com;
+	}
+
+	emit modifiedWindow(this);
+	modifiedData(this);
+#else
+	QMessageBox::critical(this, tr("QtiPlot"), tr("QtiPlot was built without support for ALGLIB, resampling is not possible!"));
+#endif
+}
+
 bool Matrix::canCalculate(bool useMuParser)
 {
 	if (formula_str.isEmpty())
@@ -885,6 +933,7 @@ void Matrix::exportRasterImage(const QString& fileName, int quality, int dpi)
 	int dpm = (int)ceil(100.0/2.54*dpi);
 	image.setDotsPerMeterX(dpm);
 	image.setDotsPerMeterY(dpm);
+#if QT_VERSION >= 0x040500
 	if (fileName.endsWith(".odf")){
 		QTextDocument *document = new QTextDocument();
 		QTextCursor cursor = QTextCursor(document);
@@ -896,6 +945,7 @@ void Matrix::exportRasterImage(const QString& fileName, int quality, int dpi)
 		QTextDocumentWriter writer(fileName);
 		writer.write(document);
 	} else
+#endif
 		image.save(fileName, 0, quality);
 }
 
@@ -912,16 +962,12 @@ void Matrix::exportToFile(const QString& fileName)
 	} else if(fileName.contains(".svg")){
 		exportSVG(fileName);
 		return;
-	}
-#ifdef EMF_OUTPUT
-	else if(fileName.contains(".emf")){
+	} else if(fileName.contains(".emf")){
 		exportEMF(fileName);
 		return;
-	}
-#endif
-	else {
+	} else {
 		QList<QByteArray> list = QImageWriter::supportedImageFormats();
-    	for(int i=0 ; i<list.count() ; i++){
+		for(int i=0 ; i<list.count() ; i++){
 			if (fileName.contains( "." + list[i].toLower())){
 				d_matrix_model->renderImage().save(fileName, list[i], 100);
 				return;
@@ -1097,27 +1143,25 @@ void Matrix::exportVector(const QString& fileName, int res, bool color)
     paint.end();
 }
 
-#ifdef EMF_OUTPUT
 void Matrix::exportEMF(const QString& fileName)
 {
-	int width = numRows();
-	int height = numCols();
-
-	EmfPaintDevice emf(QSize(width, height), fileName);
-	QPainter p(&emf);
-	p.drawImage (QRect(0, 0, width, height), d_matrix_model->renderImage());
-	p.end();
+	if (!applicationWindow())
+		return;
+	ImportExportPlugin *ep = applicationWindow()->exportPlugin("emf");
+	if (!ep)
+		return;
+	ep->exportMatrix(this, fileName, false);
 }
-#endif
 
 bool Matrix::isEmpty()
 {
-	double min, max;
-	range(&min, &max);
-	if (gsl_isnan(min) && gsl_isnan(max))
-		return true;
-
-	return false;
+	double *data = d_matrix_model->dataVector();
+	int size = numRows()*numCols();
+	for (int i = 0; i < size; i++){
+		if (gsl_finite(data[i]))
+			return false;
+	}
+	return true;
 }
 
 void Matrix::range(double *min, double *max)
@@ -1514,6 +1558,7 @@ void Matrix::fft(bool inverse)
 
 bool Matrix::exportODF(const QString& fname, bool exportSelection)
 {
+#if QT_VERSION >= 0x040500
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
 	int topRow = 0;
@@ -1571,11 +1616,69 @@ bool Matrix::exportODF(const QString& fname, bool exportSelection)
 
 	QApplication::restoreOverrideCursor();
 	return true;
+#endif
+	return false;
+}
+
+bool Matrix::exportOdsSpreadsheet(const QString& fname, bool exportSelection)
+{
+	QString name = fname;
+	QString ext = QFileInfo(fname).completeSuffix();
+	name.replace("." + ext, ".xls");
+	if (!exportExcel(name, exportSelection))
+		return false;
+
+	QFile::remove(fname);
+
+	ExcelFileConverter(name, applicationWindow());
+	return true;
 }
 
-#ifdef XLS_IMPORT
 bool Matrix::exportExcel(const QString& fname, bool exportSelection)
 {
+	if (!applicationWindow())
+		return false;
+	ImportExportPlugin *ep = applicationWindow()->exportPlugin("xls");
+	if (!ep)
+		return false;
+	return ep->exportMatrix(this, fname, exportSelection);
+}
+
+bool Matrix::exportASCII(const QString& fname, const QString& separator, bool exportSelection)
+{
+	if (!applicationWindow())
+		return false;
+
+	if (fname.endsWith(".tex")){
+		ImportExportPlugin *ep = applicationWindow()->exportPlugin("tex");
+		if (!ep)
+			return false;
+		return ep->exportMatrix(this, fname, exportSelection);
+	} else if (fname.endsWith(".csv")){
+		ImportExportPlugin *ep = applicationWindow()->exportPlugin("csv");
+		if (!ep)
+			return false;
+		return ep->exportMatrix(this, fname, exportSelection);
+	}
+
+	QFile f(fname);
+	if (!f.open( QIODevice::WriteOnly)){
+		QMessageBox::critical(this, tr("QtiPlot - ASCII Export Error"),
+		tr("Could not write to file: <br><h4>%1</h4><p>Please verify that you have the right to write to this location!").arg(fname));
+		return false;
+	}
+
+	if (fname.endsWith(".odf") || fname.endsWith(".html")){
+		f.close();
+		return exportODF(fname, exportSelection);
+	} else if (fname.endsWith(".xls")){
+		f.close();
+		return exportExcel(fname, exportSelection);
+	} else if (fname.endsWith(".ods")){
+		f.close();
+		return exportOdsSpreadsheet(fname, exportSelection);
+	}
+
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
 	int topRow = 0;
@@ -1583,6 +1686,10 @@ bool Matrix::exportExcel(const QString& fname, bool exportSelection)
 	int leftCol = 0;
 	int rightCol = numCols() - 1;
 
+	QTextStream t( &f );
+	QString eol = applicationWindow()->endOfLine();
+	QString sep = separator;
+
 	if (exportSelection && d_view_type == TableView){
 		QModelIndexList selectedIndexes = d_table_view->selectionModel()->selectedIndexes();
 		if (!selectedIndexes.isEmpty()){
@@ -1591,7 +1698,6 @@ bool Matrix::exportExcel(const QString& fname, bool exportSelection)
 			leftCol = selectedIndexes[0].column();
 			rightCol = leftCol;
 		}
-
 		foreach(QModelIndex index, selectedIndexes){
 			int row = index.row();
 			if (row < topRow)
@@ -1607,94 +1713,6 @@ bool Matrix::exportExcel(const QString& fname, bool exportSelection)
 		}
 	}
 
-	BasicExcel xls;
-	xls.New(1);
-	BasicExcelWorksheet* sheet = xls.GetWorksheet((size_t)0);
-
-	rightCol = QMIN(rightCol, 256);
-	bottomRow = QMIN(bottomRow, 65536);
-	for (int i = topRow; i <= bottomRow; i++){
-		for (int j = leftCol; j <= rightCol; j++){
-			if (d_matrix_model->text(i, j).isEmpty())
-				continue;
-			sheet->Cell(i, j)->Set(d_matrix_model->cell(i, j));
-		}
-	}
-
-	xls.SaveAs(fname);
-
-	QApplication::restoreOverrideCursor();
-	return true;
-}
-#endif
-
-bool Matrix::exportASCII(const QString& fname, const QString& separator, bool exportSelection)
-{
-	QFile f(fname);
-	if ( !f.open( QIODevice::WriteOnly ) ){
-		QMessageBox::critical(this, tr("QtiPlot - ASCII Export Error"),
-				tr("Could not write to file: <br><h4>%1</h4><p>Please verify that you have the right to write to this location!").arg(fname));
-		return false;
-	}
-
-	if (fname.endsWith(".odf") || fname.endsWith(".html")){
-		f.close();
-		return exportODF(fname, exportSelection);
-        }
-#ifdef XLS_IMPORT
-        else if (fname.endsWith(".xls")){
-            f.close();
-            return exportExcel(fname, exportSelection);
-        }
-#endif
-
-	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-	int topRow = 0;
-	int bottomRow = numRows() - 1;
-	int leftCol = 0;
-	int rightCol = numCols() - 1;
-
-	QTextStream t( &f );
-	QString eol = applicationWindow()->endOfLine();
-	QString sep = separator;
-
-	bool exportTex = (fname.endsWith(".tex")) ? true : false;
-	if (exportTex){
-		t << "\\begin{tabular}{|";
-		eol = "\\\\\\hline\n";
-		sep = " & ";
-	}
-
-	if (exportSelection && d_view_type == TableView){
-            QModelIndexList selectedIndexes = d_table_view->selectionModel()->selectedIndexes();
-            if (!selectedIndexes.isEmpty()){
-                topRow = selectedIndexes[0].row();
-                bottomRow = topRow;
-                leftCol = selectedIndexes[0].column();
-                rightCol = leftCol;
-            }
-            foreach(QModelIndex index, selectedIndexes){
-                int row = index.row();
-                if (row < topRow)
-                    topRow = row;
-                if (row > bottomRow)
-                    bottomRow = row;
-
-                int col = index.column();
-                if (col < leftCol)
-                    leftCol = col;
-                if (col > rightCol)
-                    rightCol = col;
-            }
-	}
-
-	if (exportTex){
-		for (int i = leftCol; i <= rightCol; i++)
-			t << "c|";
-		t << "}\\hline\n";
-	}
-
 	for (int i = topRow; i <= bottomRow; i++){
 		for (int j = leftCol; j < rightCol; j++){
 			t << d_matrix_model->text(i, j);
@@ -1704,9 +1722,6 @@ bool Matrix::exportASCII(const QString& fname, const QString& separator, bool ex
 		t << eol;
 	}
 
-	if (exportTex)
-		t << "\\end{tabular}\n";
-
 	f.close();
 	QApplication::restoreOverrideCursor();
 	return true;
