@@ -86,6 +86,7 @@ public:
 		NewRows, //!< add file as new rows to the current matrix
 		Overwrite //!< replace content of current matrix with the imported file
 	};
+	enum ResamplingMethod{Bilinear, Bicubic};
 
 	void setViewType(ViewType, bool renderImage = true);
 	ViewType viewType(){return d_view_type;};
@@ -101,9 +102,7 @@ public:
 	void exportSVG(const QString& fileName);
 	void exportToFile(const QString& fileName);
 	void exportVector(const QString& fileName, int res = 0, bool color = true);
-#ifdef EMF_OUTPUT
 	void exportEMF(const QString& fileName);
-#endif
 
 	MatrixModel * matrixModel(){return d_matrix_model;};
     QUndoStack *undoStack(){return d_undo_stack;};
@@ -118,6 +117,9 @@ public:
 	int numCols(){return d_matrix_model->columnCount();};
 	void setNumCols(int cols){d_matrix_model->setColumnCount(cols);};
 
+	void resample(int rows, int cols, const ResamplingMethod& method = Bilinear);
+	void smooth();
+
 	//event handlers
 	//! Custom event handler
 	/**
@@ -160,9 +162,9 @@ public:
 	bool muParserCalculate(int startRow = 0, int endRow = -1, int startCol = 0, int endCol = -1);
 
 	bool exportODF(const QString& fname, bool exportSelection);
-#ifdef XLS_IMPORT
-        bool exportExcel(const QString& fname, bool exportSelection);
-#endif
+	bool exportExcel(const QString& fname, bool exportSelection);
+	bool exportOdsSpreadsheet(const QString& fname, bool exportSelection);
+
 	bool exportASCII(const QString& fname, const QString& separator, bool exportSelection);
 	void importASCII(const QString &fname, const QString &sep, int ignoredLines, bool stripSpaces,
 					bool simplifySpaces, const QString& commentString, ImportMode importAs = Overwrite,
