@@ -51,7 +51,7 @@ class QwtPlotPanner;
 class QwtPlotMagnifier;
 class QwtPlotCurve;
 class QwtPlotZoomer;
-class QwtPieCurve;
+class PieCurve;
 class Table;
 class ArrowMarker;
 class ImageWidget;
@@ -64,7 +64,7 @@ class SelectionMoveResizer;
 class RangeSelectorTool;
 class DataCurve;
 class PlotCurve;
-class QwtErrorPlotCurve;
+class ErrorBarsCurve;
 class MultiLayer;
 class Spectrogram;
 class FunctionCurve;
@@ -160,6 +160,7 @@ class Graph: public QwtPlot
 		bool hasSeletedItems();
 		void deselect();
 		void deselect(QWidget *);
+		void selectCanvas();
 
 		QPointer<SelectionMoveResizer> selectionMoveResizer(){return d_markers_selector;};
 
@@ -220,9 +221,10 @@ class Graph: public QwtPlot
 		bool hasPanningMagnifierEnabled(){if (d_magnifier && d_panner) return true; return false;};
 		QwtPlotMagnifier* magnifyTool(){return d_magnifier;};
 
+#ifdef TEX_OUTPUT
 		static QString escapeTeXSpecialCharacters(const QString &);
 		static QString texSuperscripts(const QString &);
-
+#endif
 		void changeCurveIndex(int fromIndex, int toIndex);
 		void enableDouglasPeukerSpeedMode(double tolerance, int maxPoints);
 
@@ -236,15 +238,17 @@ class Graph: public QwtPlot
 	public slots:
 		void copy(Graph* g);
 		void copyCurves(Graph* g);
+		void copyScaleWidget(Graph* g, int i);
+		void copyScaleDraw(Graph* g, int i);
 
 		//! \name Pie Curves
 		//@{
 		//! Returns true if this Graph is a pie plot, false otherwise.
 		bool isPiePlot();
 		//! Used when creating a pie plot.
-		QwtPieCurve* plotPie(Table* w,const QString& name, int startRow = 0, int endRow = -1);
+		PieCurve* plotPie(Table* w,const QString& name, int startRow = 0, int endRow = -1);
 		//! Used when restoring a pie plot from a project file.
-		QwtPieCurve* plotPie(Table* w, const QString& name, const QPen& pen, int brush, int size,
+		PieCurve* plotPie(Table* w, const QString& name, const QPen& pen, int brush, int size,
 			int firstColor, int startRow = 0, int endRow = -1, bool visible = true,
 			double d_start_azimuth = 270, double d_view_angle = 90, double d_thickness = 33,
 			double d_horizontal_offset = 0.0, double d_edge_dist = 25, bool d_counter_clockwise = false,
@@ -280,6 +284,7 @@ class Graph: public QwtPlot
 		void removeCurves(const QString& s);
 
 		void updateCurvesData(Table* w, const QString& yColName);
+		void reloadCurvesData();
 
 		int curveCount(){return d_curves.size();};
 		bool validCurvesDataSize();
@@ -289,8 +294,9 @@ class Graph: public QwtPlot
 		//! Map curve pointer to index.
 		int curveIndex(QwtPlotItem *c){return d_curves.indexOf(c);};
 		//! map curve title to index
-		int curveIndex(const QString &title){return plotItemsList().findIndex(title);}
+		int curveIndex(const QString &title){return plotItemsList().indexOf(title);}
 		DataCurve* dataCurve(int index);
+		FunctionCurve* functionCurve(int index);
 		//! get curve by index
 		PlotCurve* curve(int index);
 		//! get curve by name
@@ -329,11 +335,15 @@ class Graph: public QwtPlot
 		//! Provided for convenience in scripts
 		void exportToFile(const QString& fileName);
 		void exportSVG(const QString& fname, const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
-#ifdef EMF_OUTPUT
 		void exportEMF(const QString& fname, const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
-#endif
 		void exportTeX(const QString& fname, bool color = true, bool escapeStrings = true, bool fontSizes = true,
 						const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
+#ifdef TEX_OUTPUT
+		bool isExportingTeX(){return d_is_exporting_tex;};
+		void setTeXExportingMode(bool on = true){d_is_exporting_tex = on;};
+		bool escapeTeXStrings(){return d_tex_escape_strings;};
+		void setEscapeTeXStringsMode(bool on = true){d_tex_escape_strings = on;};
+#endif
 		void exportVector(const QString& fileName, int res = 0, bool color = true,
 						const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
 		void exportImage(const QString& fileName, int quality = 100, bool transparent = false,
@@ -342,35 +352,35 @@ class Graph: public QwtPlot
 
 		void draw(QPaintDevice *, const QSize& size, double fontsFactor = 1.0);
 		static QSize customPrintSize(const QSizeF& customSize, int unit, int dpi);
-
-		bool isExportingTeX(){return d_is_exporting_tex;};
-		void setTeXExportingMode(bool on = true){d_is_exporting_tex = on;};
-		bool escapeTeXStrings(){return d_tex_escape_strings;};
-		void setEscapeTeXStringsMode(bool on = true){d_tex_escape_strings = on;};
 		//@}
 
 		void updatePlot();
 
 		//! \name Error Bars
 		//@{
-		QwtErrorPlotCurve* addErrorBars(const QString& xColName, const QString& yColName, Table *errTable,
+		ErrorBarsCurve* addErrorBars(const QString& xColName, const QString& yColName, Table *errTable,
 				const QString& errColName, int type = 1, double width = 1, int cap = 8, const QColor& color = QColor(Qt::black),
 				bool through = true, bool minus = true, bool plus = true);
 
-		QwtErrorPlotCurve* addErrorBars(const QString& yColName, Table *errTable, const QString& errColName,
+		ErrorBarsCurve* addErrorBars(const QString& yColName, Table *errTable, const QString& errColName,
 				int type = 1, double width = 1, int cap = 8, const QColor& color = QColor(Qt::black),
 				bool through = true, bool minus = true, bool plus = true);
 
-		void updateErrorBars(QwtErrorPlotCurve *er, bool xErr, double width, int cap, const QColor& c, bool plus, bool minus, bool through);
+		ErrorBarsCurve* addErrorBars(DataCurve *c, Table *errTable, const QString& errColName,
+				int type = 1, double width = 1, int cap = 8, const QColor& color = QColor(Qt::black),
+				bool through = true, bool minus = true, bool plus = true);
+
+		void updateErrorBars(ErrorBarsCurve *er, bool xErr, double width, int cap, const QColor& c, bool plus, bool minus, bool through);
 
 		//! Returns a valid master curve for the error bars curve.
-		DataCurve* masterCurve(QwtErrorPlotCurve *er);
+		DataCurve* masterCurve(ErrorBarsCurve *er);
 		//! Returns a valid master curve for a plot association.
 		DataCurve* masterCurve(const QString& xColName, const QString& yColName);
 		//@}
 
 		//! \name Event Handlers
 		//@{
+		bool mousePressed(QEvent *);
 		void contextMenuEvent(QContextMenuEvent *);
 		void closeEvent(QCloseEvent *e);
 		bool focusNextPrevChild ( bool next );
@@ -384,6 +394,7 @@ class Graph: public QwtPlot
 				double stepBeforeBreak = 0.0, double stepAfterBreak = 0.0, int minTicksBeforeBreak = 4,
 				int minTicksAfterBreak = 4, bool log10AfterBreak = false, int breakWidth = 4, bool breakDecoration = true);
 		double axisStep(int axis){return d_user_step[axis];};
+		void setAxisStep(int axis, double step){d_user_step[axis] = step;};
 		void setCanvasCoordinates(const QRectF&);
 
 		//! \name Curves Layout
@@ -406,7 +417,7 @@ class Graph: public QwtPlot
 		void setAutoScale();
 		void updateScale();
 
-		//! \name Saving to File
+		//! \name Saving/Restoring to/from file
 		//@{
 		QString saveToString(bool saveAsTemplate = false);
 		QString saveScale();
@@ -431,6 +442,10 @@ class Graph: public QwtPlot
 		QString saveAxesBackbones();
 		QString saveTickLabelsSpace();
 		QString saveLabelsPrefixAndSuffix();
+		QString saveBackgroundImage();
+		void restoreBackgroundImage(const QStringList& lst);
+		void restoreSymbolImage(int index, const QStringList& lst);
+		static QString rgbaName(const QColor& color);
 		//@}
 
 		//! \name Texts
@@ -597,6 +612,13 @@ class Graph: public QwtPlot
 		int canvasFrameWidth();
 		//@}
 
+		//! \name Canvas Image Background
+		//@{
+		QString canvasBackgroundFileName(){return d_canvas_bkg_path;};
+		void setCanvasBackgroundImage (const QString & fn = QString(), bool update = true);
+		QPixmap backgroundPixmap(){return d_canvas_bkg_pix;};
+		//@}
+
 		//! \name Plot Title
 		//@{
 		void setTitleFont(const QFont &fnt);
@@ -612,11 +634,6 @@ class Graph: public QwtPlot
 		void initTitle( bool on, const QFont& fnt);
 		//@}
 
-		//! \name Modifing insertCurve Data
-		//@{
-		QString selectedCurveTitle();
-		//@}
-
 		void disableTools();
 
 		/*! Enables the data range selector tool.
@@ -670,7 +687,7 @@ class Graph: public QwtPlot
 
 		//! \name Vector Curves
 		//@{
-		VectorCurve* plotVectorCurve(Table* w, const QStringList& colList, int style, int startRow = 0, int endRow = -1);
+		VectorCurve* plotVectors(Table* w, const QStringList& colList, int style, int startRow = 0, int endRow = -1);
 		void updateVectorsLayout(int curve, const QColor& color, double width, int arrowLength, int arrowAngle, bool filled, int position,
 				const QString& xEndColName = QString(), const QString& yEndColName = QString());
 		//@}
@@ -678,7 +695,8 @@ class Graph: public QwtPlot
 		//! \name Box Plots
 		//@{
 		BoxCurve* openBoxDiagram(Table *w, const QStringList& l, int fileVersion);
-		void plotBoxDiagram(Table *w, const QStringList& names, int startRow = 0, int endRow = -1);
+		void plotBox(Table *w, const QStringList& names, int startRow = 0, int endRow = -1);
+		BoxCurve * boxCurve(int index);
 		//@}
 
 		//! \name Resizing
@@ -741,13 +759,18 @@ class Graph: public QwtPlot
 
 		void disableCurveAntialiasing(bool disable, int maxPoints);
 		bool isCurveAntialiasingEnabled(QwtPlotItem *it);
+		bool isCurveAntialiasingDisabled(){return d_disable_curve_antialiasing;};
+		int maxAntialisingSize(){return d_max_antialising_size;};
 
+		void setCurrentColor(const QColor& c);
+		void notifyColorChange(const QColor& c){emit currentColorChanged(c);};
 		void setCurrentFont(const QFont& f);
 		void notifyFontChange(const QFont& f){emit currentFontChanged(f);};
         void enableTextEditor();
 
 signals:
-		void selectedGraph (Graph*);
+		void selectedGraph(Graph*);
+		void selectedCanvas(Graph*);
 		void closedGraph();
 		void drawLineEnded(bool);
 		void cursorInfo(const QString&);
@@ -770,6 +793,7 @@ signals:
 		void dataRangeChanged();
 		void showFitResults(const QString&);
 		void currentFontChanged(const QFont&);
+		void currentColorChanged(const QColor&);
         void enableTextEditor(Graph *);
         void axisDivChanged(Graph *, int);
 		void updatedLayout(Graph *);
@@ -836,8 +860,10 @@ signals:
 		bool d_auto_scale;
 		//! Axes tick lengths
 		int d_min_tick_length, d_maj_tick_length;
+#ifdef TEX_OUTPUT
 		bool d_is_exporting_tex;
 		bool d_tex_escape_strings;
+#endif
 		QList<FrameWidget*> d_enrichments;
 		QwtPlotMagnifier *d_magnifier;
 		QwtPlotPanner *d_panner;
@@ -847,5 +873,8 @@ signals:
 		AxisTitlePolicy d_axis_title_policy;
 		bool d_synchronize_scales;
 		QStringList d_axis_titles;
+
+		QString d_canvas_bkg_path;
+		QPixmap d_canvas_bkg_pix;
 };
 #endif // GRAPH_H
