@@ -28,14 +28,16 @@
  ***************************************************************************/
 #include "LegendWidget.h"
 #include "PlotCurve.h"
-#include "QwtPieCurve.h"
+#include "PieCurve.h"
 #include "VectorCurve.h"
 #include "SelectionMoveResizer.h"
 #include "MultiLayer.h"
 #include <ApplicationWindow.h>
 #include <PenStyleBox.h>
 
-#include <QTeXEngine.h>
+#ifdef TEX_OUTPUT
+	#include <QTeXEngine.h>
+#endif
 
 #include <QPainter>
 #include <QPaintEngine>
@@ -120,16 +122,20 @@ void LegendWidget::print(QPainter *painter, const QwtScaleMap map[QwtPlot::axisC
 	int dfx = qRound(d_frame_pen.width()*xfactor);
 	int dfy = qRound(d_frame_pen.width()*yfactor);
 
+#ifdef TEX_OUTPUT
 	if (plot()->isExportingTeX()){
 		drawFrame(painter, QRect(x, y, qRound(this->width()*xfactor), height).adjusted(-dfx, -dfy, dfx, dfy));
 		((QTeXPaintDevice *)painter->device())->setTextHorizontalAlignment(Qt::AlignLeft);
 	} else
+#endif
 		drawFrame(painter, QRect(x, y, width, height).adjusted(-dfx, -dfy, dfx, dfy));
 
 	drawText(painter, QRect(x, y, textWidth, textHeight), heights, symbolLineLength);
 
+#ifdef TEX_OUTPUT
 	if (plot()->isExportingTeX())
 		((QTeXPaintDevice *)painter->device())->setTextHorizontalAlignment(Qt::AlignHCenter);
+#endif
 
 	// restore screen geometry parameters
 	h_space = space;
@@ -203,7 +209,7 @@ void LegendWidget::drawSymbol(PlotCurve *c, int point, QPainter *p, int x, int y
 	}
 
 	if (c->type() == Graph::Pie){
-		QwtPieCurve *pie = (QwtPieCurve *)c;
+		PieCurve *pie = (PieCurve *)c;
 		const QBrush br = QBrush(pie->color(point), pie->pattern());
 		QPen pen = pie->pen();
 		pen.setCosmetic(false);
@@ -235,19 +241,22 @@ void LegendWidget::drawSymbol(PlotCurve *c, int point, QPainter *p, int x, int y
 			QwtPainter::drawLine(p, x, y, x + l, y);
 	}
 
-	QwtSymbol symb = c->symbol();
-	int symb_size = symb.size().width();
-	if (symb_size > 15)
-		symb_size = 15;
-	else if (symb_size < 3)
-		symb_size = 3;
-	symb.setSize(symb_size);
+	if (c->symbol().pen().style() != Qt::NoPen){
+		QwtSymbol symb = c->symbol();
+		int symb_size = symb.size().width();
+		if (symb_size > 15)
+			symb_size = 15;
+		else if (symb_size < 3)
+			symb_size = 3;
+		symb.setSize(symb_size);
 
-	QPen pen = symb.pen();
-	pen.setCosmetic(false);
-	symb.setPen(pen);
+		QPen pen = symb.pen();
+		pen.setCosmetic(false);
+		symb.setPen(pen);
 
-	symb.draw(p, x + l/2, y);
+		symb.draw(p, x + l/2, y);
+	} else //ImageSymbol ?
+		c->symbol().draw(p, x + l/2, y);
 	p->restore();
 }
 
@@ -571,6 +580,13 @@ QString LegendWidget::parse(const QString& str)
     s.remove(QRegExp("\\l(*)", Qt::CaseInsensitive, QRegExp::Wildcard));
     s.remove(QRegExp("\\p{*}", Qt::CaseInsensitive, QRegExp::Wildcard));
 
+	QString ltag[] = {"<b>","<i>","<u>","<sup>","<sub>"};
+	QString rtag[] = {"</b>","</i>","</u>","</sup>","</sub>"};
+	for (int i = 0; i < 5; i++){//remove special tags if they are not paired
+		if (s.count(ltag[i]) != s.count(rtag[i]))
+			s.remove(QRegExp(ltag[i])).remove(QRegExp(rtag[i]));
+	}
+
 	QString aux = str;
     while (aux.contains(QRegExp("%(*)", Qt::CaseInsensitive, QRegExp::Wildcard))){//curve name specification
 		int pos = str.indexOf("%(", 0, Qt::CaseInsensitive);
@@ -598,20 +614,21 @@ QString LegendWidget::parse(const QString& str)
 			PlotCurve *c = getCurve(lst[0], point);
 			if (c){
 				Table *t = 0;
+				QString colLabel;
+				int ycol = -1;
 				if (c->type() == Graph::Function || c->type() == Graph::Histogram)
 					s = s.replace(pos, pos2 - pos + 1, c->title().text());
-				else
+				else {
 					t = ((DataCurve *)c)->table();
+					ycol = t->colIndex(c->title().text());
+					colLabel = t->colLabel(ycol);
+				}
 
 				if (t){
 					switch(lcmd){
-						case -1: //use table comment if not empty else use curve title
+						case -1: //use column name
 						{
-							QString comment = t->comment(t->colIndex(c->title().text()));
-							if (!comment.isEmpty())
-								s = s.replace(pos, pos2-pos+1, comment.replace("\n", " "));
-							else
-								s = s.replace(pos, pos2-pos+1, c->title().text());
+							s = s.replace(pos, pos2-pos+1, colLabel);
 							break;
 						}
 						case 0: //use curve title
@@ -621,8 +638,8 @@ QString LegendWidget::parse(const QString& str)
 						}
 						case 1: //use col label
 						{
-							int ycol = t->colIndex(c->title().text());
-							if (ycol >= 0) s = s.replace(pos, pos2-pos+1, ((DataCurve *)c)->table()->colLabel(ycol));
+							if (ycol >= 0)
+								s = s.replace(pos, pos2-pos+1, colLabel);
 							break;
 						}
 						case 2: //use table name
@@ -639,15 +656,13 @@ QString LegendWidget::parse(const QString& str)
 							switch (lst.count()){
 								case 2: //2 arguments
 								{
-									int ycol = t->colIndex(c->title().text());
 									s = s.replace(pos, pos2-pos+1, t->comment(ycol));
 									break;
 								}
 								case 3:  //3 arguments, display cell contents
 								{
-									int col = t->colIndex(c->title().text()); //use y column
 									int row = lst[2].toInt() - 1;
-									s = s.replace(pos, pos2-pos+1, t->text(((DataCurve *)c)->tableRow(row), col));
+									s = s.replace(pos, pos2-pos+1, t->text(((DataCurve *)c)->tableRow(row), ycol));
 									break;
 								}
 								case 4:  //4 arguments, display cell contents
@@ -674,12 +689,14 @@ QString LegendWidget::parse(const QString& str)
 		}
     }
 
+#ifdef TEX_OUTPUT
 	if (plot()->isExportingTeX()){
 		if (!d_tex_output && plot()->escapeTeXStrings())
 			s = Graph::escapeTeXSpecialCharacters(s);
 
 		s = Graph::texSuperscripts(s);
 	}
+#endif
 
     return s;
 }
@@ -690,13 +707,13 @@ PlotCurve* LegendWidget::getCurve(const QString& s, int &point)
 	PlotCurve *curve = 0;
 
 	QStringList l = s.split(",");
-    if (l.count() == 2)
+	if (l.count() == 2)
 		point = l[1].toInt() - 1;
 
 	if (!l.isEmpty()){
 		l = l[0].split(".");
-    	if (l.count() == 2){
-    		int cv = l[1].toInt() - 1;
+		if (l.count() == 2){
+			int cv = l[1].toInt() - 1;
 			Graph *layer = d_plot->multiLayer()->layer(l[0].toInt());
 			if (layer && cv >= 0 && cv < layer->curveCount())
 				return (PlotCurve*)layer->curve(cv);
@@ -847,7 +864,7 @@ QSize LegendWidget::textSize(QPainter *p, const QwtText& text)
 			int width = size.width() + QFontMetrics(text.font(), p->device()).boundingRect(" ").width();
 			size =  QSize(width, size.height());
 		} else
-			size = QFontMetrics(text.font(), p->device()).boundingRect(s + " ").size();
+			size = QFontMetrics(text.font(), p->device()).boundingRect(s + "  ").size();
 	}
 	return size;
 }
