@@ -47,13 +47,17 @@
 #include <QLabel>
 #include <QGroupBox>
 #include <QSpinBox>
+#if QT_VERSION >= 0x040500
 #include <QTextDocumentWriter>
-
-#ifdef EMF_OUTPUT
-	#include <EmfEngine.h>
 #endif
 
-#include <QTeXEngine.h>
+#ifdef TEX_OUTPUT
+	#include <QTeXEngine.h>
+#endif
+
+#ifdef Q_OS_WIN
+	#include <windows.h>
+#endif
 
 #include <qwt_plot.h>
 #include <qwt_plot_canvas.h>
@@ -71,6 +75,7 @@
 #include <Matrix.h>
 #include <ColorButton.h>
 #include <ScaleEngine.h>
+#include <ImportExportPlugin.h>
 
 #include <gsl/gsl_vector.h>
 
@@ -88,8 +93,11 @@ LayerButton::LayerButton(const QString& text, QWidget* parent)
 
 void LayerButton::mousePressEvent( QMouseEvent *event )
 {
-	if (event->button() == Qt::LeftButton && !isOn())
+	if (!isOn())
 		emit clicked(this);
+
+	if (event->button() == Qt::RightButton && isOn())
+		showLayerContextMenu();
 }
 
 void LayerButton::mouseDoubleClickEvent ( QMouseEvent * )
@@ -129,6 +137,8 @@ d_size_policy(UserSize),
 d_link_x_axes(false),
 d_common_axes_layout(false)
 {
+	d_layer_coordinates.resize(0);
+
 	layerButtonsBox = new QHBoxLayout();
 	waterfallBox = new QHBoxLayout();
 	toolbuttonsBox = new QHBoxLayout();
@@ -208,6 +218,9 @@ LayerButton* MultiLayer::addLayerButton()
 	LayerButton *button = new LayerButton(QString::number(graphsList.size() + 1));
 	connect (button, SIGNAL(clicked(LayerButton*)), this, SLOT(activateGraph(LayerButton*)));
 	connect (button, SIGNAL(showCurvesDialog()), this, SIGNAL(showCurvesDialog()));
+	ApplicationWindow *app = applicationWindow();
+	if (app)
+		connect(button, SIGNAL(showLayerContextMenu()), app, SLOT(showWindowContextMenu()));
 
 	buttonsList.append(button);
     layerButtonsBox->addWidget(button);
@@ -270,27 +283,71 @@ void MultiLayer::activateGraph(LayerButton* button)
 	}
 }
 
+bool MultiLayer::isLayerSelected(Graph* g)
+{
+	if (!g || !d_layers_selector)
+		return false;
+
+	return d_layers_selector.data()->contains(g->canvas());
+}
+
+//! Try to guess on which layer the user clicked if the layers are superposed
+Graph* MultiLayer::clickedLayer(Graph* g)
+{
+	if (!g)
+		return 0;
+
+	QRect ar = g->frameGeometry();
+	foreach (Graph *gr, graphsList){
+		if (gr == g)
+			continue;
+
+		QPoint pos = gr->mapFromGlobal(QCursor::pos());
+		if (ar.contains(gr->frameGeometry()) && gr->rect().contains(pos)){
+			return gr;
+		}
+	}
+
+	return g;
+}
+
+void MultiLayer::selectLayerCanvas(Graph* g)
+{
+	setActiveLayer(g);
+
+	if (active_graph && active_graph != g){
+		QMouseEvent e(QEvent::MouseButtonPress, QCursor::pos(), Qt::LeftButton, 0, 0);
+		if (!active_graph->mousePressed(&e)){
+			d_layers_selector = new SelectionMoveResizer(active_graph->canvas());
+			connect(d_layers_selector, SIGNAL(targetsChanged()), this, SIGNAL(modifiedPlot()));
+		}
+	} else {
+		d_layers_selector = new SelectionMoveResizer(g->canvas());
+		connect(d_layers_selector, SIGNAL(targetsChanged()), this, SIGNAL(modifiedPlot()));
+	}
+}
+
 void MultiLayer::setActiveLayer(Graph* g)
 {
-	if (!g || active_graph == g)
+	Graph *ag = clickedLayer(g);
+	if (!ag || active_graph == ag)
 		return;
 
-	active_graph = g;
+	active_graph = ag;
 	active_graph->setFocus();
 
-	if (d_layers_selector)
-		delete d_layers_selector;
+	deselect();
 
 	if (!d_is_waterfall_plot)
 		active_graph->raise();//raise layer on top of the layers stack
 	active_graph->raiseEnrichements();
 
-	for(int i=0; i<graphsList.count(); i++){
+	for(int i = 0; i < graphsList.count(); i++){
 		Graph *gr = (Graph *)graphsList.at(i);
 		gr->deselect();
 
 		LayerButton *btn = (LayerButton *)buttonsList.at(i);
-		if (gr == g)
+		if (gr == ag)
 			btn->setOn(true);
 		else
 			btn->setOn(false);
@@ -308,8 +365,9 @@ QRect MultiLayer::canvasChildrenRect()
 
 void MultiLayer::resizeLayers (QResizeEvent *re)
 {
-	if (!d_scale_layers || applicationWindow()->d_opening_file){
-		emit modifiedPlot();
+	if (!d_scale_layers || applicationWindow()->d_opening_file || graphsList.isEmpty()){
+		if (!applicationWindow()->d_opening_file)
+			emit modifiedPlot();
 		return;
 	}
 
@@ -319,7 +377,8 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 	if (size.height() <= 0)
 		size.setHeight(oldSize.height());
 
-	if(!oldSize.isValid()){// The old size is invalid when maximizing a window (why?)
+	bool invalidOldSize = !oldSize.isValid();
+	if (invalidOldSize){// The old size is invalid when maximizing a window (why?)
 		if (d_canvas_size.isValid())
 			oldSize = d_canvas_size;
 		else {
@@ -331,9 +390,7 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 	double w_ratio = (double)size.width()/(double)oldSize.width();
 	double h_ratio = (double)(size.height())/(double)(oldSize.height());
 
-	if (d_common_axes_layout)
-		arrangeLayers(false, false);
-	else {
+	if (isWaterfallPlot()){
 		foreach (Graph *g, graphsList){
 			int gx = qRound(g->x()*w_ratio);
 			int gy = qRound(g->y()*h_ratio);
@@ -341,11 +398,72 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 			int gh = qRound(g->height()*h_ratio);
 			g->setGeometry(gx, gy, gw, gh);
 		}
+		foreach (Graph *g, graphsList){
+			if (g->autoscaleFonts())
+				g->scaleFonts(h_ratio);
+		}
+		emit modifiedPlot();
+		return;
 	}
 
-	foreach (Graph *g, graphsList){
-		if (g->autoscaleFonts())
-			g->scaleFonts(h_ratio);
+	if (d_common_axes_layout && !invalidOldSize){
+		arrangeLayers(false, false);
+		foreach (Graph *g, graphsList){
+			if (g->autoscaleFonts())
+				g->scaleFonts(h_ratio);
+		}
+	} else {
+		Graph *g0 = graphsList[0];
+		int l = graphsList.size();
+		if (d_layer_coordinates.size() == 0){
+			d_layer_coordinates.resize(l);
+
+			QPoint oPos = g0->pos() + g0->canvas()->pos();
+			for(int i = 1; i < l; i++){
+				Graph *g = graphsList[i];
+				if (!g)
+					continue;
+
+				QwtPlotCanvas *canvas = g->canvas();
+				QPoint pos = g->pos() + canvas->pos() - oPos;
+
+				double xl = g0->invTransform(QwtPlot::xBottom, pos.x());
+				double yt = g0->invTransform(QwtPlot::yLeft, pos.y());
+				double xr = g0->invTransform(QwtPlot::xBottom, pos.x() + canvas->width() - 1);
+				double yb = g0->invTransform(QwtPlot::yLeft, pos.y() + canvas->height() - 1);
+
+				d_layer_coordinates[i] = QRectF(QPointF(xl, yt), QPointF(xr, yb));
+			}
+		}
+
+		QwtPlotCanvas *canvas0 = g0->canvas();
+		g0->setGeometry(qRound(g0->x()*w_ratio), qRound(g0->y()*h_ratio),
+						qRound(g0->width()*w_ratio), qRound(g0->height()*h_ratio));
+
+		if (g0->autoscaleFonts())
+			g0->scaleFonts(h_ratio);
+		g0->updateLayout();
+
+		for(int i = 1; i < l; i++){
+			Graph *g = graphsList[i];
+			if (!g)
+				continue;
+
+			QRectF r = d_layer_coordinates[i];
+
+			int xl = g0->transform(QwtPlot::xBottom, r.left());
+			int yt = g0->transform(QwtPlot::yLeft, r.top());
+			int xr = g0->transform(QwtPlot::xBottom, r.right());
+			int yb = g0->transform(QwtPlot::yLeft, r.bottom());
+
+			QPoint tl = canvas0->mapTo(d_canvas, QPoint(xl, yt));
+			QPoint br = canvas0->mapTo(d_canvas, QPoint(xr, yb));
+
+			if (g->autoscaleFonts())
+				g->scaleFonts(h_ratio);
+
+			g->setCanvasGeometry(QRect(tl, br));
+		}
 	}
 
 	emit modifiedPlot();
@@ -653,6 +771,8 @@ QSize MultiLayer::arrangeLayers(bool userSize)
 
 void MultiLayer::setCommonLayerAxes(bool verticalAxis, bool horizontalAxis)
 {
+	d_common_axes_layout = true;
+
 	int layers = graphsList.size();
 	for (int i=0; i<layers; i++){
 		int row = i / d_cols;
@@ -881,17 +1001,17 @@ void MultiLayer::exportToFile(const QString& fileName)
 	} else if(fileName.contains(".svg")){
 		exportSVG(fileName);
 		return;
-	} else if(fileName.contains(".tex")){
+	}
+#ifdef TEX_OUTPUT
+	else if(fileName.contains(".tex")){
 		exportTeX(fileName);
 		return;
 	}
-#ifdef EMF_OUTPUT
+#endif
 	 else if(fileName.contains(".emf")){
 		exportEMF(fileName);
 		return;
-	}
-#endif
-	 else {
+	} else {
 		QList<QByteArray> list = QImageWriter::supportedImageFormats();
     	for(int i=0 ; i<list.count() ; i++){
 			if (fileName.contains( "." + list[i].toLower())){
@@ -918,6 +1038,7 @@ void MultiLayer::exportImage(const QString& fileName, int quality, bool transpar
 	int dpm = (int)ceil(100.0/2.54*dpi);
 	image.setDotsPerMeterX(dpm);
 	image.setDotsPerMeterY(dpm);
+#if QT_VERSION >= 0x040500
 	if (fileName.endsWith(".odf")){
 		QTextDocument *document = new QTextDocument();
 		QTextCursor cursor = QTextCursor(document);
@@ -929,9 +1050,11 @@ void MultiLayer::exportImage(const QString& fileName, int quality, bool transpar
 		QTextDocumentWriter writer(fileName);
 		writer.write(document);
 	} else
+#endif
 		image.save(fileName, 0, quality);
 }
 
+#if QT_VERSION >= 0x040500
 void MultiLayer::exportImage(QTextDocument *document, int, bool transparent,
 				int dpi, const QSizeF& customSize, int unit, double fontsFactor)
 {
@@ -978,6 +1101,7 @@ void MultiLayer::exportImage(QTextDocument *document, int, bool transparent,
 	cursor.insertBlock();
 	cursor.insertImage(image);
 }
+#endif
 
 void MultiLayer::exportPDF(const QString& fname)
 {
@@ -988,9 +1112,8 @@ void MultiLayer::exportVector(const QString& fileName, int res, bool color,
 				const QSizeF& customSize, int unit, double fontsFactor)
 {
 	if ( fileName.isEmpty() ){
-		QMessageBox::critical(this, tr("QtiPlot - Error"),
-		tr("Please provide a valid file name!"));
-        return;
+		QMessageBox::critical(this, tr("QtiPlot - Error"), tr("Please provide a valid file name!"));
+		return;
 	}
 
 	QPrinter printer;
@@ -1106,21 +1229,19 @@ void MultiLayer::exportSVG(const QString& fname, const QSizeF& customSize, int u
 	draw(&svg, customSize, unit, res, fontsFactor);
 }
 
-#ifdef EMF_OUTPUT
 void MultiLayer::exportEMF(const QString& fname, const QSizeF& customSize, int unit, double fontsFactor)
 {
-	int res = logicalDpiX();
-	QSize size = d_canvas->size();
-	if (customSize.isValid())
-		size = Graph::customPrintSize(customSize, unit, res);
-
-	EmfPaintDevice emf(size, fname);
-	draw(&emf, customSize, unit, res, fontsFactor);
+	if (!applicationWindow())
+		return;
+	ImportExportPlugin *ep = applicationWindow()->exportPlugin("emf");
+	if (!ep)
+		return;
+	ep->exportMultiLayerPlot(this, fname, customSize, unit, fontsFactor);
 }
-#endif
 
 void MultiLayer::exportTeX(const QString& fname, bool color, bool escapeStrings, bool fontSizes, const QSizeF& customSize, int unit, double fontsFactor)
 {
+#ifdef TEX_OUTPUT
 	int res = logicalDpiX();
 	QSize size = d_canvas->size();
 	if (customSize.isValid())
@@ -1144,6 +1265,7 @@ void MultiLayer::exportTeX(const QString& fname, bool color, bool escapeStrings,
 
 	foreach (Graph* g, graphsList)
 		g->setTeXExportingMode(false);
+#endif
 }
 
 void MultiLayer::copyAllLayers()
@@ -1158,24 +1280,20 @@ void MultiLayer::copyAllLayers()
 		g->deselectMarker();
 
 #ifdef Q_OS_WIN
-	#ifdef EMF_OUTPUT
-		if (OpenClipboard(0)){
-			EmptyClipboard();
+	if (OpenClipboard(0)){
+		EmptyClipboard();
 
-			QString path = QDir::tempPath();
-			QString name = path + "/" + "qtiplot_clipboard.emf";
-			name = QDir::cleanPath(name);
+		QString path = QDir::tempPath();
+		QString name = path + "/" + "qtiplot_clipboard.emf";
+		name = QDir::cleanPath(name);
 
-			exportEMF(name);
-			HENHMETAFILE handle = GetEnhMetaFile(name.toStdWString().c_str());
+		exportEMF(name);
+		HENHMETAFILE handle = GetEnhMetaFile(name.toStdWString().c_str());
 
-			SetClipboardData(CF_ENHMETAFILE, handle);
-			CloseClipboard();
-			QFile::remove(name);
-		}
-	#else
-		QApplication::clipboard()->setImage(canvasPixmap().convertToImage());
-	#endif
+		SetClipboardData(CF_ENHMETAFILE, handle);
+		CloseClipboard();
+		QFile::remove(name);
+	}
 #else
 	QApplication::clipboard()->setImage(canvasPixmap().convertToImage());
 #endif
@@ -1338,7 +1456,9 @@ void MultiLayer::connectLayer(Graph *g)
 	connect (g,SIGNAL(modifiedGraph()),this,SIGNAL(modifiedPlot()));
 	connect (g,SIGNAL(modifiedGraph()),this,SLOT(notifyChanges()));
 	connect (g,SIGNAL(selectedGraph(Graph*)),this, SLOT(setActiveLayer(Graph*)));
+	connect (g,SIGNAL(selectedCanvas(Graph*)), this, SLOT(selectLayerCanvas(Graph*)));
 	connect (g,SIGNAL(currentFontChanged(const QFont&)), this, SIGNAL(currentFontChanged(const QFont&)));
+	connect (g,SIGNAL(currentColorChanged(const QColor&)), this, SIGNAL(currentColorChanged(const QColor&)));
 	if (d_link_x_axes)
 		connect(g, SIGNAL(axisDivChanged(Graph *, int)), this, SLOT(updateLayerAxes(Graph *, int)));
 }
@@ -1351,51 +1471,62 @@ bool MultiLayer::eventFilter(QObject *object, QEvent *e)
 		d_canvas->setUpdatesEnabled(true);
 		d_canvas_size = d_canvas->size();
 	} else if (e->type() == QEvent::MouseButtonPress && object == (QObject *)d_canvas){
-	    const QMouseEvent *me = (const QMouseEvent *)e;
-		if (me->button() == Qt::RightButton || me->button() == Qt::MidButton)
-            return QMdiSubWindow::eventFilter(object, e);
+		const QMouseEvent *me = (const QMouseEvent *)e;
+		if (me->button() == Qt::RightButton && applicationWindow()){
+			applicationWindow()->showWindowContextMenu();
+			return true;
+		} else if (me->button() == Qt::MidButton)
+			return QMdiSubWindow::eventFilter(object, e);
 
 		if (d_is_waterfall_plot)
 			return true;
 
-		QPoint pos = d_canvas->mapFromParent(me->pos());
-        // iterate backwards, so layers on top are preferred for selection
-        QList<Graph*>::iterator i = graphsList.end();
+		QPoint pos = d_canvas->mapFromGlobal(me->globalPos());
+		// iterate backwards, so layers on top are preferred for selection
+		QList<Graph*>::iterator i = graphsList.end();
 		while (i != graphsList.begin()){
-            --i;
-            Graph *g = *i;
+			--i;
+			Graph *g = *i;
 			if (g->hasSeletedItems()){
 				g->deselect();
-                return true;
+				return true;
 			}
 
-            QRect igeo = (*i)->frameGeometry();
-            if (igeo.contains(pos)) {
-                if (me->modifiers() & Qt::ShiftModifier) {
-                    if (d_layers_selector)
-                        d_layers_selector->add((*i)->canvas());
-                    else {
-                        d_layers_selector = new SelectionMoveResizer((*i)->canvas());
-                        connect(d_layers_selector, SIGNAL(targetsChanged()), this, SIGNAL(modifiedPlot()));
-                    }
-                } else {
-                    setActiveLayer(g);
-                    active_graph->raise();
-                    if (!d_layers_selector) {
-                        d_layers_selector = new SelectionMoveResizer((*i)->canvas());
-                        connect(d_layers_selector, SIGNAL(targetsChanged()), this, SIGNAL(modifiedPlot()));
-                    }
-                }
-                return true;
-            }
-        }
-        if (d_layers_selector)
-            delete d_layers_selector;
+			QRect igeo = g->frameGeometry();
+			if (igeo.contains(pos)){
+				if (me->modifiers() & Qt::ShiftModifier){
+					if (d_layers_selector)
+						d_layers_selector->add((*i)->canvas());
+					else {
+						d_layers_selector = new SelectionMoveResizer(g->canvas());
+						connect(d_layers_selector, SIGNAL(targetsChanged()), this, SIGNAL(modifiedPlot()));
+					}
+				} else {
+					setActiveLayer(g);
+					if (!g->mousePressed(e) && !d_layers_selector){
+						d_layers_selector = new SelectionMoveResizer(g->canvas());
+						connect(d_layers_selector, SIGNAL(targetsChanged()), this, SIGNAL(modifiedPlot()));
+					}
+				}
+				return true;
+			}
+		}
+		deselect();
+	} else if (e->type() == QEvent::MouseButtonDblClick && object == (QObject *)d_canvas){
+		if (applicationWindow())
+			applicationWindow()->showPlotDialog(-100);
+		return true;
 	}
 
 	return MdiSubWindow::eventFilter(object, e);
 }
 
+void MultiLayer::mouseReleaseEvent( QMouseEvent * e)
+{
+	d_layer_coordinates.resize(0);
+	return QMdiSubWindow::mouseReleaseEvent(e);
+}
+
 void MultiLayer::keyPressEvent(QKeyEvent * e)
 {
 	if (e->key() == Qt::Key_Escape){
@@ -1421,8 +1552,7 @@ void MultiLayer::keyPressEvent(QKeyEvent * e)
 	}
 
 	if (e->key() == Qt::Key_F10){
-		if (d_layers_selector)
-			delete d_layers_selector;
+		deselect();
 		int index = graphsList.indexOf(active_graph) - 1;
 		if (index < 0)
 			index = graphsList.size() - 1;
@@ -1432,8 +1562,8 @@ void MultiLayer::keyPressEvent(QKeyEvent * e)
 		return;
 	}
 
-	if (e->key() == Qt::Key_F11){
-		emit showContextMenu();
+	if (e->key() == Qt::Key_F11 && applicationWindow()){
+		applicationWindow()->showWindowContextMenu();
 		return;
 	}
 }
@@ -1534,6 +1664,7 @@ void MultiLayer::save(const QString &fn, const QString &geometry, bool saveAsTem
 	}
 
 	t << "<LinkXAxes>" + QString::number(d_link_x_axes) + "</LinkXAxes>\n";
+	t << "<ScaleLayers>" + QString::number(d_scale_layers) + "</ScaleLayers>\n";
 	t << "</multiLayer>\n";
 }
 
@@ -1624,13 +1755,13 @@ void MultiLayer::setNumLayers(int n)
 void MultiLayer::copy(MultiLayer* ml)
 {
     resize(ml->size());
+	hide();
 
 	setSpacing(ml->rowsSpacing(), ml->colsSpacing());
 	setAlignement(ml->horizontalAlignement(), ml->verticalAlignement());
 	setMargins(ml->leftMargin(), ml->rightMargin(), ml->topMargin(), ml->bottomMargin());
 	d_size_policy = ml->sizePolicy();
 	d_align_policy = ml->alignPolicy();
-
 	d_scale_on_print = ml->scaleLayersOnPrint();
 	d_print_cropmarks = ml->printCropmarksEnabled();
 
@@ -1647,10 +1778,13 @@ void MultiLayer::copy(MultiLayer* ml)
 		d_waterfall_offset_y = ml->waterfallYOffset();
 		createWaterfallBox();
 		setWaterfallSideLines(ml->sideLinesEnabled());
+		updateWaterfallLayout();
 	}
 
 	d_scale_layers = ml->scaleLayersOnResize();
 	linkXLayerAxes(ml->hasLinkedXLayerAxes());
+	d_common_axes_layout = ml->hasCommonAxes();
+	show();
 }
 
 bool MultiLayer::swapLayers(int src, int dest)
@@ -2173,6 +2307,14 @@ void MultiLayer::updateLayerAxes(Graph *g, int axis)
 	int minorTicks = g->axisMaxMinor(axis);
 	double step = g->axisStep(axis);
 
+	int oppositeAxis = Graph::xTop;
+	if (axis == Graph::xTop)
+		oppositeAxis = Graph::xBottom;
+
+	bool synchronizeScales = true;
+	if (this->applicationWindow())
+		synchronizeScales = this->applicationWindow()->d_synchronize_graph_scales;
+
 	foreach(Graph *l, graphsList){
 		if (l == g)
 			continue;
@@ -2183,9 +2325,28 @@ void MultiLayer::updateLayerAxes(Graph *g, int axis)
 					se->axisBreakLeft(), se->axisBreakRight(), se->breakPosition(),
 					se->stepBeforeBreak(), se->stepAfterBreak(), se->minTicksBeforeBreak(),
 					se->minTicksAfterBreak(), se->log10ScaleAfterBreak(), se->breakWidth(), se->hasBreakDecoration());
+		if (synchronizeScales){
+			l->setScale(oppositeAxis, sd->lowerBound(), sd->upperBound(), step, majorTicks, minorTicks,
+					se->type(), se->testAttribute(QwtScaleEngine::Inverted),
+					se->axisBreakLeft(), se->axisBreakRight(), se->breakPosition(),
+					se->stepBeforeBreak(), se->stepAfterBreak(), se->minTicksBeforeBreak(),
+					se->minTicksAfterBreak(), se->log10ScaleAfterBreak(), se->breakWidth(), se->hasBreakDecoration());
+		}
+
 		l->replot();
 		l->blockSignals(false);
 	}
+
+	if (synchronizeScales){
+		g->blockSignals(true);
+		g->setScale(oppositeAxis, sd->lowerBound(), sd->upperBound(), step, majorTicks, minorTicks,
+				se->type(), se->testAttribute(QwtScaleEngine::Inverted),
+				se->axisBreakLeft(), se->axisBreakRight(), se->breakPosition(),
+				se->stepBeforeBreak(), se->stepAfterBreak(), se->minTicksBeforeBreak(),
+				se->minTicksAfterBreak(), se->log10ScaleAfterBreak(), se->breakWidth(), se->hasBreakDecoration());
+		g->blockSignals(false);
+		g->replot();
+	}
 }
 
 void MultiLayer::updateLayersLayout(Graph *g)
@@ -2201,10 +2362,15 @@ void MultiLayer::updateLayersLayout(Graph *g)
 	}
 }
 
-MultiLayer::~MultiLayer()
+void MultiLayer::deselect()
 {
 	if(d_layers_selector)
-		d_layers_selector->setParent(NULL);
+		delete d_layers_selector;
+}
+
+MultiLayer::~MultiLayer()
+{
+	deselect();
 
 	foreach(Graph *g, graphsList)
 		delete g;
