@@ -122,7 +122,11 @@ public:
 	void linkXLayerAxes(bool link = true);
 	bool hasLinkedXLayerAxes(){return d_link_x_axes;};
 	bool hasCommonAxes(){return d_common_axes_layout;};
-	void setCommonAxesLayout(bool on){d_common_axes_layout = on;};
+	void setCommonAxesLayout(bool on = true){d_common_axes_layout = on;};
+
+	void deselect();
+	bool hasSelectedLayers();
+	bool isLayerSelected(Graph*);
 
 public slots:
 	Graph* addLayer(int x = 0, int y = 0, int width = 0, int height = 0, bool = false);
@@ -135,6 +139,7 @@ public slots:
 	Graph* activeLayer(){return active_graph;};
 	void setActiveLayer(Graph* g);
 	void activateGraph(LayerButton* button);
+	void selectLayerCanvas(Graph* g);
 
     //! Returns the layer at the given position; returns 0 if there is no such layer.
 	Graph* layerAt(const QPoint& pos);
@@ -175,8 +180,10 @@ public slots:
 	//@{
 	QPixmap canvasPixmap(const QSize& size = QSize(), double scaleFontsFactor = 1.0, bool transparent = false);
 	void exportToFile(const QString& fileName);
+#if QT_VERSION >= 0x040500
 	void exportImage(QTextDocument *document, int quality = 100, bool transparent = false,
 		int dpi = 0, const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
+#endif
 	void exportImage(const QString& fileName, int quality = 100, bool transparent = false,
 		int dpi = 0, const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
 	void exportSVG(const QString& fname, const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
@@ -186,9 +193,7 @@ public slots:
 
 	void draw(QPaintDevice *, const QSizeF& customSize, int unit, int res, double fontsFactor = 1.0);
 
-#ifdef EMF_OUTPUT
 	void exportEMF(const QString& fname, const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
-#endif
 	void exportTeX(const QString& fname, bool color = true, bool escapeStrings = true, bool fontSizes = true,
 					const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
 
@@ -206,8 +211,6 @@ public slots:
 
 	void save(const QString& fn, const QString& geometry, bool = false);
 
-    bool hasSelectedLayers();
-
     //! \name Waterfall Plots
 	//@{
     void showWaterfallOffsetDialog();
@@ -235,10 +238,12 @@ signals:
 	void pasteMarker();
 	void setPointerCursor();
 	void currentFontChanged(const QFont&);
+	void currentColorChanged(const QColor&);
 
 private:
 	//! \name Event Handlers
 	//@{
+	void mouseReleaseEvent(QMouseEvent *);
 	void dropEvent(QDropEvent*);
 	void dragEnterEvent(QDragEnterEvent*);
 	void wheelEvent(QWheelEvent *);
@@ -246,6 +251,8 @@ private:
 	bool eventFilter(QObject *object, QEvent *);
 	void releaseLayer();
 	void resizeLayers(QResizeEvent *);
+	//! Try to guess on which layer the user clicked if the layers are superposed
+	Graph* clickedLayer(Graph*);
 	//@}
 
 	LayerButton* addLayerButton();
@@ -280,6 +287,8 @@ private:
 	SizePolicy d_size_policy;
 	bool d_link_x_axes;
 	bool d_common_axes_layout;
+
+	QVector<QRectF> d_layer_coordinates;
 };
 
 //! Button with layer number
@@ -298,6 +307,7 @@ protected:
 signals:
 	void showCurvesDialog();
 	void clicked(LayerButton*);
+	void showLayerContextMenu();
 };
 
 #endif
