@@ -27,15 +27,19 @@
  *                                                                         *
  ***************************************************************************/
 #include "PlotCurve.h"
+#include "ErrorBarsCurve.h"
+#include "BoxCurve.h"
 #include "Graph.h"
 #include "ScaleDraw.h"
 #include "ScaleEngine.h"
-
 #include <SymbolBox.h>
 #include <PatternBox.h>
+#include <ImageSymbol.h>
 
 #include <QDateTime>
 #include <QPainter>
+#include <QBuffer>
+
 #include <qwt_symbol.h>
 #include <qwt_painter.h>
 #include <qwt_curve_fitter.h>
@@ -88,6 +92,28 @@ QwtDoubleRect PlotCurve::boundingRect() const
 	return r;
 }
 
+QString PlotCurve::saveCurveSymbolImage()
+{
+	if (symbol().style() != QwtSymbol::Image)
+		return QString();
+
+	ImageSymbol *is = (ImageSymbol *)(&symbol());
+	if (!is)
+		return QString();
+
+	QString s = "<SymbolImage>\n";
+	s += "<path>" + is->imagePath() + "</path>\n";
+	s += "<xpm>\n";
+	QByteArray bytes;
+	QBuffer buffer(&bytes);
+	buffer.open(QIODevice::WriteOnly);
+	is->pixmap().save(&buffer, "XPM");
+	s += QString(bytes);
+	s += "</xpm>\n";
+
+	return s + "</SymbolImage>\n";
+}
+
 QString PlotCurve::saveCurveLayout()
 {
 	QString s = "<Style>" + QString::number(d_plot_style) + "</Style>\n";
@@ -102,6 +128,8 @@ QString PlotCurve::saveCurveLayout()
 	if (pen.style() != Qt::NoPen){
 		s += "<Pen>\n";
 		s += "\t<Color>" + pen.color().name() + "</Color>\n";
+		if (pen.color().alpha() != 255)
+			s += "\t<Alpha>" + QString::number(pen.color().alpha()) + "</Alpha>\n";
 		s += "\t<Style>" + QString::number(pen.style()-1) + "</Style>\n";
 		s += "\t<Width>" + QString::number(pen.widthF()) + "</Width>\n";
 		s += "</Pen>\n";
@@ -111,7 +139,8 @@ QString PlotCurve::saveCurveLayout()
 	if (brush.style() != Qt::NoBrush){
 		s += "<Brush>\n";
 		s += "\t<Color>" + brush.color().name() + "</Color>\n";
-		s += "\t<Alpha>" + QString::number(brush.color().alpha()) + "</Alpha>\n";
+		if (brush.color().alpha() != 255)
+			s += "\t<Alpha>" + QString::number(brush.color().alpha()) + "</Alpha>\n";
 		s += "\t<Style>" + QString::number(PatternBox::patternIndex(brush.style())) + "</Style>\n";
 		s += "</Brush>\n";
 	}
@@ -124,6 +153,8 @@ QString PlotCurve::saveCurveLayout()
 
 		s += "\t<SymbolPen>\n";
 		s += "\t\t<Color>" + symbol.pen().color().name() + "</Color>\n";
+		if (symbol.pen().color().alpha() != 255)
+			s += "\t<Alpha>" + QString::number(symbol.pen().color().alpha()) + "</Alpha>\n";
 		s += "\t\t<Width>" + QString::number(symbol.pen().widthF()) + "</Width>\n";
 		s += "\t</SymbolPen>\n";
 
@@ -131,6 +162,8 @@ QString PlotCurve::saveCurveLayout()
 		if (brush.style() != Qt::NoBrush){
 			s += "\t<SymbolBrush>\n";
 			s += "\t\t<Color>" + symbol.brush().color().name() + "</Color>\n";
+			if (symbol.brush().color().alpha() != 255)
+				s += "\t<Alpha>" + QString::number(symbol.brush().color().alpha()) + "</Alpha>\n";
 			s += "\t\t<Style>" + QString::number(PatternBox::patternIndex(symbol.brush().style())) + "</Style>\n";
 			s += "\t</SymbolBrush>\n";
 		}
@@ -155,7 +188,11 @@ void PlotCurve::restoreCurveLayout(const QStringList& lst)
 				s = (*(++line)).stripWhiteSpace();
 				if (s.contains("<Color>"))
 					pen.setColor(QColor(s.remove("<Color>").remove("</Color>")));
-				else if (s.contains("<Style>"))
+				else if (s.contains("<Alpha>")){
+					QColor c = pen.color();
+					c.setAlpha(s.remove("<Alpha>").remove("</Alpha>").toInt());
+					pen.setColor(c);
+				} else if (s.contains("<Style>"))
 					pen.setStyle(Graph::getPenStyle(s.remove("<Style>").remove("</Style>").toInt()));
 				else if (s.contains("<Width>"))
 					pen.setWidthF(s.remove("<Width>").remove("</Width>").toDouble());
@@ -189,7 +226,11 @@ void PlotCurve::restoreCurveLayout(const QStringList& lst)
 						s = (*(++line)).stripWhiteSpace();
 						if (s.contains("<Color>"))
 							pen.setColor(QColor(s.remove("<Color>").remove("</Color>")));
-						else if (s.contains("<Style>"))
+						else if (s.contains("<Alpha>")){
+							QColor c = pen.color();
+							c.setAlpha(s.remove("<Alpha>").remove("</Alpha>").toInt());
+							pen.setColor(c);
+						} else if (s.contains("<Style>"))
 							pen.setStyle(Graph::getPenStyle(s.remove("<Style>").remove("</Style>").toInt()));
 						else if (s.contains("<Width>"))
 							pen.setWidthF(s.remove("<Width>").remove("</Width>").toDouble());
@@ -202,7 +243,11 @@ void PlotCurve::restoreCurveLayout(const QStringList& lst)
 						s = (*(++line)).stripWhiteSpace();
 						if (s.contains("<Color>"))
 							brush.setColor(QColor(s.remove("<Color>").remove("</Color>")));
-						else if (s.contains("<Style>"))
+						else if (s.contains("<Alpha>")){
+							QColor c = brush.color();
+							c.setAlpha(s.remove("<Alpha>").remove("</Alpha>").toInt());
+							brush.setColor(c);
+						} else if (s.contains("<Style>"))
 							brush.setStyle(PatternBox::brushStyle(s.remove("<Style>").remove("</Style>").toInt()));
 					}
 					symbol.setBrush(brush);
@@ -331,132 +376,6 @@ void PlotCurve::drawSideLines(QPainter *p, const QwtScaleMap &xMap, const QwtSca
 	p->drawLine(QPointF(xr, yr), QPointF(xr, base));
 
 	p->restore();
-
-	/*int size = to - from + 1;
-    if ( size <= 0 )
-        return;
-
-	size += 2;
-
-	p->save();
-	QPen pen = p->pen();
-	pen.setCapStyle(Qt::FlatCap);
-	pen.setJoinStyle(Qt::MiterJoin);
-	p->setPen(pen);
-
-	const double xl = xMap.xTransform(minXValue());
-	const double xr = xMap.xTransform(maxXValue());
-	const double base = yMap.xTransform(baseline());
-
-    QwtPolygonF polyline;
-    if ( testCurveAttribute(QwtPlotCurve::Fitted) && curveFitter () )
-    {
-        // Transform x and y values to window coordinates
-        // to avoid a distinction between linear and
-        // logarithmic scales.
-
-        QPolygonF points(size);
-        for (int i = from; i <= to; i++)
-        {
-            QwtDoublePoint &p = points[i];
-            p.setX( xMap.xTransform(x(i)) );
-            p.setY( yMap.xTransform(y(i)) );
-        }
-
-        points = curveFitter()->fitCurve(points);
-        size = points.size();
-
-        if ( size == 0 )
-            return;
-
-        // Round QwtDoublePoints to QPoints
-        // When Qwt support for Qt3 has been dropped (Qwt 6.x)
-        // we will use a doubles for painting and the following
-        // step will be obsolete.
-
-        polyline.resize(size);
-
-        const QwtDoublePoint *p = points.data();
-        QPointF *pl = polyline.data();
-        if (testPaintAttribute(QwtPlotCurve::PaintFiltered))
-        {
-
-            QPointF pp(p[0].x(), p[0].y());
-            pl[0] = pp;
-
-            int count = 1;
-            for (int i = 1; i < size; i++)
-            {
-                const QPointF pi(p[i].x(), p[i].y());
-                if ( pi != pp )
-                {
-                    pl[count++] = pi;
-                    pp = pi;
-                }
-            }
-            if ( count != size )
-                polyline.resize(count);
-        }
-        else
-        {
-            for ( int i = 0; i < size; i++ )
-            {
-                pl[i].setX( p[i].x() );
-                pl[i].setY( p[i].y() );
-            }
-        }
-    }
-    else
-    {
-        polyline.resize(size);
-
-        if ( testPaintAttribute(QwtPlotCurve::PaintFiltered) )
-        {
-        	QPointF pp(xl, base);
-            polyline[0] = pp;
-
-            int count = 1;
-            for (int i = from; i <= to; i++)
-            {
-                const QPointF pi(xMap.xTransform(x(i)), yMap.xTransform(y(i)));
-                if ( pi != pp )
-                {
-                    polyline[count] = pi;
-                    count++;
-
-                    pp = pi;
-                }
-            }
-
-            polyline[size - 1] = QPointF(xr, base);
-			count++;
-
-            if ( count != size )
-                polyline.resize(count);
-        }
-        else
-        {
-            polyline[0] = QPointF( xl, base );
-
-            for (int i = from; i <= to; i++)
-            {
-                const QPointF pi(xMap.xTransform(x(i)), yMap.xTransform(y(i)));
-                polyline[i - from + 1] = pi;
-            }
-
-            polyline[size - 1] = QPointF(xr, base);
-        }
-    }
-
-    if ( testPaintAttribute(QwtPlotCurve::ClipPolygons) )
-        polyline = QwtClipper::clipPolygonF(p->window(), polyline);
-
-    QwtPainter::drawPolyline(p, polyline);
-
-    if ( brush().style() != Qt::NoBrush )
-        fillCurve(p, xMap, yMap, polyline);
-
-	p->restore();*/
 }
 
 DataCurve::DataCurve(Table *t, const QString& xColName, const QString& name, int startRow, int endRow):
@@ -470,6 +389,7 @@ DataCurve::DataCurve(Table *t, const QString& xColName, const QString& name, int
 	d_labels_font(QFont()),
 	d_labels_angle(0.0),
 	d_white_out_labels(false),
+	d_show_labels(false),
 	d_labels_align(Qt::AlignHCenter),
 	d_labels_x_offset(0),
 	d_labels_y_offset(50),
@@ -489,7 +409,7 @@ void DataCurve::setRowRange(int startRow, int endRow)
 
 	loadData();
 
-	foreach(DataCurve *c, d_error_bars)
+	foreach(ErrorBarsCurve *c, d_error_bars)
 		c->loadData();
 }
 
@@ -500,7 +420,7 @@ void DataCurve::setFullRange()
 
 	loadData();
 
-	foreach(DataCurve *c, d_error_bars)
+	foreach(ErrorBarsCurve *c, d_error_bars)
 		c->loadData();
 }
 
@@ -512,37 +432,40 @@ bool DataCurve::isFullRange()
 		return true;
 }
 
-QString DataCurve::plotAssociation()
+QStringList DataCurve::plotAssociation()
 {
-	QString s = title().text();
-    if (!d_x_column.isEmpty())
-        s = d_x_column + "(X)," + title().text() + "(Y)";
+	QStringList lst = QStringList() << title().text();
+	if (!d_x_column.isEmpty())
+		lst = QStringList() << d_x_column + "(X)" << title().text() + "(Y)";
 
-    if (!d_labels_column.isEmpty())
-        s += "," + d_labels_column + "(L)";
+	if (!d_labels_column.isEmpty())
+		lst << d_labels_column + "(L)";
 
-	return s;
+	return lst;
 }
 
 void DataCurve::updateColumnNames(const QString& oldName, const QString& newName, bool updateTableName)
 {
-    if (updateTableName){
-        QString s = title().text();
-        QStringList lst = s.split("_", QString::SkipEmptyParts);
-        if (lst[0] == oldName)
-            setTitle(newName + "_" + lst[1]);
+	if (updateTableName){
+		QString s = title().text();
+		QStringList lst = s.split("_", QString::SkipEmptyParts);
+		if (lst.size() < 2)
+			return;
 
-        if (!d_x_column.isEmpty()){
-            lst = d_x_column.split("_", QString::SkipEmptyParts);
-            if (lst[0] == oldName)
-                d_x_column = newName + "_" + lst[1];
-        }
-    } else {
-        if (title().text() == oldName)
-            setTitle(newName);
-        if (d_x_column == oldName)
-            d_x_column = newName;
-    }
+		if (lst[0] == oldName)
+			setTitle(newName + "_" + lst[1]);
+
+		if (!d_x_column.isEmpty()){
+			lst = d_x_column.split("_", QString::SkipEmptyParts);
+			if (lst[0] == oldName)
+				d_x_column = newName + "_" + lst[1];
+		}
+	} else {
+		if (title().text() == oldName)
+			setTitle(newName);
+		if (d_x_column == oldName)
+			d_x_column = newName;
+	}
 }
 
 bool DataCurve::updateData(Table *t, const QString& colName)
@@ -618,7 +541,7 @@ void DataCurve::loadData()
 			time0 = sd->dateTimeOrigin().time();
 		else {
 			for (int i = d_start_row; i <= d_end_row; i++ ){
-				QString xval=d_table->text(i,xcol);
+				QString xval = d_table->text(i, xcol).trimmed();
 				if (!xval.isEmpty()){
 					time0 = QTime::fromString (xval, date_time_fmt);
 					if (time0.isValid())
@@ -632,7 +555,7 @@ void DataCurve::loadData()
 			date0 = sd->dateTimeOrigin();
 		else {
 			for (int i = d_start_row; i <= d_end_row; i++ ){
-				QString xval=d_table->text(i,xcol);
+				QString xval = d_table->text(i, xcol).trimmed();
 				if (!xval.isEmpty()){
 					date0 = QDateTime::fromString (xval, date_time_fmt);
 					if (date0.isValid())
@@ -645,19 +568,19 @@ void DataCurve::loadData()
 	int size = 0, from = 0;
 	d_data_ranges.clear();
 	for (int i = d_start_row; i <= d_end_row; i++ ){
-		QString xval = d_table->text(i,xcol);
-		QString yval = d_table->text(i,ycol);
+		QString xval = d_table->text(i, xcol);
+		QString yval = d_table->text(i, ycol);
 		if (!xval.isEmpty() && !yval.isEmpty()){
 			bool valid_data = true;
 			if (xColType == Table::Text){
 				xLabels << xval;
 				X[size] = (double)(size + 1);
 			} else if (xColType == Table::Time){
-				QTime time = QTime::fromString (xval, date_time_fmt);
+				QTime time = QTime::fromString(xval.trimmed(), date_time_fmt);
 				if (time.isValid())
 					X[size]= time0.msecsTo (time);
 			} else if (xColType == Table::Date){
-				QDateTime d = QDateTime::fromString (xval, date_time_fmt);
+				QDateTime d = QDateTime::fromString(xval.trimmed(), date_time_fmt);
 				if (d.isValid())
 					X[size] = (double) date0.secsTo(d);
 			} else
@@ -696,26 +619,16 @@ void DataCurve::loadData()
 	} else {
 		if (d_type == Graph::HorizontalBars){
 			setData(Y.data(), X.data(), size);
-			foreach(DataCurve *c, d_error_bars)
+			foreach(ErrorBarsCurve *c, d_error_bars)
                 c->setData(Y.data(), X.data(), size);
 		} else {
 			setData(X.data(), Y.data(), size);
-			foreach(DataCurve *c, d_error_bars)
+			foreach(ErrorBarsCurve *c, d_error_bars)
                 c->setData(X.data(), Y.data(), size);
 		}
 
-		if (xColType == Table::Text){
+		if (xColType == Table::Text)
 			g->setLabelsTextFormat(xAxis, ScaleDraw::Text, d_x_column, xLabels);
-		} else if (xColType == Table::Time || xColType == Table::Date){
-			ScaleDraw *old_sd = (ScaleDraw *)g->axisScaleDraw(xAxis);
-			ScaleDraw *sd = new ScaleDraw(g, old_sd);
-			if (xColType == Table::Date)
-				sd->setDateTimeOrigin(date0);
-			else
-				sd->setDateTimeOrigin(QDateTime(QDate::currentDate(), time0));
-			g->setAxisScaleDraw(xAxis, sd);
-		}
-
 		if (yColType == Table::Text)
 			g->setLabelsTextFormat(QwtPlot::yLeft, ScaleDraw::Text, title().text(), yLabels);
 	}
@@ -730,7 +643,7 @@ void DataCurve::loadData()
 	}
 }
 
-void DataCurve::removeErrorBars(DataCurve *c)
+void DataCurve::removeErrorBars(ErrorBarsCurve *c)
 {
 	if (!c || d_error_bars.isEmpty())
 		return;
@@ -745,7 +658,7 @@ void DataCurve::clearErrorBars()
 	if (d_error_bars.isEmpty())
 		return;
 
-	foreach(DataCurve *c, d_error_bars)
+	foreach(ErrorBarsCurve *c, d_error_bars)
 		c->remove();
 }
 
@@ -761,7 +674,7 @@ void DataCurve::remove()
 void DataCurve::setVisible(bool on)
 {
 	QwtPlotCurve::setVisible(on);
-	foreach(DataCurve *c, d_error_bars)
+	foreach(ErrorBarsCurve *c, d_error_bars)
 		c->setVisible(on);
 	foreach(PlotMarker *m, d_labels_list)
 		m->setVisible(on);
@@ -903,6 +816,8 @@ void DataCurve::loadLabels()
 		d_labels_list << m;
 		index++;
 	}
+
+	d_show_labels = true;
 }
 
 void DataCurve::clearLabels()
@@ -910,6 +825,8 @@ void DataCurve::clearLabels()
 	if (!validCurveType())
 		return;
 
+	d_show_labels = false;
+
 	foreach(PlotMarker *m, d_labels_list){
 		m->detach();
 		delete m;
@@ -1057,8 +974,8 @@ void DataCurve::clone(DataCurve* c)
 	d_labels_x_offset = c->labelsXOffset();
 	d_labels_y_offset = c->labelsYOffset();
 	d_skip_symbols = c->skipSymbolsCount();
-
-    if (!c->labelsColumnName().isEmpty()){
+	d_show_labels = c->hasVisibleLabels();
+	if (d_show_labels){
         plot()->replot();
         setLabelsColumnName(c->labelsColumnName());
     }
@@ -1073,7 +990,7 @@ QString DataCurve::saveToString()
 	if (d_skip_symbols > 1)
 		s += "<SkipPoints>" + QString::number(d_skip_symbols) + "</SkipPoints>\n";
 
-    if (d_labels_list.isEmpty() || type() == Graph::Function || type() == Graph::Box)
+	if (d_labels_list.isEmpty() || type() == Graph::Function)
         return s;
 
     s += "<CurveLabels>\n";
@@ -1087,7 +1004,15 @@ QString DataCurve::saveToString()
         s += "\t<xoffset>" + QString::number(d_labels_x_offset) + "</xoffset>\n";
     if (d_labels_y_offset != 0.0)
         s += "\t<yoffset>" + QString::number(d_labels_y_offset) + "</yoffset>\n";
-    return s + "</CurveLabels>\n";
+
+	if (type() == Graph::Box){
+		s += "\t<boxLabels>" + QString::number(((BoxCurve *)this)->hasBoxLabels()) + "</boxLabels>\n";
+		s += "\t<whiskerLabels>" + QString::number(((BoxCurve *)this)->hasWhiskerLabels()) + "</whiskerLabels>\n";
+		s += "\t<display>" + QString::number(((BoxCurve *)this)->labelsDisplayPolicy()) + "</display>\n";
+	}
+
+	s += "</CurveLabels>\n";
+	return s + saveCurveSymbolImage();
 }
 
 void DataCurve::restoreLabels(const QStringList& lst)
@@ -1128,6 +1053,12 @@ void DataCurve::restoreLabels(const QStringList& lst)
             xoffset = s.remove("<xoffset>").remove("</xoffset>").toInt();
         else if (s.contains("<yoffset>"))
             yoffset = s.remove("<yoffset>").remove("</yoffset>").toInt();
+		else if (s.contains("<boxLabels>"))
+			((BoxCurve *)this)->showBoxLabels(s.remove("<boxLabels>").remove("</boxLabels>").toInt());
+		else if (s.contains("<whiskerLabels>"))
+			((BoxCurve *)this)->showWhiskerLabels(s.remove("<whiskerLabels>").remove("</whiskerLabels>").toInt());
+		else if (s.contains("<display>"))
+			((BoxCurve *)this)->setLabelsDisplayPolicy((BoxCurve::LabelsDisplayPolicy)s.remove("<display>").remove("</display>").toInt());
     }
     setLabelsOffset(xoffset, yoffset);
     setLabelsColumnName(labelsColumn);
@@ -1167,16 +1098,14 @@ bool DataCurve::hasSelectedLabels()
 	if (!validCurveType())
 		return false;
 
-    if (d_labels_list.isEmpty())
-        return false;
+	if (d_labels_list.isEmpty())
+		return false;
 
-    foreach(PlotMarker *m, d_labels_list){
-        if (m->label().backgroundPen() == QPen(Qt::blue))
-            return true;
-        else
-            return false;
-    }
-    return false;
+	foreach(PlotMarker *m, d_labels_list){
+		if (m->label().backgroundPen().color() == Qt::blue)
+			return true;
+	}
+	return false;
 }
 
 void DataCurve::setLabelsSelected(bool on)
@@ -1200,6 +1129,7 @@ void DataCurve::setLabelsSelected(bool on)
         g->selectTitle(false);
         g->deselectMarker();
         g->notifyFontChange(d_labels_font);
+		g->notifyColorChange(d_labels_color);
     }
     plot()->replot();
 }
@@ -1207,9 +1137,8 @@ void DataCurve::setLabelsSelected(bool on)
 bool DataCurve::validCurveType()
 {
 	int style = type();
-	if (style == Graph::Function || style == Graph::Box ||
-		style == Graph::Pie || //style == Graph::ErrorBars ||
-		style == Graph::ColorMap ||  style == Graph::GrayScale ||
+	if (style == Graph::Function || style == Graph::Pie ||
+		style == Graph::ColorMap || style == Graph::GrayScale ||
 		style == Graph::Contour || style == Graph::ImagePlot)
 		return false;
 	return true;
@@ -1217,9 +1146,7 @@ bool DataCurve::validCurveType()
 
 void DataCurve::moveLabels(const QPoint& pos)
 {
-	if (!validCurveType())
-		return;
-	if (!d_selected_label || d_labels_list.isEmpty())
+	if (!validCurveType() || !d_selected_label || d_labels_list.isEmpty())
 		return;
 
     QwtPlot *d_plot = plot();
