@@ -35,6 +35,7 @@
 
 class PlotMarker;
 class Table;
+class ErrorBarsCurve;
 
 //! Abstract 2D plot curve class
 class PlotCurve: public QwtPlotCurve
@@ -62,6 +63,7 @@ public:
 	bool sideLinesEnabled(){return d_side_lines;};
 	void enableSideLines(bool on){d_side_lines = on;};
 
+	QString saveCurveSymbolImage();
 	QString saveCurveLayout();
 	void restoreCurveLayout(const QStringList& lst);
 
@@ -164,15 +166,15 @@ public:
 		 *
 		 * Column ids are of the form '&lt;name of table> "_" &lt;name of column>'.
 		 */
-    virtual QString plotAssociation();
+	virtual QStringList plotAssociation();
 	virtual void updateColumnNames(const QString& oldName, const QString& newName, bool updateTableName);
 
 	//! The list of attached error bars.
-	QList<DataCurve *> errorBarsList(){return d_error_bars;};
+	QList<ErrorBarsCurve *> errorBarsList(){return d_error_bars;};
 	//! Adds a single error bars curve to the list of attached error bars.
-	void addErrorBars(DataCurve *c){if (c) d_error_bars << c;};
+	void addErrorBars(ErrorBarsCurve *c){if (c) d_error_bars << c;};
 	//! Remove a single error bars curve from the list of attached error bars.
-	void removeErrorBars(DataCurve *c);
+	void removeErrorBars(ErrorBarsCurve *c);
 	//! Clears the list of attached error bars.
 	void clearErrorBars();
 	//! Clears the list of attached text labels.
@@ -180,21 +182,23 @@ public:
 
 	void setVisible(bool on);
 
+	void setVisibleLabels(bool on = true){d_show_labels = on;};
+	bool hasVisibleLabels(){return d_show_labels;};
 	bool selectedLabels(const QPoint& pos);
 	bool hasSelectedLabels();
 	void setLabelsSelected(bool on = true);
 
 	void moveLabels(const QPoint& pos);
-    void updateLabelsPosition();
+	virtual void updateLabelsPosition();
 
 protected:
         virtual void drawCurve(QPainter *p, int style, const QwtScaleMap &xMap, const QwtScaleMap &yMap, int from, int to) const;
 
 	bool validCurveType();
-    void loadLabels();
+	virtual void loadLabels();
 
 	//! List of the error bar curves associated to this curve.
-	QList <DataCurve *> d_error_bars;
+	QList <ErrorBarsCurve *> d_error_bars;
 	//! The data source table.
 	Table *d_table;
 	//!\brief The name of the column used for abscissae values.
@@ -218,6 +222,7 @@ protected:
 	QFont d_labels_font;
 	double d_labels_angle;
 	bool d_white_out_labels;
+	bool d_show_labels;
 	int d_labels_align, d_labels_x_offset, d_labels_y_offset;
 	//! Keeps track of the plot marker on which the user clicked when selecting the labels.
 	PlotMarker *d_selected_label;
