@@ -33,29 +33,33 @@
 #include <QPainter>
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_histogram.h>
+#include <qwt_painter.h>
 
 QwtHistogram::QwtHistogram(Table *t, const QString& name, int startRow, int endRow):
 	QwtBarCurve(QwtBarCurve::Vertical, t, "", name, startRow, endRow),
 	d_autoBin(true)
 {
-    d_matrix = 0;
-    setType(Graph::Histogram);
-	setPlotStyle(Graph::Histogram);
-    setStyle(QwtPlotCurve::UserCurve);
+	init();
 }
 
 QwtHistogram::QwtHistogram(Matrix *m):
     QwtBarCurve(QwtBarCurve::Vertical, NULL, "matrix", m->objectName(), 0, 0)
 {
     if (m){
-        d_autoBin = true;
+		init();
         d_matrix = m;
-        setType(Graph::Histogram);
-		setPlotStyle(Graph::Histogram);
-        setStyle(QwtPlotCurve::UserCurve);
     }
 }
 
+void QwtHistogram::init()
+{
+	d_matrix = 0;
+	bar_gap = 0;
+	setType(Graph::Histogram);
+	setPlotStyle(Graph::Histogram);
+	setStyle(QwtPlotCurve::UserCurve);
+}
+
 void QwtHistogram::copy(QwtHistogram *h)
 {
 	QwtBarCurve::copy((const QwtBarCurve *)h);
@@ -76,19 +80,27 @@ void QwtHistogram::draw(QPainter *painter,
 		to = dataSize() - 1;
 
 	painter->save();
-	painter->setPen(QwtPlotCurve::pen());
-	painter->setBrush(QwtPlotCurve::brush());
+	painter->setPen(QwtPainter::scaledPen(pen()));
+	painter->setBrush(brush());
 
-	const int ref= yMap.transform(baseline());
-	const int dx=abs(xMap.transform(x(from+1)) - xMap.transform(x(from)));
-	const int bar_width=int(dx*(1-gap()*0.01));
-	const int half_width = int(0.5*(dx-bar_width));
-	const int xOffset = int(0.01*offset()*bar_width);
+	const double ref = yMap.transform(baseline()) + 1;
+	const double dx = abs(xMap.transform(x(from + 1)) - xMap.transform(x(from)));
+	const double bar_width = dx*(1 - gap()*0.01);
+	const double half_width = 0.5*(dx - bar_width);
+	const double xOffset = 0.01*offset()*bar_width + half_width;
 
-	for (int i=from; i<=to; i++){
-		const int px1 = xMap.transform(x(i));
-		const int py1 = yMap.transform(y(i));
-		painter->drawRect(px1+half_width+xOffset,py1,bar_width+1,(ref-py1+1));
+	if (gap()){
+		for (int i = from;  i <= to; i++){
+			const double py = yMap.transform(y(i));
+			painter->drawRect(QRectF(xMap.transform(x(i)) + xOffset, py, bar_width, (ref - py)));
+		}
+	} else {
+		for (int i = from;  i < to; i++){
+			painter->drawRect(QRectF(QPointF(xMap.transform(x(i)) + xOffset, yMap.transform(y(i))),
+									 QPointF(xMap.transform(x(i + 1)) + xOffset, ref)));
+		}
+		const double py = yMap.transform(y(to));
+		painter->drawRect(QRectF(xMap.transform(x(to)) + xOffset, py, bar_width, (ref - py)));
 	}
 
 	painter->restore();
@@ -217,6 +229,8 @@ void QwtHistogram::loadData()
 	d_max = gsl_histogram_max_val(h);
 
 	gsl_histogram_free (h);
+	if (d_show_labels)
+		loadLabels();
 }
 
 void QwtHistogram::loadDataFromMatrix()
@@ -280,4 +294,61 @@ void QwtHistogram::loadDataFromMatrix()
 	d_max = gsl_histogram_max_val(h);
 
 	gsl_histogram_free (h);
+	if (d_show_labels)
+		loadLabels();
+}
+
+
+void QwtHistogram::loadLabels()
+{
+	clearLabels();
+
+	int size = this->dataSize();
+	if (!size)
+		return;
+
+	QwtPlot *d_plot = plot();
+	if (!d_plot)
+		return;
+
+	int index = 0;
+	for (int i = 0; i < size; i++){
+		PlotMarker *m = new PlotMarker(index, d_labels_angle);
+
+		QwtText t = QwtText(QString::number(y(i)));
+		t.setColor(d_labels_color);
+		t.setFont(d_labels_font);
+		if (d_white_out_labels)
+			t.setBackgroundBrush(QBrush(Qt::white));
+		else
+			t.setBackgroundBrush(QBrush(Qt::transparent));
+		m->setLabel(t);
+
+		int x_axis = xAxis();
+		int y_axis = yAxis();
+		m->setAxis(x_axis, y_axis);
+
+		QSize size = t.textSize();
+		int dx = int(d_labels_x_offset*0.01*size.height());
+		int dy = -int((d_labels_y_offset*0.01 + 0.5)*size.height());
+		int x2 = d_plot->transform(x_axis, x(index)) + dx;
+		int y2 = d_plot->transform(y_axis, y(index)) + dy;
+		switch(d_labels_align){
+			case Qt::AlignLeft:
+			break;
+			case Qt::AlignHCenter:
+				x2 -= size.width()/2;
+			break;
+			case Qt::AlignRight:
+				x2 -= size.width();
+			break;
+		}
+		m->setXValue(d_plot->invTransform(x_axis, x2));
+		m->setYValue(d_plot->invTransform(y_axis, y2));
+		m->attach(d_plot);
+		d_labels_list << m;
+		index++;
+	}
+
+	d_show_labels = true;
 }
