@@ -349,9 +349,9 @@ void ScaleDraw::drawLabel(QPainter *painter, double value) const
     ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
 	if (sc_engine->hasBreak()){
 		bool invertedScale = sc_engine->testAttribute(QwtScaleEngine::Inverted);
-		if (invertedScale && sc_engine->axisBreakRight() == value)
+		if (invertedScale && (sc_engine->axisBreakLeft() > value && sc_engine->axisBreakRight() < value))
         	return;
-		if (!invertedScale && sc_engine->axisBreakLeft() == value)
+		if (!invertedScale && (sc_engine->axisBreakLeft() < value && sc_engine->axisBreakRight() > value))
         	return;
 	}
 
@@ -501,7 +501,7 @@ int ScaleDraw::axis() const
 void ScaleDraw::drawTick(QPainter *p, double value, int len) const
 {
 	ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
-	if (sc_engine->hasBreak() && (sc_engine->axisBreakLeft() == value || sc_engine->axisBreakRight() == value))
+	if (sc_engine->hasBreak() && (sc_engine->axisBreakLeft() < value && sc_engine->axisBreakRight() > value))
 		return;
 
 	QwtScaleDiv scDiv = scaleDiv();
@@ -540,10 +540,128 @@ void ScaleDraw::drawTick(QPainter *p, double value, int len) const
     QwtScaleDraw::drawTick(p, value, len);
 }
 
+void ScaleDraw::drawInwardTick(QPainter *painter, double value, int len) const
+{
+	ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
+	if (sc_engine->hasBreak() && (sc_engine->axisBreakLeft() < value && sc_engine->axisBreakRight() > value))
+		return;
+
+	int pw2 = qwtMin((int)painter->pen().width(), len) / 2;
+
+	QwtScaleMap scaleMap = map();
+	const QwtMetricsMap metricsMap = QwtPainter::metricsMap();
+	QPoint pos = this->pos();
+
+	int majLen = tickLength(QwtScaleDiv::MajorTick);
+
+	if ( !metricsMap.isIdentity() ){
+		/*
+		   The perfect position of the ticks is important.
+		   To avoid rounding errors we have to use
+		   device coordinates.
+		 */
+		QwtPainter::resetMetricsMap();
+
+		pos = metricsMap.layoutToDevice(pos);
+
+		if ( orientation() == Qt::Vertical ){
+			scaleMap.setPaintInterval(
+				metricsMap.layoutToDeviceY((int)scaleMap.p1()),
+				metricsMap.layoutToDeviceY((int)scaleMap.p2())
+			);
+			len = metricsMap.layoutToDeviceX(len);
+			majLen = metricsMap.layoutToDeviceX(majLen);
+		} else {
+			scaleMap.setPaintInterval(
+				metricsMap.layoutToDeviceX((int)scaleMap.p1()),
+				metricsMap.layoutToDeviceX((int)scaleMap.p2())
+			);
+			len = metricsMap.layoutToDeviceY(len);
+			majLen = metricsMap.layoutToDeviceY(majLen);
+		}
+	}
+
+	const int clw = d_plot->canvasLineWidth();
+	const int tval = scaleMap.transform(value);
+
+	bool draw = false;
+	if ( orientation() == Qt::Vertical ){
+		int low = (int)scaleMap.p2() + majLen;
+		int high = (int)scaleMap.p1() - majLen;
+		if ((tval > low && tval < high) ||
+			(tval > high && !d_plot->axisEnabled (QwtPlot::xBottom) && !clw) ||
+			(tval < low && !d_plot->axisEnabled(QwtPlot::xTop) && !clw)) draw = true;
+	} else {
+		int low = (int)scaleMap.p1() + majLen;
+		int high = (int)scaleMap.p2() - majLen;
+		if ((tval > low && tval < high) ||
+			(tval > high && !d_plot->axisEnabled(QwtPlot::yRight) && !clw) ||
+			(tval < low && !d_plot->axisEnabled(QwtPlot::yLeft) && !clw)) draw = true;
+	}
+
+	if (draw){
+		switch(alignment()){
+			case LeftScale:
+			{
+				QwtPainter::drawLine(painter, pos.x() + pw2, tval, pos.x() + len, tval);
+				break;
+			}
+			case RightScale:
+			{
+				QwtPainter::drawLine(painter, pos.x() - pw2, tval, pos.x() - len, tval);
+				break;
+			}
+			case BottomScale:
+			{
+				QwtPainter::drawLine(painter, tval, pos.y() - pw2, tval, pos.y() - len);
+				break;
+			}
+			case TopScale:
+			{
+				QwtPainter::drawLine(painter, tval, pos.y() + pw2, tval, pos.y() + len);
+				break;
+			}
+		}
+	}
+	QwtPainter::setMetricsMap(metricsMap); // restore metrics map
+}
+
 void ScaleDraw::draw(QPainter *painter, const QPalette& palette) const
 {
 	drawBreak(painter);
 	QwtScaleDraw::draw(painter, palette);
+
+	if (!d_plot->isPrinting())
+		return;
+
+	painter->save();
+
+	QPen pen = painter->pen();
+	pen.setColor(palette.color(QPalette::Foreground));
+	painter->setPen(pen);
+
+	int majLen = d_plot->majorTickLength();
+	if (d_majTicks >= Both && majLen > 0){
+		const QwtValueList &ticks = this->scaleDiv().ticks(QwtScaleDiv::MajorTick);
+		for (int i = 0; i < (int)ticks.count(); i++){
+			const double v = ticks[i];
+			if (this->scaleDiv().contains(v))
+				drawInwardTick(painter, v, majLen);
+		}
+	}
+
+	int minLen = d_plot->minorTickLength();
+	if (d_minTicks >= Both && minLen > 0){
+		for (int tickType = QwtScaleDiv::MinorTick; tickType < QwtScaleDiv::MajorTick; tickType++){
+			const QwtValueList &ticks = this->scaleDiv().ticks(tickType);
+			for (int i = 0; i < (int)ticks.count(); i++){
+				const double v = ticks[i];
+				if ( this->scaleDiv().contains(v) )
+					drawInwardTick(painter, v, minLen);
+			}
+		}
+	}
+	painter->restore();
 }
 
 void ScaleDraw::drawBreak(QPainter *painter) const
@@ -559,7 +677,7 @@ void ScaleDraw::drawBreak(QPainter *painter) const
 	pen.setColor(d_plot->axisWidget(axis())->palette().color(QPalette::Active, QColorGroup::Foreground));
 	painter->setPen(pen);
 
-	int len = majTickLength();
+	int len = d_plot->majorTickLength();
 
     QwtScaleMap scaleMap = map();
     const QwtMetricsMap metricsMap = QwtPainter::metricsMap();
@@ -695,18 +813,20 @@ void ScaleDraw::setMonthFormat(NameFormat format)
 	d_name_format = format;
 }
 
-void ScaleDraw::setTimeFormat(const QTime& t, const QString& format)
+void ScaleDraw::setTimeFormat(const QString& format, const QTime& t)
 {
 	d_type = Time;
 	d_format_info = format;
-	d_date_time_origin.setTime(t);
+	if (!t.isNull() && t.isValid())
+		d_date_time_origin.setTime(t);
 }
 
-void ScaleDraw::setDateFormat(const QDateTime& d, const QString& format)
+void ScaleDraw::setDateFormat(const QString& format, const QDateTime& d)
 {
 	d_type = Date;
 	d_format_info = format;
-	d_date_time_origin = d;
+	if (!d.isNull() && d.isValid())
+		d_date_time_origin = d;
 }
 
 QString ScaleDraw::formatString()
@@ -714,7 +834,7 @@ QString ScaleDraw::formatString()
 	if (d_type == Time)
 		return d_date_time_origin.time().toString() + ";" + d_format_info;
 	else if (d_type == Date)
-		return d_date_time_origin.toString(Qt::ISODate) + ";" + d_format_info;
+		return d_date_time_origin.toString(d_format_info) + ";" + d_format_info;
 
 	return d_format_info;
 }
