@@ -52,6 +52,8 @@ public:
 	ScaleDraw(Graph *plot, const QString& formula = QString::null);
 	ScaleDraw(Graph *plot, const QStringList& labels, const QString& format, ScaleType type = Text);
 
+	Graph *plot(){return d_plot;};
+
     QString formatString();
     QString format(){return d_format_info;};
 
@@ -88,8 +90,8 @@ public:
 
 	void setDayFormat(NameFormat format);
 	void setMonthFormat(NameFormat format);
-	void setTimeFormat(const QTime& t, const QString& format);
-	void setDateFormat(const QDateTime& d, const QString& format);
+	void setTimeFormat(const QString& format, const QTime& t = QTime());
+	void setDateFormat(const QString& format, const QDateTime& d = QDateTime());
 
 	QDateTime dateTimeOrigin(){return d_date_time_origin;};
     void setDateTimeOrigin(const QDateTime& d){d_date_time_origin = d;};
@@ -108,6 +110,7 @@ protected:
 	virtual void draw (QPainter *, const QPalette &) const;
     virtual void drawLabel(QPainter *painter, double value) const;
 	virtual void drawTick(QPainter *p, double value, int len) const;
+	void drawInwardTick(QPainter *painter, double value, int len) const;
 	virtual void drawBackbone(QPainter *painter) const;
 	void drawBreak(QPainter *) const;
 
