@@ -470,7 +470,7 @@ void Spectrogram::drawContourLines (QPainter *p, const QwtScaleMap &xMap, const
 		updateLabels(p, xMap, yMap, contourLines);
 }
 
-void Spectrogram::updateLabels(QPainter *p, const QwtScaleMap &xMap, const QwtScaleMap &yMap,
+void Spectrogram::updateLabels(QPainter *p, const QwtScaleMap &, const QwtScaleMap &,
 		const QwtRasterData::ContourLines &contourLines) const
 {
 	QwtValueList levels = contourLevels();
@@ -610,6 +610,7 @@ void Spectrogram::selectLabel(bool on)
 	if (on){
 		d_graph->deselect();
 		d_graph->notifyFontChange(d_labels_font);
+		d_graph->notifyColorChange(d_labels_color);
 	}
 
 	foreach(PlotMarker *m, d_labels_list){
