@@ -4,8 +4,8 @@
     --------------------------------------------------------------------
 	Copyright            : (C) 2004 - 2010 by Ion Vasilief,
 						   (C) 2006 - June 2007 Tilman Hoener zu Siederdissen
-    Email (use @ for *)  : ion_vasilief*yahoo.fr, thzs*gmx.net
-    Description          : General plot options dialog
+	Email (use @ for *)  : ion_vasilief*yahoo.fr
+	Description          : Axes preferences dialog
 
  ***************************************************************************/
 
@@ -195,7 +195,7 @@ void AxesDialog::initScalesPage()
 	breaksLayout->addWidget(boxBreakWidth, 4, 1);
 
     boxLog10AfterBreak = new QCheckBox(tr("&Log10 Scale After Break"));
-    breaksLayout->addWidget(boxLog10AfterBreak, 0, 3);
+	breaksLayout->addWidget(boxLog10AfterBreak, 0, 2);
 
     breaksLayout->addWidget(new QLabel(tr("Step Before Break")), 1, 2);
     boxStepBeforeBreak = new DoubleSpinBox();
@@ -493,15 +493,23 @@ void AxesDialog::initAxesPage()
 	labelBoxLayout->addWidget(formatButtons);
 
 	QHBoxLayout *hl = new QHBoxLayout();
+	hl->addWidget(new QLabel(tr("Color")));
+	axisLabelColorButton = new ColorButton();
+	connect(axisLabelColorButton, SIGNAL(colorChanged()), this, SLOT(pickAxisLabelColor()));
+	hl->addWidget(axisLabelColorButton);
+
+	buttonLabelFont = new QPushButton(tr("&Font"));
+	buttonLabelFont->setIcon(QIcon(":/font.png"));
+	connect(buttonLabelFont, SIGNAL(clicked()), this, SLOT(customAxisLabelFont()));
+	hl->addWidget(buttonLabelFont);
+
 	hl->addWidget(new QLabel(tr("Distance to axis")));
 	boxLabelsDistance = new QSpinBox();
 	boxLabelsDistance->setRange(0, 1000);
 	boxLabelsDistance->setSuffix(" " + tr("pixels"));
 	connect(boxLabelsDistance, SIGNAL(valueChanged(int)), this, SLOT(updatePlot()));
 	hl->addWidget(boxLabelsDistance);
-
-	buttonLabelFont = new QPushButton(tr("&Font"));
-	hl->addWidget(buttonLabelFont);
+	hl->addStretch();
 
 	invertTitleBox = new QCheckBox(tr("&Inverted"));
 	invertTitleBox->hide();
@@ -525,7 +533,7 @@ void AxesDialog::initAxesPage()
 	boxAxisType->addItem(tr("Day of the week"));
 	boxAxisType->addItem(tr("Month"));
 	boxAxisType->addItem(tr("Time"));
-	boxAxisType->addItem(tr("Date"));
+	boxAxisType->addItem(tr("Date") + "/" + tr("Time"));
 	boxAxisType->addItem(tr("Column Headings"));
 	leftBoxLayout->addWidget( boxAxisType, 0, 1 );
 
@@ -533,6 +541,7 @@ void AxesDialog::initAxesPage()
 
 	btnAxesFont = new QPushButton();
 	btnAxesFont->setText( tr( "Axis &Font" ) );
+	btnAxesFont->setIcon(QIcon(":/font.png"));
 	leftBoxLayout->addWidget( btnAxesFont, 1, 1 );
 
 	leftBoxLayout->addWidget( new QLabel(tr( "Color" )), 2, 0 );
@@ -671,8 +680,6 @@ void AxesDialog::initAxesPage()
 
 	generalDialog->addTab( axesPage, tr( "Axis" ) );
 
-	connect(buttonLabelFont, SIGNAL(clicked()), this, SLOT(customAxisLabelFont()));
-
 	connect(axesTitlesList,SIGNAL(currentRowChanged(int)), this, SLOT(updateShowBox(int)));
 	connect(axesTitlesList,SIGNAL(currentRowChanged(int)), this, SLOT(updateAxisColor(int)));
 	connect(axesTitlesList,SIGNAL(currentRowChanged(int)), this, SLOT(updateTitleBox(int)));
@@ -912,6 +919,13 @@ void AxesDialog::showAxisFormatOptions(int format)
 				boxFormat->setCurrentText(formatInfo);
 				originDateTimeBox->setDateTime (scaleDraw->dateTimeOrigin());
 			}
+			boxFormat->insertItem("yyyy-MM-dd hh:mm:ss");
+			boxFormat->insertItem("yyyy/MM/dd hh:mm:ss");
+			boxFormat->insertItem("yyyy.MM.dd hh:mm:ss");
+			boxFormat->insertItem("dd-MM-yyyy hh:mm:ss");
+			boxFormat->insertItem("dd/MM/yyyy hh:mm:ss");
+			boxFormat->insertItem("dd.MM.yyyy hh:mm:ss");
+
 			boxFormat->insertItem("yyyy-MM-dd");
 			boxFormat->insertItem("yyyy/MM/dd");
 			boxFormat->insertItem("yyyy.MM.dd");
@@ -926,7 +940,7 @@ void AxesDialog::showAxisFormatOptions(int format)
         {
             labelTable->show();
             QString tableName = d_graph->axisFormatInfo(axis);
-            if (tablesList.contains(tableName))
+			if (((ApplicationWindow *)parent())->tableNames().contains(tableName))
                 boxTableName->setCurrentText(tableName);
             boxTableName->show();
         }
@@ -952,19 +966,15 @@ void AxesDialog::showAxis()
     switch(a){
         case 0:
             axis = QwtPlot::xBottom;
-            xAxisOn=ok;
         break;
         case 1:
             axis = QwtPlot::yLeft;
-            yAxisOn=ok;
         break;
         case 2:
             axis = QwtPlot::xTop;
-            topAxisOn=ok;
         break;
         case 3:
             axis = QwtPlot::yRight;
-            rightAxisOn=ok;
         break;
     }
 
@@ -976,12 +986,7 @@ void AxesDialog::showAxis()
     boxColName->setEnabled(labels && ok);
     boxShowFormula->setEnabled(labels && ok);
 	boxFormula->setEnabled(labels && ok);
-
-	if (axis == QwtPlot::xBottom || axis == QwtPlot::xTop)
-		boxAngle->setEnabled(labels && ok);
-	else
-		boxAngle->setDisabled(true);
-
+	boxAngle->setEnabled(labels && ok);
 	boxPrecision->setEnabled(labels && ok);
 
 	QString formula =  boxFormula->text();
@@ -996,50 +1001,15 @@ void AxesDialog::showAxis()
 
 void AxesDialog::updateShowBox(int axis)
 {
-	switch(axis)
-	{
-		case 0:
-			{
-				boxShowAxis->setChecked(xAxisOn);
-				int labelsOn=tickLabelsOn[2].toInt();
-				boxShowLabels->setChecked(labelsOn);
-				boxAngle->setEnabled(labelsOn && xAxisOn);
-				boxFormat->setEnabled(labelsOn && xAxisOn);
-				boxAngle->setValue(xBottomLabelsRotation);
-				break;
-			}
-		case 1:
-			{
-				boxShowAxis->setChecked(yAxisOn);
-				int labelsOn=tickLabelsOn[0].toInt();
-				boxShowLabels->setChecked(labelsOn);
-				boxFormat->setEnabled(labelsOn && yAxisOn);
-				boxAngle->setEnabled(false);
-				boxAngle->setValue(0);
-				break;
-			}
-		case 2:
-			{
-				boxShowAxis->setChecked(topAxisOn);
+	int a = mapToQwtAxis(axis);
+	bool axisOn = d_graph->axisEnabled(a);
+	boxShowAxis->setChecked(axisOn);
 
-				int labelsOn=tickLabelsOn[3].toInt();
-				boxShowLabels->setChecked(labelsOn);
-				boxFormat->setEnabled(labelsOn && topAxisOn);
-				boxAngle->setEnabled(labelsOn && topAxisOn);
-				boxAngle->setValue(xTopLabelsRotation);
-				break;
-			}
-		case 3:
-			{
-				boxShowAxis->setChecked(rightAxisOn);
-				int labelsOn=tickLabelsOn[1].toInt();
-				boxShowLabels->setChecked(labelsOn );
-				boxFormat->setEnabled(labelsOn && rightAxisOn);
-				boxAngle->setEnabled(false);
-				boxAngle->setValue(0);
-				break;
-			}
-	}
+	int labelsOn = tickLabelsOn[a].toInt();
+	boxShowLabels->setChecked(labelsOn);
+	boxFormat->setEnabled(labelsOn && axisOn);
+	boxAngle->setEnabled(labelsOn && axisOn);
+	boxAngle->setValue(d_graph->labelsRotation(a));
 
 	bool ok = boxShowAxis->isChecked();
 	axisFormatBox->setEnabled(ok);
@@ -1268,12 +1238,16 @@ void AxesDialog::updateAxisColor(int)
 {
 	int a = mapToQwtAxisId();
 	boxAxisColor->blockSignals(true);
-    boxAxisColor->setColor(d_graph->axisColor(a));
+	boxAxisColor->setColor(d_graph->axisColor(a));
 	boxAxisColor->blockSignals(false);
 
 	boxAxisNumColor->blockSignals(true);
-    boxAxisNumColor->setColor(d_graph->axisLabelsColor(a));
+	boxAxisNumColor->setColor(d_graph->axisLabelsColor(a));
 	boxAxisNumColor->blockSignals(false);
+
+	axisLabelColorButton->blockSignals(true);
+	axisLabelColorButton->setColor(d_graph->axisTitleColor(a));
+	axisLabelColorButton->blockSignals(false);
 }
 
 bool AxesDialog::updatePlot(QWidget *page)
@@ -1324,11 +1298,23 @@ bool AxesDialog::updatePlot(QWidget *page)
 		        switch (boxUnit->currentIndex())
                     {
                     case 0:
-						step *= 86400;
+						step *= 60;//min
                     break;
                     case 1:
-                         step *= 604800;
+						 step *= 3600;//hour
                     break;
+					case 2:
+						step *= 86400;//day
+					break;
+					case 3:
+						 step *= 604800;//week
+					break;
+					case 4:
+						 step *= 2592000;//month
+					break;
+					case 5:
+						 step *= 31536000;//year
+					break;
                     }
 	            }
           	}
@@ -1351,17 +1337,11 @@ bool AxesDialog::updatePlot(QWidget *page)
 		int axis = mapToQwtAxisId();
 		int format = boxAxisType->currentIndex();
 
-		int baseline = boxBaseline->value();
-		axesBaseline[axis] = baseline;
-
         QString formatInfo = QString::null;
-		if (format == ScaleDraw::Numeric)
-		{
-			if (boxShowFormula->isChecked())
-			{
+		if (format == ScaleDraw::Numeric){
+			if (boxShowFormula->isChecked()){
 				QString formula = boxFormula->text().lower();
-				try
-				{
+				try {
 					double value = 1.0;
 					MyParser parser;
 					if (formula.contains("x"))
@@ -1370,18 +1350,17 @@ bool AxesDialog::updatePlot(QWidget *page)
 						parser.DefineVar("y", &value);
 					parser.SetExpr(formula.ascii());
 					parser.Eval();
-				}
-				catch(mu::ParserError &e)
-				{
+				} catch(mu::ParserError &e) {
 					QMessageBox::critical(this, tr("QtiPlot - Formula input error"), QString::fromStdString(e.GetMsg())+"\n"+
 							tr("Valid variables are 'x' for Top/Bottom axes and 'y' for Left/Right axes!"));
 					boxFormula->setFocus();
 					return false;
 				}
 			}
-		} else if (format == ScaleDraw::Date)
-			formatInfo = originDateTimeBox->date().toString(Qt::ISODate) + ";" + boxFormat->currentText();
-		else if (format == ScaleDraw::Time)
+		} else if (format == ScaleDraw::Date){
+			QString fmt = boxFormat->currentText();
+			formatInfo = originDateTimeBox->dateTime().toString(fmt) + ";" + fmt;
+		} else if (format == ScaleDraw::Time)
 			formatInfo = originDateTimeBox->time().toString() + ";" + boxFormat->currentText();
 		else if (format == ScaleDraw::Day || format == ScaleDraw::Month)
             formatInfo = QString::number(boxFormat->currentIndex());
@@ -1394,18 +1373,13 @@ bool AxesDialog::updatePlot(QWidget *page)
 			d_graph->setAxisTitle(axis, boxTitle->text());
 
 		d_graph->setAxisTitleDistance(axis, boxLabelsDistance->value());
-		
-		if (axis == QwtPlot::xBottom)
-			xBottomLabelsRotation = boxAngle->value();
-		else if (axis == QwtPlot::xTop)
-			xTopLabelsRotation = boxAngle->value();
 
 		QString formula = boxFormula->text();
 		if (!boxShowFormula->isChecked())
 			formula = QString();
 		showAxis(axis, format, formatInfo, boxShowAxis->isChecked(), boxMajorTicksType->currentIndex(), boxMinorTicksType->currentIndex(),
 				boxShowLabels->isChecked(), boxAxisColor->color(), boxFormat->currentIndex(),
-				boxPrecision->value(), boxAngle->value(), baseline, formula, boxAxisNumColor->color(),
+				boxPrecision->value(), boxAngle->value(), boxBaseline->value(), formula, boxAxisNumColor->color(),
 				boxTickLabelDistance->value(), boxAxisBackbone->isChecked(), showTicksPolicyBox->currentIndex());
 
 		if (axis == QwtPlot::yRight){
@@ -1433,33 +1407,14 @@ void AxesDialog::setGraph(Graph *g)
 
 	d_graph = g;
 
-	tablesList = app->tableNames();
-	boxTableName->insertStringList(tablesList);
-
+	boxTableName->insertStringList(app->tableNames());
 	boxColName-> insertStringList(app->columnsList(Table::All));
 
-	xAxisOn = g->axisEnabled(QwtPlot::xBottom);
-	yAxisOn = g->axisEnabled(QwtPlot::yLeft);
-	topAxisOn = g->axisEnabled(QwtPlot::xTop);
-	rightAxisOn = g->axisEnabled(QwtPlot::yRight);
-
-	majTicks = g->getMajorTicksType();
-	minTicks = g->getMinorTicksType();
-
 	updateTitleBox(0);
 
-	xBottomLabelsRotation = g->labelsRotation(QwtPlot::xBottom);
-	xTopLabelsRotation = g->labelsRotation(QwtPlot::xTop);
-
 	for (int axis=0; axis<QwtPlot::axisCnt; axis++){
 		const QwtScaleDraw *sd = g->axisScaleDraw (axis);
 		tickLabelsOn << QString::number(sd->hasComponent(QwtAbstractScaleDraw::Labels));
-
-		QwtScaleWidget *scale = (QwtScaleWidget *)g->axisWidget(axis);
-		if (scale)
-			axesBaseline << scale->margin();
-		else
-			axesBaseline << 0;
 	}
 
 	boxAxesLinewidth->setValue(g->axesLinewidth());
@@ -1479,28 +1434,28 @@ void AxesDialog::setGraph(Graph *g)
 
 int AxesDialog::mapToQwtAxisId()
 {
-return mapToQwtAxis(axesTitlesList->currentRow());
+	return mapToQwtAxis(axesTitlesList->currentRow());
 }
 
 int AxesDialog::mapToQwtAxis(int axis)
 {
-int a=-1;
-switch(axis)
-        {
-        case 0:
-           a = QwtPlot::xBottom;
-        break;
-        case 1:
-            a = QwtPlot::yLeft;
-        break;
-        case 2:
-             a = QwtPlot::xTop;
-        break;
-        case 3:
-             a = QwtPlot::yRight;
-        break;
+	int a = -1;
+	switch(axis)
+		{
+		case 0:
+			a = QwtPlot::xBottom;
+		break;
+		case 1:
+			a = QwtPlot::yLeft;
+		break;
+		case 2:
+			 a = QwtPlot::xTop;
+		break;
+		case 3:
+			 a = QwtPlot::yRight;
+		break;
 		}
-return a;
+	return a;
 }
 
 void AxesDialog::updateScale()
@@ -1536,9 +1491,34 @@ void AxesDialog::updateScale()
         boxEndDateTime->setDateTime(origin.addSecs((int)end));
 
 		boxUnit->show();
+		boxUnit->insertItem(tr("min."));
+		boxUnit->insertItem(tr("hours"));
 		boxUnit->insertItem(tr("days"));
 		boxUnit->insertItem(tr("weeks"));
-		boxStep->setValue(d_graph->axisStep(a)/86400.0);
+		boxUnit->insertItem(tr("months"));
+		boxUnit->insertItem(tr("years"));
+
+		double step = d_graph->axisStep(a)/3600.0; //hours
+		if (step < 1){
+			boxUnit->setCurrentIndex(0);
+			boxStep->setValue(step*60);
+		} else if (step < 24){
+			boxUnit->setCurrentIndex(1);
+			boxStep->setValue(step);
+		} else if (step < 168){
+			boxUnit->setCurrentIndex(2);
+			boxStep->setValue(step/24.0);
+		} else if (step < 720){
+			boxUnit->setCurrentIndex(3);
+			boxStep->setValue(step/168.0);
+		} else if (step < 8760){
+			boxUnit->setCurrentIndex(4);
+			boxStep->setValue(step/720.0);
+		} else {
+			boxUnit->setCurrentIndex(5);
+			boxStep->setValue(step/8760.0);
+		}
+
 		boxStep->setSingleStep(1);
 	} else if (type == ScaleDraw::Time){
 	    ScaleDraw *sclDraw = (ScaleDraw *)d_graph->axisScaleDraw(a);
@@ -1561,9 +1541,10 @@ void AxesDialog::updateScale()
         boxUnit->insertItem(tr("sec."));
         boxUnit->insertItem(tr("min."));
         boxUnit->insertItem(tr("hours"));
-        boxUnit->setCurrentIndex(1);
-        boxStep->setValue(d_graph->axisStep(a)/1e3);
-        boxStep->setSingleStep(1000);
+
+		boxUnit->setCurrentIndex(1);
+		boxStep->setValue(d_graph->axisStep(a)/1e3);
+		boxStep->setSingleStep(1000);
 	} else {
 	    boxStart->show();
         boxStart->setValue(start);
@@ -1670,7 +1651,11 @@ void AxesDialog::setAxisType(int)
 
 void AxesDialog::setBaselineDist(int)
 {
-	boxBaseline->setValue(axesBaseline[mapToQwtAxisId()]);
+	QwtScaleWidget *scale = (QwtScaleWidget *)d_graph->axisWidget(mapToQwtAxisId());
+	if (scale)
+		boxBaseline->setValue(scale->margin());
+	else
+		boxBaseline->setValue(0);
 }
 
 void AxesDialog::updateCurrentAxis()
@@ -1697,8 +1682,8 @@ void AxesDialog::updateCurrentAxis()
 void AxesDialog::setTicksType(int)
 {
 	int a = mapToQwtAxisId();
-	boxMajorTicksType->setCurrentIndex(majTicks[a]);
-	boxMinorTicksType->setCurrentIndex(minTicks[a]);
+	boxMajorTicksType->setCurrentIndex(d_graph->getMajorTicksType()[a]);
+	boxMinorTicksType->setCurrentIndex(d_graph->getMinorTicksType()[a]);
 }
 
 void AxesDialog::updateTickLabelsList(bool on)
@@ -1707,10 +1692,7 @@ void AxesDialog::updateTickLabelsList(bool on)
 
 	boxFormat->setEnabled(on && boxShowAxis->isChecked());
 	boxColName->setEnabled(on && boxShowAxis->isChecked());
-
-	if (axis == QwtPlot::xBottom || axis == QwtPlot::xTop)
-		boxAngle->setEnabled(on);
-
+	boxAngle->setEnabled(on);
 	boxPrecision->setEnabled(on);
 
 	if (tickLabelsOn[axis] == QString::number(on))
@@ -1860,11 +1842,17 @@ void AxesDialog::showFormulaBox()
 		boxFormula->hide();
 }
 
+void AxesDialog::pickAxisLabelColor()
+{
+	d_graph->setAxisTitleColor(mapToQwtAxisId(), axisLabelColorButton->color());
+	d_graph->replot();
+}
+
 void AxesDialog::customAxisLabelFont()
 {
 	int axis = mapToQwtAxisId();
-		bool okF;
-		QFont oldFont = d_graph->axisTitleFont(axis);
+	bool okF;
+	QFont oldFont = d_graph->axisTitleFont(axis);
 	QFont fnt = QFontDialog::getFont( &okF, oldFont,this);
 	if (okF && fnt != oldFont)
 		d_graph->setAxisTitleFont(axis, fnt);
