@@ -368,14 +368,15 @@ void CurvesDialog::addCurves()
 		QString text = item->text(0);
 		switch(item->type()){
 			case ColumnItem:
-				if (contents->findItems(text, Qt::MatchExactly).isEmpty()){
-					Table *t = app->table(text);
-					if (t && !addCurveFromTable(app, t, text))
-						emptyColumns << text;
-				}
+			{
+				Table *t = app->table(text);
+				if (t && !addCurveFromTable(app, t, text))
+					emptyColumns << text;
+			}
 			break;
 
-			case TableItem:{
+			case TableItem:
+			{
 				Table *t = app->table(text);
 				if (!t)
 					continue;
@@ -383,17 +384,15 @@ void CurvesDialog::addCurves()
 				QStringList lst = t->YColumns();
 				for(int i = 0; i < lst.size(); i++){
 					QString s = lst[i];
-					if (contents->findItems(s, Qt::MatchExactly ).isEmpty ()){
-						if (!addCurveFromTable(app, t, s))
-							emptyColumns << s;
-					}
+					if (!addCurveFromTable(app, t, s))
+						emptyColumns << s;
 				}
 			}
 			break;
 
 			case MatrixItem:
 				if (contents->findItems(text, Qt::MatchExactly).isEmpty()){
-					if (!addCurveFromMatrix(app->matrix(text), text))
+					if (!addCurveFromMatrix(app->matrix(text)))
 						emptyColumns << text;
 				}
 			break;
@@ -421,7 +420,7 @@ void CurvesDialog::addCurves()
 	QApplication::restoreOverrideCursor();
 }
 
-bool CurvesDialog::addCurveFromMatrix(Matrix *m, const QString& name)
+bool CurvesDialog::addCurveFromMatrix(Matrix *m)
 {
 	if (!m)
 		return false;
@@ -526,15 +525,12 @@ bool CurvesDialog::addCurveFromTable(ApplicationWindow *app, Table *t, const QSt
 void CurvesDialog::removeCurves()
 {
 	QList<QListWidgetItem *> lst = contents->selectedItems();
-	for (int i = 0; i < lst.size(); ++i){
-        QListWidgetItem *it = lst.at(i);
-        QString s = it->text();
-        if (boxShowRange->isChecked()){
-            QStringList lst = s.split("[");
-            s = lst[0];
-        }
-        d_graph->removeCurve(s);
-    }
+	QList<QwtPlotItem *> curvesList;
+	for (int i = 0; i < lst.size(); ++i)
+		curvesList << d_graph->curve(contents->row(lst.at(i)));
+
+	foreach(QwtPlotItem *c, curvesList)
+		d_graph->removeCurve(c);
 
 	showCurveRange(boxShowRange->isChecked());
 	d_graph->updatePlot();
