@@ -32,6 +32,8 @@
 #include <QHttp>
 #include <QIODevice>
 #include <QNetworkProxy>
+#include <QCompleter>
+#include <QDirModel>
 
 #include "EnrichmentDialog.h"
 #include <Graph.h>
@@ -50,7 +52,7 @@
 #include <PenStyleBox.h>
 
 EnrichmentDialog::EnrichmentDialog(WidgetType wt, Graph *g, ApplicationWindow *app, QWidget *parent)
-	: QDialog(parent), d_plot(g), d_widget(NULL), d_widget_type(wt), d_app(app)
+	: QDialog(parent), d_app(app), d_plot(g), d_widget(NULL), d_widget_type(wt)
 {
 	bool standAlone = qobject_cast<ApplicationWindow*>(parent);
 	if (standAlone)
@@ -157,6 +159,7 @@ void EnrichmentDialog::initTextPage()
 	gl1->addWidget(textColorBtn, 0, 1);
 
 	textFontBtn = new QPushButton(tr( "&Font" ));
+	textFontBtn->setIcon(QIcon(":/font.png"));
 	connect(textFontBtn, SIGNAL(clicked()), this, SLOT(customFont()));
 	gl1->addWidget(textFontBtn, 0, 2);
 
@@ -242,6 +245,13 @@ void EnrichmentDialog::initImagePage()
     gl->addWidget(new QLabel( tr("File")), 0, 0);
 
 	imagePathBox = new QLineEdit();
+
+	QCompleter *completer = new QCompleter(this);
+	completer->setModel(new QDirModel(completer));
+	completer->setModelSorting(QCompleter::CaseSensitivelySortedModel);
+	completer->setCompletionMode(QCompleter::InlineCompletion);
+
+	imagePathBox->setCompleter(completer);
 	gl->addWidget(imagePathBox, 0, 1);
 
 	QPushButton *browseBtn = new QPushButton();
@@ -510,16 +520,18 @@ void EnrichmentDialog::customButtons(QWidget *w)
 
 void EnrichmentDialog::setWidget(QWidget *w)
 {
-	if (!w)
-		return;
-
-	if (!d_app)
+	if (!w || !d_app)
 		return;
 
 	d_widget = w;
 
     FrameWidget *fw = qobject_cast<FrameWidget *>(d_widget);
     if (fw){
+	#ifndef QT_MAC_USE_COCOA
+		if (d_plot)
+			d_plot->deselectMarker();
+	#endif
+
 		frameBox->blockSignals(true);
         frameBox->setCurrentIndex(fw->frameStyle());
 		frameBox->blockSignals(false);
@@ -591,6 +603,8 @@ void EnrichmentDialog::setWidget(QWidget *w)
 			boxSaveImagesInternally->blockSignals(true);
 			boxSaveImagesInternally->setChecked(i->saveInternally());
 			boxSaveImagesInternally->blockSignals(false);
+
+			bestSizeButton->show();
 		}
 	} else if (d_widget_type == Frame){
 		RectangleWidget *r = qobject_cast<RectangleWidget *>(d_widget);
@@ -887,11 +901,20 @@ void EnrichmentDialog::adjustWidth(double height)
 
 void EnrichmentDialog::setBestSize()
 {
+	ImageWidget *iw = qobject_cast<ImageWidget *>(d_widget);
+	if (iw){
+		iw->setSize(iw->pixmap().size());
+		displayCoordinates(unitBox->currentIndex());
+		d_plot->multiLayer()->notifyChanges();
+		return;
+	}
+
 	TexWidget *tw = qobject_cast<TexWidget *>(d_widget);
 	if (tw){
 		tw->setBestSize();
 		displayCoordinates(unitBox->currentIndex());
 		d_plot->multiLayer()->notifyChanges();
+		return;
 	}
 }
 
