@@ -44,7 +44,9 @@
 #include <QCursor>
 #include <QImageWriter>
 #include <QTextStream>
+#if QT_VERSION >= 0x040500
 #include <QTextDocumentWriter>
+#endif
 
 #include <qwt3d_io_gl2ps.h>
 #include <qwt3d_coordsys.h>
@@ -54,6 +56,18 @@
 #include <gsl/gsl_math.h>
 #include <fstream>
 
+ConstFunction::ConstFunction(Qwt3D::Curve *pw)
+: Function(pw)
+{}
+
+double ConstFunction::operator()(double x, double y)
+{
+	if (x < 0.5*(xMin() + xMax()) || y < 0.5*(yMin() + yMax()))
+		return zMin();
+
+	return zMax();
+}
+
 UserFunction::UserFunction(const QString& s, Qwt3D::Curve *pw)
 : Function(pw), formula(s)
 {}
@@ -64,18 +78,14 @@ double UserFunction::operator()(double x, double y)
 		return 0.0;
 
 	MyParser parser;
-	double result=0.0;
-	try
-	{
+	double result = 0.0;
+	try {
 		parser.DefineVar("x", &x);
 		parser.DefineVar("y", &y);
-
 		parser.SetExpr((const std::string)formula.ascii());
-		result=parser.Eval();
-	}
-	catch(mu::ParserError &e)
-	{
-		QMessageBox::critical(0,"QtiPlot - Input function error",QString::fromStdString(e.GetMsg()));
+		result = parser.Eval();
+	} catch(mu::ParserError &e){
+		QMessageBox::critical(0, "QtiPlot - Input function error", QString::fromStdString(e.GetMsg()));
 	}
 	return result;
 }
@@ -153,6 +163,8 @@ void Graph3D::initPlot()
 	setAcceptDrops(true);
 
 	d_active_curve = NULL;
+	d_const_curve = NULL;
+	d_const_func = NULL;
 
 	d_table = 0;
 	d_table_plot_type = NoTable;
@@ -273,6 +285,37 @@ void Graph3D::initCoord()
 	sp->coordinates()->setAutoScale(false);
 }
 
+void Graph3D::addHiddenConstantCurve(double xl, double xr, double yl, double yr, double zl, double zr)
+{
+	if (d_const_curve){
+		delete d_const_curve;
+		d_const_curve = 0;
+	}
+
+	if (d_const_func){
+		delete d_const_func;
+		d_const_func = 0;
+	}
+
+	d_const_curve = new Curve(sp);
+	d_const_curve->setPlotStyle(NOPLOT);
+	d_const_curve->legend()->drawScale(false);
+	d_const_curve->legend()->drawNumbers(false);
+	d_const_curve->showColorLegend(false);
+	d_const_curve->setTitle(QString());
+	d_const_curve->setDataProjection(false);
+	d_const_curve->setFloorStyle(NOFLOOR);
+	d_const_curve->setProjection(BASE, false);
+	sp->addCurve(d_const_curve);
+
+	d_const_func = new ConstFunction(d_const_curve);
+	d_const_func->setMesh(3, 3);
+	d_const_func->setDomain(xl, xr, yl, yr);
+	d_const_func->setMinZ(zl);
+	d_const_func->setMaxZ(zr);
+	d_const_func->create();
+}
+
 Curve* Graph3D::addCurve()
 {
 	removeCurve();
@@ -288,6 +331,7 @@ Curve* Graph3D::addCurve()
 	d_active_curve->setProjection(FACE, false);
 	d_active_curve->setProjection(SIDE, false);
 	d_active_curve->setResolution(app->d_3D_resolution);
+	d_active_curve->legend()->axis()->setNumberFont (this->numbersFont());
 
 	if (!title.isEmpty() && d_active_curve->title()->string() != title)
 		setTitle(title, titleCol, titleFnt);
@@ -305,6 +349,16 @@ void Graph3D::removeCurve()
 		d_func = 0;
 	}
 
+	if (d_const_curve){
+		delete d_const_curve;
+		d_const_curve = 0;
+	}
+
+	if (d_const_func){
+		delete d_const_func;
+		d_const_func = 0;
+	}
+
 	if (d_active_curve){
 		delete d_active_curve;
 		d_active_curve = 0;
@@ -337,7 +391,8 @@ void Graph3D::addFunction(const QString& s, double xl, double xr, double yl,
 		pointStyle = None;
 	}
   	sp->createCoordinateSystem(Triple(xl, yl, zl), Triple(xr, yr, zr));
-	findBestLayout();
+	if (d_autoscale)
+		findBestLayout();
 	update();
 }
 
@@ -607,7 +662,7 @@ void Graph3D::addData(Table* table, int xCol, int yCol, int zCol, int type)
 }
 
 void Graph3D::loadData(Table* table, int xCol, int yCol, int zCol,
-		double xl, double xr, double yl, double yr, double zl, double zr, int axis)
+		double xl, double xr, double yl, double yr, double zl, double zr, int /*axis*/)
 {
 	if (!table || xCol < 0 || yCol < 0 || zCol < 0)
 		return;
@@ -632,9 +687,12 @@ void Graph3D::loadData(Table* table, int xCol, int yCol, int zCol,
 			double y = table->cell(i, yCol);
 			double z = table->cell(i, zCol);
 
-			if (check_limits &&
+			/*if (check_limits &&
 			   ((axis < 0 && (x < xl || x > xr || y < yl || y > yr || z < zl || z > zr)) ||
 			   (axis == 0 && (x < xl || x > xr)) || (axis == 1 && (y < yl || y > yr)) || (axis == 2 && (z < zl || z > zr))))
+				continue;*/
+
+			if (check_limits && (x < xl || x > xr || y < yl || y > yr || z < zl || z > zr))
 				continue;
 
 			data.push_back (Triple(x, y, z));
@@ -656,8 +714,11 @@ void Graph3D::loadData(Table* table, int xCol, int yCol, int zCol,
 	if (!d_active_curve)
 		d_active_curve = addCurve();
 	d_active_curve->loadFromData (data, cells);
-	if (check_limits)
-		sp->createCoordinateSystem(Triple(xl, yl, zl), Triple(xr, yr, zr));
+
+	if (check_limits){
+		sp->coordinates()->setPosition(Triple(xl, yl, zl), Triple(xr, yr, zr));
+		changeScales(xl, xr, yl, yr, zl, zr);
+	}
 
 	double start, end;
 	sp->coordinates()->axes[Z1].limits (start, end);
@@ -672,24 +733,23 @@ void Graph3D::updateData(Table* table)
 		return;
 
 	QString name = plotAssociation;
-	int pos=name.find("_",0);
-	int posX=name.find("(",pos);
-	QString xColName=name.mid(pos+1,posX-pos-1);
+	QStringList lst = name.split(",");
+	if (lst.size() < 2)
+		return;
 
-	pos=name.find(",", posX);
-	posX=name.find("(", pos);
-	QString yColName=name.mid(pos+1, posX-pos-1);
+	QString xColName = lst[0];
+	xColName.chop(3);
+	int xCol = table->colIndex(xColName);
 
-	int xCol=table->colIndex(xColName);
-	int yCol=table->colIndex(yColName);
+	QString yColName = lst[1];
+	yColName.chop(3);
+	int yCol = table->colIndex(yColName);
 
-	if (name.contains("(Z)", true)) {
-		pos=name.find(",", posX);
-		posX=name.find("(", pos);
-		QString zColName=name.mid(pos+1, posX-pos-1);
-		int zCol=table->colIndex(zColName);
+	if (lst.size() == 3 && name.contains("(Z)", true)){
+		QString zColName = lst[2];
+		zColName.chop(3);
 		resetNonEmptyStyle();
-		loadData(table, xCol, yCol, zCol);
+		loadData(table, xCol, yCol, table->colIndex(zColName));
 	} else
 		updateDataXY(table, xCol, yCol);
 
@@ -844,9 +904,7 @@ void Graph3D::resetNonEmptyStyle()
 void Graph3D::update()
 {
 	sp->makeCurrent();
-
 	resetAxesLabels();
-
 	sp->updateData();
 }
 
@@ -929,7 +987,7 @@ void Graph3D::setZAxisLabelFont(const QStringList& lst)
 QStringList Graph3D::axisTickLengths()
 {
 	QStringList lst;
-	double majorl,minorl;
+	double majorl, minorl;
 
 	sp->coordinates()->axes[X1].ticLength (majorl,minorl);
 	lst<<QString::number(majorl);
@@ -953,26 +1011,26 @@ void Graph3D::setTickLengths(const QStringList& lst)
 	if (int(lst.count()) > 6)
 		tick_length.remove(tick_length.first());
 
-	majorl=tick_length[0].toDouble();
-	minorl=tick_length[1].toDouble();
-	sp->coordinates()->axes[X1].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[X2].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[X3].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[X4].setTicLength (majorl,minorl);
+	majorl = tick_length[0].toDouble();
+	minorl = tick_length[1].toDouble();
+	sp->coordinates()->axes[X1].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[X2].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[X3].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[X4].setTicLength (majorl, minorl);
 
-	majorl=tick_length[2].toDouble();
-	minorl=tick_length[3].toDouble();
-	sp->coordinates()->axes[Y1].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[Y2].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[Y3].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[Y4].setTicLength (majorl,minorl);
+	majorl = tick_length[2].toDouble();
+	minorl = tick_length[3].toDouble();
+	sp->coordinates()->axes[Y1].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[Y2].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[Y3].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[Y4].setTicLength (majorl, minorl);
 
-	majorl=tick_length[4].toDouble();
-	minorl=tick_length[5].toDouble();
-	sp->coordinates()->axes[Z1].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[Z2].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[Z3].setTicLength (majorl,minorl);
-	sp->coordinates()->axes[Z4].setTicLength (majorl,minorl);
+	majorl = tick_length[4].toDouble();
+	minorl = tick_length[5].toDouble();
+	sp->coordinates()->axes[Z1].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[Z2].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[Z3].setTicLength (majorl, minorl);
+	sp->coordinates()->axes[Z4].setTicLength (majorl, minorl);
 }
 
 void Graph3D::setXAxisTickLength(double majorLength, double minorLength)
@@ -984,7 +1042,7 @@ void Graph3D::setXAxisTickLength(double majorLength, double minorLength)
 		sp->coordinates()->axes[X2].setTicLength (majorLength,minorLength);
 		sp->coordinates()->axes[X3].setTicLength (majorLength,minorLength);
 		sp->coordinates()->axes[X4].setTicLength (majorLength,minorLength);
-		}
+	}
 }
 
 void Graph3D::setYAxisTickLength(double majorLength, double minorLength)
@@ -1131,12 +1189,18 @@ void Graph3D::setAxesLabels(const QStringList& l)
 	sp->coordinates()->axes[X3].setLabelString(label);
 	sp->coordinates()->axes[X4].setLabelString(label);
 
+	if (l.size() < 2)
+		return;
+
 	label = l[1];
 	sp->coordinates()->axes[Y1].setLabelString(label);
 	sp->coordinates()->axes[Y2].setLabelString(label);
 	sp->coordinates()->axes[Y3].setLabelString(label);
 	sp->coordinates()->axes[Y4].setLabelString(label);
 
+	if (l.size() < 3)
+		return;
+
 	label = l[2];
 	sp->coordinates()->axes[Z1].setLabelString(label);
 	sp->coordinates()->axes[Z2].setLabelString(label);
@@ -1302,7 +1366,7 @@ void Graph3D::setAxisNumericFormat(int axis, int format, int precision)
 	sp->coordinates()->axes[axis3].setNumericFormat((Qwt3D::Scale::NumericFormat)format, precision);
 	sp->coordinates()->axes[axis4].setNumericFormat((Qwt3D::Scale::NumericFormat)format, precision);
 
-	update();
+	sp->updateGL();
 	emit modified();
 }
 
@@ -1324,9 +1388,6 @@ void Graph3D::setScale(int axis, double start, double end, int majorTicks, int m
 	sp->coordinates()->axes[Y1].limits(yMin, yMax);
 	sp->coordinates()->axes[Z1].limits(zMin, zMax);
 
-	double majorTicLength, minorTicLength;
-	sp->coordinates()->axes[axis].ticLength(majorTicLength, minorTicLength);
-
 	switch(axis){
 		case 0:
 			if (xMin != start || xMax != end){
@@ -1351,9 +1412,11 @@ void Graph3D::setScale(int axis, double start, double end, int majorTicks, int m
 	}
 
 	if (d_func){
-		d_func->setDomain(xMin, xMax, yMin, yMax);
-		d_func->setMinZ(zMin);
-		d_func->setMaxZ(zMax);
+		if (axis == 2){
+			d_func->setMinZ(zMin);
+			d_func->setMaxZ(zMax);
+		} else
+			d_func->setDomain(xMin, xMax, yMin, yMax);
 		d_func->create();
 	} else if (d_surface){
 		d_surface->restrictRange(ParallelEpiped(Triple(xMin, yMin, zMin), Triple(xMax, yMax, zMax)));
@@ -1366,7 +1429,6 @@ void Graph3D::setScale(int axis, double start, double end, int majorTicks, int m
 	sp->coordinates()->axes[axis3].setLimits(start, end);
 	sp->coordinates()->axes[axis4].setLimits(start, end);
 
-	resetAxesType();
 	if(scaleType[axis] != type){
 		sp->coordinates()->axes[axis1].setScale(type);
 		sp->coordinates()->axes[axis2].setScale(type);
@@ -1389,8 +1451,6 @@ void Graph3D::setScale(int axis, double start, double end, int majorTicks, int m
 		sp->coordinates()->axes[axis4].setMinors(minorTicks);
 	}
 
-	sp->coordinates()->axes[axis].setTicLength(majorTicLength, minorTicLength);
-
 	if (d_active_curve)
 		d_active_curve->updateColorLegend(legendMajorTicks, 2);
 
@@ -1402,10 +1462,7 @@ void Graph3D::setScales(double xl, double xr, double yl, double yr, double zl, d
 {
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-	double *majorTicLengths = new double[12];
-	double *minorTicLengths = new double[12];
-	for (int i = 0; i < 12; i++)
-		sp->coordinates()->axes[i].ticLength(majorTicLengths[i], minorTicLengths[i]);
+	QStringList tickLengths = axisTickLengths();
 
 	if (d_matrix)
 		updateScalesFromMatrix(xl, xr, yl, yr, zl, zr);
@@ -1414,46 +1471,48 @@ void Graph3D::setScales(double xl, double xr, double yl, double yr, double zl, d
         d_func->setMinZ(zl);
         d_func->setMaxZ(zr);
         d_func->create ();
-        sp->createCoordinateSystem(Triple(xl, yl, zl), Triple(xr, yr, zr));
+		sp->coordinates()->setPosition(Triple(xl, yl, zl), Triple(xr, yr, zr));
 		d_active_curve->legend()->setLimits(zl, zr);
     } else if (d_table){
-		QString name = plotAssociation;
+		QStringList cols = plotAssociation.split(",");
+		if (cols.size() < 3)
+			return;
 
-		int pos = name.find("_", 0);
-		int posX = name.find("(", pos);
-		QString xColName = name.mid(pos+1, posX-pos-1);
-		int xCol = d_table->colIndex(xColName);
-
-		pos = name.find(",", posX);
-		posX = name.find("(", pos);
-		QString yColName = name.mid(pos+1, posX-pos-1);
-		int yCol = d_table->colIndex(yColName);
-
-		if (name.endsWith("(Z)",true)){
-			pos = name.find(",",posX);
-			posX = name.find("(",pos);
-			QString zColName = name.mid(pos + 1, posX - pos - 1);
-			int zCol = d_table->colIndex(zColName);
+		int xCol = d_table->colIndex(cols[0].remove("(X)"));
+		int yCol = d_table->colIndex(cols[1].remove("(Y)"));
 
+		if (plotAssociation.endsWith("(Z)",true)){
+			int zCol = d_table->colIndex(cols[2].remove("(Z)"));
 			loadData(d_table, xCol, yCol, zCol, xl, xr, yl, yr, zl, zr, axis);
-		} else if (name.endsWith("(Y)",true))
+		} else if (plotAssociation.endsWith("(Y)",true))
 			updateScales(xl, xr, yl, yr, zl, zr, xCol, yCol);
 	}
-    resetAxesLabels();
+
 	if (d_autoscale)
 		findBestLayout();
 
-	for (int i = 0; i < 12; i++)
-		sp->coordinates()->axes[i].setTicLength(majorTicLengths[i], minorTicLengths[i]);
-
-	delete [] majorTicLengths;
-	delete [] minorTicLengths;
+	setTickLengths(tickLengths);//restore tick lengths
 
 	QApplication::restoreOverrideCursor();
 }
 
+void Graph3D::changeScales(double xl, double xr, double yl, double yr, double zl, double zr)
+{
+	if (d_const_func){
+		d_const_func->setDomain(xl, xr, yl, yr);
+		d_const_func->setMinZ(zl);
+		d_const_func->setMaxZ(zr);
+		d_const_func->create();
+	} else
+		addHiddenConstantCurve(xl, xr, yl, yr, zl, zr);
+}
+
 void Graph3D::updateScalesFromMatrix(double xl, double xr, double yl, double yr, double zl, double zr)
 {
+	double xmin = qMin(xl, xr);
+	double xmax = qMax(xl, xr);
+	double ymin = qMin(yl, yr);
+	double ymax = qMax(yl, yr);
 	double zmin = qMin(zl, zr);
 	double zmax = qMax(zl, zr);
 
@@ -1461,51 +1520,72 @@ void Graph3D::updateScalesFromMatrix(double xl, double xr, double yl, double yr,
 	double xEnd = qMax(d_matrix->xStart(), d_matrix->xEnd());
 	double yStart = qMin(d_matrix->yStart(), d_matrix->yEnd());
 	double yEnd = qMax(d_matrix->yStart(), d_matrix->yEnd());
-	double dx = d_matrix->dx();
-	double dy = d_matrix->dy();
-	double x_begin = qMin(xl, xr);
-	double y_begin = qMin(yl, yr);
+	double zStart = 0.0, zEnd = 0.0;
+	d_matrix->range(&zStart, &zEnd);
 
-	int nc = qRound(fabs(xr - xl)/dx) + 1;// new number of columns
-	int nr = qRound(fabs(yr - yl)/dy) + 1;// new number of rows
+	sp->coordinates()->setPosition(Triple(xl, yl, zmin), Triple(xr, yr, zmax));
 
-	double **data_matrix = Matrix::allocateMatrixData(nc, nr);
-	for (int i = 0; i < nc; i++){
-		double x = x_begin + i*dx;
-		if (x < xStart || x > xEnd){
-			for (int j = 0; j < nr; j++)
-				data_matrix[i][j] = zmin;
-		}
+	if (xmin > xEnd || xmax < xStart || ymin > yEnd || ymax < yStart || zmin > zEnd || zmax < zStart){
+		if (d_active_curve)
+			delete d_active_curve;
+		d_active_curve = 0;
 
-		double dli, dlf;
-		dlf = modf(fabs((x - xStart)/dx), &dli);
-		int l = qRound(dli); if (dlf > 0.5) l++;
-		for (int j = 0; j < nr; j++){
-			double y = y_begin + j*dy;
-			if (y < yStart || y > yEnd)
-				data_matrix[i][j] = zmin;
-
-			double dki, dkf;
-			dkf = modf(fabs((y - yStart)/dy), &dki);
-			int k = qRound(dki); if (dkf > 0.5) k++;
-			double val = d_matrix->cell(k, l);
-			if (val > zmax)
-				data_matrix[i][j] = zmax;
-			else if (val < zmin)
-				data_matrix[i][j] = zmin;
-			else
-				data_matrix[i][j] = val;
-		}
+		changeScales(xl, xr, yl, yr, zl, zr);
+		update();
+		return;
 	}
+
 	if (!d_active_curve)
 		d_active_curve = addCurve();
-	d_active_curve->loadFromData(data_matrix, nc, nr, xl, xr, yl, yr);
-	Matrix::freeMatrixData(data_matrix, nc);
 
-	sp->createCoordinateSystem(Triple(xl, yl, zmin), Triple(xr, yr, zmax));
+	int cols = d_matrix->numCols();
+	int rows = d_matrix->numRows();
+	double **data = 0;
+	if (xmin <= xStart && xmax >= xEnd && ymin <= yStart && ymax >= yEnd){
+		data = Matrix::allocateMatrixData(cols, rows);
+		for (int i = 0; i < cols; i++ ){
+			for (int j = 0; j < rows; j++)
+				data[i][j] = d_matrix->cell(j, i);
+		}
+		d_active_curve->loadFromData(data, cols, rows, d_matrix->xStart(), d_matrix->xEnd(), d_matrix->yStart(), d_matrix->yEnd());
+	} else {
+		double x_begin = qMax(xmin, xStart);
+		double y_begin = qMax(ymin, yStart);
+		double x_end = qMin(xmax, xEnd);
+		double y_end = qMin(ymax, yEnd);
+
+		double dx = d_matrix->dx();
+		double dy = d_matrix->dy();
+
+		cols = qRound(fabs(x_end - x_begin)/dx);
+		rows = qRound(fabs(y_end - y_begin)/dy);
+		data = Matrix::allocateMatrixData(cols, rows);
+		for (int i = 0; i < cols; i++){
+			double x = x_begin + i*dx;
+			double dli, dlf;
+			dlf = modf(fabs((x - xStart)/dx), &dli);
+			int l = qRound(dli); if (dlf > 0.5) l++;
+			for (int j = 0; j < rows; j++){
+				double y = y_begin + j*dy;
+				if (y < yStart || y > yEnd){
+					data[i][j] = zmin;
+					continue;
+				}
+
+				double dki, dkf;
+				dkf = modf(fabs((y - yStart)/dy), &dki);
+				int k = qRound(dki); if (dkf > 0.5) k++;
+				data[i][j] = d_matrix->cell(k, l);
+			}
+		}
+		d_active_curve->loadFromData(data, cols, rows, x_begin, x_end, y_begin, y_end);
+	}
+	Matrix::freeMatrixData(data, cols);
+
 	d_active_curve->legend()->setLimits(zmin, zmax);
 	d_active_curve->legend()->setMajors(legendMajorTicks);
 
+	changeScales(xl, xr, yl, yr, zl, zr);
 	update();
 }
 
@@ -1550,15 +1630,14 @@ void Graph3D::updateScales(double xl, double xr, double yl, double yr,double zl,
 
 	if (d_active_curve)
 		d_active_curve->loadFromData(data, xmesh, ymesh, xl, xr, yl, yr);
-	sp->createCoordinateSystem(Triple(xl, yl, zl), Triple(xr, yr, zr));
+	sp->coordinates()->setPosition(Triple(xl, yl, zl), Triple(xr, yr, zr));
 	Matrix::freeMatrixData(data, xmesh);
 }
 
 void Graph3D::setTicks(const QStringList& options)
 {
 	int min,maj;
-	if (int(options.count()) == 6)
-	{
+	if (int(options.count()) == 6){
 		maj=options[0].toInt();
 		sp->coordinates()->axes[X1].setMajors(maj);
 		sp->coordinates()->axes[X2].setMajors(maj);
@@ -1594,9 +1673,7 @@ void Graph3D::setTicks(const QStringList& options)
 		sp->coordinates()->axes[Z2].setMinors(min);
 		sp->coordinates()->axes[Z3].setMinors(min);
 		sp->coordinates()->axes[Z4].setMinors(min);
-	}
-	else
-	{
+	} else {
 		maj=options[1].toInt();
 		sp->coordinates()->axes[X1].setMajors(maj);
 		sp->coordinates()->axes[X2].setMajors(maj);
@@ -2107,6 +2184,7 @@ void Graph3D::exportImage(const QString& fileName, int quality, bool transparent
 	int dpm = (int)ceil(100.0/2.54*dpi);
 	image.setDotsPerMeterX(dpm);
 	image.setDotsPerMeterY(dpm);
+#if QT_VERSION >= 0x040500
 	if (fileName.endsWith(".odf")){
 		QTextDocument *document = new QTextDocument();
 		QTextCursor cursor = QTextCursor(document);
@@ -2118,10 +2196,11 @@ void Graph3D::exportImage(const QString& fileName, int quality, bool transparent
 		QTextDocumentWriter writer(fileName);
 		writer.write(document);
 	} else
+#endif
 		image.save(fileName, 0, quality);
 }
 
-
+#if QT_VERSION >= 0x040500
 void Graph3D::exportImage(QTextDocument *document, int, bool transparent,
 						int dpi, const QSizeF& customSize, int unit, double fontsFactor)
 {
@@ -2164,6 +2243,7 @@ void Graph3D::exportImage(QTextDocument *document, int, bool transparent,
 	cursor.insertBlock();
 	cursor.insertImage(image);
 }
+#endif
 
 void Graph3D::exportPDF(const QString& fileName)
 {
@@ -2811,7 +2891,7 @@ void Graph3D::setDataColorMap(const QwtLinearColorMap& colorMap)
 
 	col_ = new StandardColor(d_active_curve);
 	col_->setColorVector(cv);
-	sp->setDataColor(col_);
+	d_active_curve->setDataColor(col_);
 
 	if (legendOn){
 		sp->showColorLegend(false);
@@ -3007,7 +3087,7 @@ void Graph3D::copy(Graph3D* g)
 		s.remove("(X)").remove("(Y)");
 		QStringList l = s.split(",");
 		if (l.size() == 2)
-			addRibbon(g->table(), l[0], l[1],g->xStart(),g->xStop(), g->yStart(),g->yStop(),g->zStart(),g->zStop());
+			addRibbon(g->table(), l[0], l[1], g->xStart(), g->xStop(), g->yStart(), g->yStop(), g->zStart(), g->zStop());
 	} else
 		addMatrixData(g->matrix(), g->xStart(), g->xStop(), g->yStart(), g->yStop(),g->zStart(),g->zStop());
 
@@ -3178,28 +3258,28 @@ Graph3D* Graph3D::restore(ApplicationWindow* app, const QStringList &lst, int fi
 	ApplicationWindow::restoreWindowGeometry(app, plot, lst[1]);
 	QString formula = fList[1];
 	if (!formula.isEmpty()){
-		if (formula.endsWith("(Y)",true)){//Ribbon plot
-			Table* t = app->table(formula.left(formula.find("_", 0)));
-			if (!t)
-				return 0;
-
+		if (formula.endsWith("(Y)", true)){//Ribbon plot
 			formula.remove("(X)").remove("(Y)");
 			QStringList l = formula.split(",");
-			if (l.size() == 2)
-				plot->addRibbon(t, l[0], l[1], fList[2].toDouble(), fList[3].toDouble(),
-				fList[4].toDouble(), fList[5].toDouble(), fList[6].toDouble(), fList[7].toDouble());
-		} else if (formula.contains("(Z)",true) > 0){
-			Table* t = app->table(formula.left(formula.find("_", 0)));
+			if (l.size() < 2)
+				return 0;
+			Table* t = app->table(l[0]);
 			if (!t)
 				return 0;
-
-			plot->show();
+			plot->addRibbon(t, l[0], l[1], fList[2].toDouble(), fList[3].toDouble(),
+					fList[4].toDouble(), fList[5].toDouble(), fList[6].toDouble(), fList[7].toDouble());
+		} else if (formula.contains("(Z)",true) > 0){
 			formula.remove("(X)").remove("(Y)").remove("(Z)");
 			QStringList l = formula.split(",");
-			if (l.size() == 3)
-				plot->loadData(t, t->colIndex(l[0]), t->colIndex(l[1]), t->colIndex(l[2]),
-						   fList[2].toDouble(),fList[3].toDouble(), fList[4].toDouble(),
-						   fList[5].toDouble(),fList[6].toDouble(),fList[7].toDouble());
+			if (l.size() < 3)
+				return 0;
+			Table* t = app->table(l[0]);
+			if (!t)
+				return 0;
+			plot->show();
+			plot->loadData(t, t->colIndex(l[0]), t->colIndex(l[1]), t->colIndex(l[2]),
+							fList[2].toDouble(), fList[3].toDouble(), fList[4].toDouble(),
+							fList[5].toDouble(), fList[6].toDouble(), fList[7].toDouble());
 		} else if (formula.startsWith("matrix<",true) && fList[1].endsWith(">",false)){
 			formula.remove("matrix<", true).remove(">");
 			Matrix* m = app->matrix(formula);
@@ -3405,10 +3485,6 @@ void Graph3D::dropEvent(QDropEvent* event)
 
 Graph3D::~Graph3D()
 {
-	if (d_surface)
-		delete d_surface;
-	if (d_func)
-		delete d_func;
-
+	removeCurve();
 	delete sp;
 }
