@@ -47,6 +47,7 @@ using namespace Qwt3D;
 class QTextDocument;
 class UserFunction;
 class UserParametricSurface;
+class ConstFunction;
 
 /*!\brief 3D graph widget.
  *
@@ -259,8 +260,10 @@ public slots:
 	void print();
 	void print(QPrinter *printer);
 	void copyImage();
+#if QT_VERSION >= 0x040500
 	void exportImage(QTextDocument *document, int quality, bool transparent,
 						int dpi, const QSizeF& customSize, int unit, double fontsFactor);
+#endif
 	void exportImage(const QString& fileName, int quality = 100, bool transparent = false, int dpi = 0,
 		const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
     void exportPDF(const QString& fileName);
@@ -390,6 +393,9 @@ signals:
 	void modified();
 
 private:
+	void addHiddenConstantCurve(double xl, double xr, double yl, double yr, double zl, double zr);
+	void changeScales(double xl, double xr, double yl, double yr, double zl, double zr);
+
 	Curve* addCurve();
 	void removeCurve();
 
@@ -434,6 +440,16 @@ private:
 	Qwt3D::PLOTSTYLE style_;
 	PlotType d_table_plot_type;
 	Curve * d_active_curve;
+	ConstFunction *d_const_func;
+	Curve * d_const_curve;
+};
+
+//! Class for constant z surfaces
+class ConstFunction : public Function
+{
+public:
+	ConstFunction(Qwt3D::Curve *pw);
+	double operator()(double x, double y);
 };
 
 //! Class for user defined surfaces
