@@ -205,7 +205,8 @@ void Plot3DDialog::initAxesPage()
     gl1->addWidget(new QLabel(tr("Axis Font")), 1, 0);
 
     QHBoxLayout* hb1 = new QHBoxLayout();
-	btnLabelFont = new QPushButton(tr( "&Choose font" ));
+	btnLabelFont = new QPushButton(tr( "&Font" ));
+	btnLabelFont->setIcon(QIcon(":/font.png"));
     hb1->addWidget(btnLabelFont);
 
 	axisTitleFormatButtons = new TextFormatButtons(boxLabel);
@@ -257,6 +258,7 @@ void Plot3DDialog::initTitlePage()
     colorLabel->setBuddy(btnTitleColor);
 
     btnTitleFont = new QPushButton(tr( "&Font" ));
+	btnTitleFont->setIcon(QIcon(":/font.png"));
     hb1->addWidget(btnTitleFont);
 
 	QVBoxLayout* vl = new QVBoxLayout();
@@ -288,7 +290,7 @@ void Plot3DDialog::initColorsPage()
 	QHBoxLayout* hb = new QHBoxLayout(linearColorMapGroupBox);
 
 	ApplicationWindow *app = (ApplicationWindow *)parent();
-	d_color_map_editor = new ColorMapEditor(app->locale());
+	d_color_map_editor = new ColorMapEditor(app->locale(), app->d_decimal_digits);
 	hb->addWidget(d_color_map_editor);
 
     colorMapFileGroupBox = new QGroupBox(tr( "Color map &file" ));
@@ -395,7 +397,8 @@ void Plot3DDialog::initGeneralPage()
     gl1->addWidget(boxResolution, 2, 1);
 
     gl1->addWidget(new QLabel( tr( "Numbers Font" )), 3, 0);
-	btnNumbersFont = new QPushButton(tr( "&Choose Font" ));
+	btnNumbersFont = new QPushButton(tr( "&Font" ));
+	btnNumbersFont->setIcon(QIcon(":/font.png"));
     gl1->addWidget(btnNumbersFont, 3, 1);
 
     gl1->addWidget(new QLabel( tr( "Distance labels - axis" )), 4, 0);
@@ -694,7 +697,7 @@ void Plot3DDialog::setPlot(Graph3D *g)
 	labels = g->axesLabels();
 	boxLabel->setText(labels[0]);
 
-	tickLengths = g->axisTickLengths();
+	QStringList tickLengths = g->axisTickLengths();
 	boxMajorLength->setValue(tickLengths[0].toDouble());
 	boxMinorLength->setValue(tickLengths[1].toDouble());
 
@@ -950,6 +953,8 @@ void Plot3DDialog::viewAxisOptions(int axis)
 {
 	boxLabel->setText(labels[axis]);
 
+	QStringList tickLengths = d_plot->axisTickLengths();
+
 	boxMajorLength->blockSignals(true);
 	boxMajorLength->setValue(tickLengths[2*axis+0].toDouble());
 	boxMajorLength->blockSignals(false);
@@ -1084,10 +1089,9 @@ bool Plot3DDialog::updatePlot()
 	} else if (generalDialog->currentPage() == (QWidget*)scale){
 		double start = qMin(boxFrom->value(), boxTo->value());
 		double end = qMax(boxFrom->value(), boxTo->value());
-		d_plot->setScale(axesList->currentRow(), start, end, boxMajors->value(),
-						 boxMinors->value(), (Qwt3D::SCALETYPE)boxType->currentIndex());
-
+		d_plot->setScale(axesList->currentRow(), start, end, boxMajors->value(), boxMinors->value(), (Qwt3D::SCALETYPE)boxType->currentIndex());
 		d_plot->setAxisNumericFormat(axesList->currentRow(), boxTickLabelsFormat->currentIndex(), boxPrecision->value());
+		viewScaleLimits(axesList->currentRow());
 	} else if (generalDialog->currentPage() == axes){
 		int axis = axesList2->currentRow();
 		labels[axis] = boxLabel->text();
