@@ -178,20 +178,28 @@ void ScriptEdit::focusInEvent(QFocusEvent *e)
 
 void ScriptEdit::keyPressEvent(QKeyEvent *e)
 {
+	if (e->key() == Qt::Key_QuoteDbl){
+		QTextCursor cursor = textCursor();
+		cursor.insertText("\"\"");
+		cursor.movePosition(QTextCursor::PreviousCharacter, QTextCursor::MoveAnchor, 1);
+		setTextCursor(cursor);
+		return;
+	}
+
 	if (d_completer && d_completer->popup()->isVisible()){
          // The following keys are forwarded by the completer to the widget
-        switch (e->key()) {
-        case Qt::Key_Enter:
-        case Qt::Key_Return:
-        case Qt::Key_Escape:
-        case Qt::Key_Tab:
-        case Qt::Key_Backtab:
-			e->ignore();
-			return; // let the completer do default behavior
-        default:
-            break;
-        }
-     }
+		switch (e->key()) {
+			case Qt::Key_Enter:
+			case Qt::Key_Return:
+			case Qt::Key_Escape:
+			case Qt::Key_Tab:
+			case Qt::Key_Backtab:
+				e->ignore();
+				return; // let the completer do default behavior
+			default:
+				break;
+		}
+	 }
 
     QTextEdit::keyPressEvent(e);
     if (d_completer && !d_completer->popup()->isVisible() && e->key() == Qt::Key_Return)
@@ -202,15 +210,15 @@ void ScriptEdit::keyPressEvent(QKeyEvent *e)
      if (!d_completer || (ctrlOrShift && e->text().isEmpty()))
          return;
 
-     static QString eow("~!@#$%^&*()_+{}|:\"<>?,./;'[]\\-="); // end of word
+	 static QString eow("~!@#$%^&*()+{}|:\"<>?,./;'[]\\-="); // end of word
      bool hasModifier = (e->modifiers() != Qt::NoModifier) && !ctrlOrShift;
      QString completionPrefix = textUnderCursor();
 
-     if (!isShortcut && (hasModifier || e->text().isEmpty()|| completionPrefix.length() < 2
+	 if (!isShortcut && (hasModifier || e->text().isEmpty()|| completionPrefix.length() < 2
 		 || eow.contains(e->text().right(1)))){
          d_completer->popup()->hide();
          return;
-     }
+	 }
 
      if (completionPrefix != d_completer->completionPrefix()){
          d_completer->setCompletionPrefix(completionPrefix);
@@ -645,16 +653,25 @@ void ScriptEdit::setDirPath(const QString& path)
 	tc.movePosition(QTextCursor::Left);
 	tc.movePosition(QTextCursor::EndOfWord);
 
-	bool specialWord = (completion == "qti" || completion == "app" || completion == "self") ? true : false;
-	bool keyWord = (PythonSyntaxHighlighter::keywordsList().contains(completion));
+	if (completion == "qti" || completion == "app" || completion == "self" || completion == "QtGui" || completion == "QtCore"){
+		tc.insertText(completion.right(extra) + ".");
+		setTextCursor(tc);
+		return;
+	}
 
+	ApplicationWindow *app = qobject_cast<ApplicationWindow *>(scriptEnv->application());
+	if (app && (app->windowsNameList().contains(completion) || app->table(completion))){//window or column name?
+		tc.insertText(completion.right(extra));
+		setTextCursor(tc);
+		return;
+	}
+
+	bool keyWord = (PythonSyntaxHighlighter::keywordsList().contains(completion));
 	QChar startChar = completion[0];
-	if (startChar.category() == QChar::Letter_Lowercase && !specialWord && !keyWord){
+	if (startChar.category() == QChar::Letter_Lowercase && !keyWord){
 		tc.insertText(completion.right(extra) + "()");
 		tc.movePosition(QTextCursor::PreviousCharacter, QTextCursor::MoveAnchor, 1);
-	} else if (specialWord)
-		tc.insertText(completion.right(extra) + ".");
-	else
+	} else
 		tc.insertText(completion.right(extra));
 
 	setTextCursor(tc);
@@ -662,9 +679,41 @@ void ScriptEdit::setDirPath(const QString& path)
 
  QString ScriptEdit::textUnderCursor() const
  {
-     QTextCursor tc = textCursor();
-     tc.select(QTextCursor::WordUnderCursor);
-     return tc.selectedText();
+	QTextCursor tc = textCursor();
+	tc.select(QTextCursor::WordUnderCursor);
+
+	QString s = tc.selectedText();
+	if (s.contains(")")){
+		tc.select(QTextCursor::LineUnderCursor);
+		s = tc.selectedText();
+		s.remove(")");
+		if (s.endsWith("\""))
+			s.chop(1);
+
+		int pos1 = s.lastIndexOf("\"") + 1;
+		int pos2 = s.lastIndexOf(".") + 1;
+		int pos3 = s.lastIndexOf("(") + 1;
+		int pos4 = s.lastIndexOf(",") + 1;
+
+		if (pos4 > pos3 && pos4 > pos2 && pos4 > pos1)
+			return s.mid(pos4, s.length() - pos4).trimmed();
+		else if (pos3 > pos2 && pos3 > pos1)
+			return s.mid(pos3, s.length() - pos3);
+		else if (pos2 > pos1)
+			return s.mid(pos2, s.length() - pos2);
+		else if (pos1 != -1)
+			return s.mid(pos1, s.length() - pos1);
+	} else if (s.contains("\"")){
+		tc.select(QTextCursor::LineUnderCursor);
+		s = tc.selectedText();
+		if (s.endsWith("\""))
+			s.chop(1);
+		int pos = s.lastIndexOf("\"") + 1;
+		if (pos != -1)
+			return s.mid(pos, s.length() - pos);
+	}
+
+	return s;
  }
 
 
