@@ -55,14 +55,18 @@ const muParserScripting::mathFunction muParserScripting::math_functions[] = {
   { "bessel_yn", 2, NULL,bessel_Yn,NULL, QObject::tr("bessel_yn(double x, int n):\n Irregular cylindrical Bessel function of order n, Y_n(x), for x>0.") },
   { "beta", 2, NULL,beta,NULL, QObject::tr("beta(a,b):\n Computes the Beta Function, B(a,b) = Gamma(a)*Gamma(b)/Gamma(a+b) for a > 0, b > 0.") },
   { "ceil", 1, ceil,NULL,NULL, QObject::tr("ceil(x):\n Round to the next larger integer,\n smallest integer larger or equal to x.") },
+  { "chi2cdf", 2, NULL,chi2cdf,NULL, QObject::tr("chi2cdf(x, df):\n Computes the cumulative distribution function for a chi-squared distribution with df degrees of freedom.") },
+  { "chi2inv", 2, NULL,chi2inv,NULL, QObject::tr("chi2inv(p, df):\n Computes the inverse of the cumulative distribution function for a chi-squared distribution with df degrees of freedom.") },
   { "cos", 1, NULL,NULL,NULL, QObject::tr("cos(x):\n Calculate cosine.") },
   { "cosh", 1, NULL,NULL,NULL, QObject::tr("cosh(x):\n Hyperbolic cos function.") },
+  { "dilog", 1, dilog, NULL,NULL, QObject::tr("dilog(x):\n Compute the dilogarithm for a real argument. In Lewin's notation this is Li_2(x), the real part of the dilogarithm of a real x.") },
   { "erf", 1, erf, NULL,NULL, QObject::tr("erf(x):\n  The error function.") },
   { "erfc", 1, erfc, NULL,NULL, QObject::tr("erfc(x):\n Complementary error function erfc(x) = 1 - erf(x).") },
   { "erfz", 1, erf_Z, NULL,NULL, QObject::tr("erfz(x):\n The Gaussian probability density function Z(x).") },
   { "erfq", 1, erf_Q, NULL,NULL, QObject::tr("erfq(x):\n The upper tail of the Gaussian probability function Q(x).") },
   { "exp", 1, NULL,NULL,NULL, QObject::tr("exp(x):\n Exponential function: e raised to the power of x.") },
   { "floor", 1, floor,NULL,NULL, QObject::tr("floor(x):\n Round to the next smaller integer,\n largest integer smaller or equal to x.") },
+  { "ftable", 3, NULL,NULL,ftable, QObject::tr("ftable(x, m, n):\n F-Distribution with m and n degrees of freedom.") },
   { "gamma", 1, gamma, NULL,NULL, QObject::tr("gamma(x):\n Computes the Gamma function, subject to x not being a negative integer.") },
   { "gammaln", 1, lngamma,NULL,NULL, QObject::tr("gammaln(x):\n Computes the logarithm of the Gamma function, subject to x not a being negative integer. For x<0, log(|Gamma(x)|) is returned.") },
   { "gauss_cdf", 2, NULL, gauss_cdf, NULL, QObject::tr("gauss_cdf(x, sigma):\n Computes the cumulative distribution function for a Gaussian distribution with standard deviation sigma.") },
@@ -70,6 +74,8 @@ const muParserScripting::mathFunction muParserScripting::math_functions[] = {
   { "hazard", 1, hazard,NULL,NULL, QObject::tr("hazard(x):\n Computes the hazard function for the normal distribution h(x) = erfz(x)/erfq(x).") },
   { "if", 3, NULL,NULL,NULL, QObject::tr("if(e1, e2, e3):\n if e1 then e2 else e3.") },
   { "inv_gauss_cdf", 2, NULL, inv_gauss_cdf, NULL, QObject::tr("inv_gauss_cdf(x, sigma):\n Computes the inverse of the cumulative distribution function for a Gaussian distribution with standard deviation sigma.") },
+  { "invf", 3, NULL, NULL, invf, QObject::tr("invf(x, m, n):\n Inverse F-Distribution with m and n degrees of freedom.") },
+  { "invt", 2, NULL, invt, NULL, QObject::tr("invt(x, n):\n Inverse t-distribution with n degrees of freedom.") },
   { "ln", 1, NULL,NULL,NULL, QObject::tr("ln(x):\n Calculate natural logarithm log_e.") },
   { "log", 1, NULL,NULL,NULL, QObject::tr("log(x):\n Calculate decimal logarithm log_10.") },
   { "log10", 1, NULL,NULL,NULL, QObject::tr("log10(x):\n Calculate decimal logarithm log_10.") },
@@ -77,6 +83,9 @@ const muParserScripting::mathFunction muParserScripting::math_functions[] = {
   { "min", -1, NULL,NULL,NULL, QObject::tr("min(x,y,...):\n Calculate minimum of all arguments.") },
   { "max", -1, NULL,NULL,NULL, QObject::tr("max(x,y,...):\n Calculate maximum of all arguments.") },
   { "mod", 2, NULL,mod,NULL, QObject::tr("mod(x,y):\n Calculate rest of integer division x/y,\n x modulo y.") },
+  { "normal", 1,normal,NULL,NULL, QObject::tr("normal(seed):\n Returns a normal random number using the Ziggurat algorithm.") },
+  { "normcdf", 1, normcdf,NULL,NULL, QObject::tr("normcdf(x):\n Computes the cumulative distribution function for a Gaussian distribution with standard deviation sigma = 1.0.") },
+  { "norminv", 1, norminv,NULL,NULL, QObject::tr("norminv(p):\n Computes the inverse of the cumulative distribution function for a Gaussian distribution with standard deviation sigma = 1.0.") },
   { "pow", 2, NULL,pow,NULL, QObject::tr("pow(x,y):\n Raise x to the power of y, x^y.") },
   { "rint", 1, NULL,NULL,NULL, QObject::tr("rint(x):\n Round to nearest integer.") },
   { "rnd", 1,rnd,NULL,NULL, QObject::tr("rnd(seed):\n Returns a pseudo-random number in the range 0 to 1. Calling this function several times with the same seed will return the same value.") },
