@@ -81,9 +81,10 @@ public:
 
 	double avg(int col, int startRow = 0, int endRow = -1);
 	double sum(int col, int startRow = 0, int endRow = -1);
-	double min(int col, int startRow = 0, int endRow = -1);
-	double max(int col, int startRow = 0, int endRow = -1);
+	double minColumnValue(int col, int startRow = 0, int endRow = -1);
+	double maxColumnValue(int col, int startRow = 0, int endRow = -1);
 	Table* extractData(const QString& name, const QString& condition, int startRow = 0, int endRow = -1);
+	static QDateTime dateTime(double val);
 
 public slots:
 	MyTable* table(){return d_table;};
@@ -104,7 +105,7 @@ public slots:
 	QStringList colNames(){return col_label;}
 	QString colName(int col);
 	void setColName(int col, const QString& text, bool enumerateRight = false, bool warn = true);
-	QString colLabel(int col){return col_label[col];};
+	QString colLabel(int col);
 	int colIndex(const QString& name);
 
 	int colPlotDesignation(int col){return col_plot_type[col];};
@@ -117,6 +118,9 @@ public slots:
 	void setHeaderColType();
 	void setText(int row,int col,const QString & text);
 	void setRandomValues();
+	void setRandomValues(int col, int startRow = 0, int endRow = -1);
+	void setNormalRandomValues();
+	void setNormalRandomValues(int col, int startRow = 0, int endRow = -1, double sigma = 1.0);
 	void setAscValues();
 
 	void cellEdited(int,int col);
@@ -246,6 +250,7 @@ public slots:
 	//@}
 
 	void init(int rows, int cols);
+	QStringList writableSelectedColumns();
 	QStringList selectedColumns();
 	QStringList selectedYColumns();
 	QStringList selectedErrColumns();
@@ -259,7 +264,7 @@ public slots:
 	int columnWidth(int col);
 	QStringList columnWidths();
 	void setColWidths(const QStringList& widths);
-	void adjustColumnsWidth();
+	void adjustColumnsWidth(bool selection = true);
 
 	void setSelectedCol(int col){selectedCol = col;};
 	int selectedColumn(){return selectedCol;};
@@ -293,15 +298,15 @@ public slots:
 	void setColumnsFormat(const QStringList& lst);
 
 	void setTextFormat(int col);
+	void setColNumericFormat(int col);
 	void setColNumericFormat(int f, int prec, int col, bool updateCells = true);
 	bool setDateFormat(const QString& format, int col, bool updateCells = true);
 	bool setTimeFormat(const QString& format, int col, bool updateCells = true);
 	void setMonthFormat(const QString& format, int col, bool updateCells = true);
 	void setDayFormat(const QString& format, int col, bool updateCells = true);
 
-#ifdef XLS_IMPORT
-        bool exportExcel(const QString& fname, bool withLabels, bool exportComments, bool exportSelection);
-#endif
+	bool exportExcel(const QString& fname, bool withLabels, bool exportComments, bool exportSelection);
+	bool exportOdsSpreadsheet(const QString& fname, bool withLabels, bool exportComments, bool exportSelection);
 	bool exportODF(const QString& fname, bool withLabels, bool exportComments, bool exportSelection);
 	bool exportASCII(const QString& fname, const QString& separator, bool withLabels = false,
                      bool exportComments = false, bool exportSelection = false);
@@ -349,6 +354,7 @@ public slots:
 signals:
 	void changedColHeader(const QString&, const QString&);
 	void removedCol(const QString&);
+	void addedCol(const QString&);
 	void removedCol(int);
 	void colIndexChanged(int, int);
 	void modifiedData(Table *, const QString&);
