@@ -60,11 +60,14 @@ TableDialog::TableDialog(Table *t, QWidget* parent, Qt::WFlags fl )
 
 	buttonPrev = new QPushButton("&<<");
 	buttonPrev->setAutoDefault(false);
-	buttonPrev->setMaximumWidth(40);
 
 	buttonNext = new QPushButton("&>>");
 	buttonNext->setAutoDefault(false);
+
+#ifndef Q_OS_MAC
+	buttonPrev->setMaximumWidth(40);
 	buttonNext->setMaximumWidth(40);
+#endif
 
 	QHBoxLayout *hboxb = new QHBoxLayout();
     hboxb->addWidget(buttonPrev);
@@ -291,7 +294,8 @@ void TableDialog::apply()
 {
 	if (colName->text().contains("_")){
 		QMessageBox::warning(this, tr("QtiPlot - Warning"),
-		tr("For internal consistency reasons the underscore character is replaced with a minus sign."));}
+		tr("For internal consistency reasons the underscore character is replaced with a minus sign."));
+	}
 
 	QString name = colName->text().replace("-", "_");
 
@@ -303,41 +307,40 @@ void TableDialog::apply()
 	bool rightColumns = applyToRightCols->isChecked();
 	int format = formatBox->currentIndex();
 	int colType = displayBox->currentIndex();
-	switch(colType)
-	{
-	case 0:
-		setNumericFormat(formatBox->currentIndex(), precisionBox->value(), rightColumns);
-	break;
+	switch(colType){
+		case 0:
+			setNumericFormat(formatBox->currentIndex(), precisionBox->value(), rightColumns);
+		break;
 
-	case 1:
-		setTextFormat(rightColumns);
-	break;
+		case 1:
+			setTextFormat(rightColumns);
+		break;
 
-	case 2:
-		 setDateTimeFormat(colType, formatBox->currentText(), rightColumns);
-	break;
+		case 2:
+			 setDateTimeFormat(colType, formatBox->currentText(), rightColumns);
+		break;
 
-	case 3:
-		setDateTimeFormat(colType, formatBox->currentText(), rightColumns);
-	break;
+		case 3:
+			setDateTimeFormat(colType, formatBox->currentText(), rightColumns);
+		break;
 
-	case 4:
-		if(format == 0)
-			setMonthFormat("MMM", rightColumns);
-		else if(format == 1)
-			setMonthFormat("MMMM", rightColumns);
-		else if(format == 2)
-			setMonthFormat("M", rightColumns);
-	break;
+		case 4:
+			if(format == 0)
+				setMonthFormat("MMM", rightColumns);
+			else if(format == 1)
+				setMonthFormat("MMMM", rightColumns);
+			else if(format == 2)
+				setMonthFormat("M", rightColumns);
+		break;
 
-	case 5:
-		if(format == 0)
-			setDayFormat("ddd", rightColumns);
-		else if(format == 1)
-			setDayFormat("dddd", rightColumns);
-		else if(format == 2)
-			setDayFormat("d", rightColumns);
-	break;
+		case 5:
+			if(format == 0)
+				setDayFormat("ddd", rightColumns);
+			else if(format == 1)
+				setDayFormat("dddd", rightColumns);
+			else if(format == 2)
+				setDayFormat("d", rightColumns);
+		break;
 	}
 
 	if (rightColumns){
@@ -422,44 +425,44 @@ void TableDialog::updateDisplay(int item)
 
 		case 2:
             formatBox->setEditable(true);
-			formatBox->addItem(tr("dd/MM/yyyy"));
-			formatBox->addItem(tr("dd/MM/yyyy HH:mm"));
-			formatBox->addItem(tr("dd/MM/yyyy HH:mm:ss"));
+			formatBox->addItem("dd/MM/yyyy");
+			formatBox->addItem("dd/MM/yyyy hh:mm");
+			formatBox->addItem("dd/MM/yyyy hh:mm:ss");
 
-			formatBox->addItem(tr("dd.MM.yyyy"));
-			formatBox->addItem(tr("dd.MM.yyyy HH:mm"));
-			formatBox->addItem(tr("dd.MM.yyyy HH:mm:ss"));
+			formatBox->addItem("dd.MM.yyyy");
+			formatBox->addItem("dd.MM.yyyy hh:mm");
+			formatBox->addItem("dd.MM.yyyy hh:mm:ss");
 
-			formatBox->addItem(tr("dd MM yyyy"));
-			formatBox->addItem(tr("dd MM yyyy HH:mm"));
-			formatBox->addItem(tr("dd MM yyyy HH:mm:ss"));
+			formatBox->addItem("dd MM yyyy");
+			formatBox->addItem("dd MM yyyy hh:mm");
+			formatBox->addItem("dd MM yyyy hh:mm:ss");
 
-			formatBox->addItem(tr("yyyy-MM-dd"));
-			formatBox->addItem(tr("yyyy-MM-dd HH:mm"));
-			formatBox->addItem(tr("yyyy-MM-dd HH:mm:ss"));
+			formatBox->addItem("yyyy-MM-dd");
+			formatBox->addItem("yyyy-MM-dd hh:mm");
+			formatBox->addItem("yyyy-MM-dd hh:mm:ss");
 
-			formatBox->addItem(tr("yyyyMMdd"));
-			formatBox->addItem(tr("yyyyMMdd HH:mm"));
-			formatBox->addItem(tr("yyyyMMdd HH:mm:ss"));
+			formatBox->addItem("yyyyMMdd");
+			formatBox->addItem("yyyyMMdd hh:mm");
+			formatBox->addItem("yyyyMMdd hh:mm:ss");
 		break;
 
 		case 3:
 			{
 			formatBox->setEditable ( true );
 
-			formatBox->addItem(tr("h") );
-			formatBox->addItem(tr("h ap") );
-			formatBox->addItem(tr("h AP") );
-			formatBox->addItem(tr("h:mm"));
-			formatBox->addItem(tr("h:mm ap") );
-			formatBox->addItem(tr("hh:mm"));
-			formatBox->addItem(tr("h:mm:ss") );
-			formatBox->addItem(tr("h:mm:ss.zzz") );
-			formatBox->addItem(tr("mm:ss") );
-			formatBox->addItem(tr("mm:ss.zzz") );
-			formatBox->addItem(tr("hmm") );
-			formatBox->addItem(tr("hmmss") );
-			formatBox->addItem(tr("hhmmss") );
+			formatBox->addItem("h");
+			formatBox->addItem("h ap");
+			formatBox->addItem("h AP");
+			formatBox->addItem("h:mm");
+			formatBox->addItem("h:mm ap");
+			formatBox->addItem("hh:mm");
+			formatBox->addItem("h:mm:ss");
+			formatBox->addItem("h:mm:ss.zzz");
+			formatBox->addItem("mm:ss");
+			formatBox->addItem("mm:ss.zzz");
+			formatBox->addItem("hmm");
+			formatBox->addItem("hmmss");
+			formatBox->addItem("hhmmss");
 			}
 		break;
 
@@ -516,7 +519,6 @@ void TableDialog::setDateTimeFormat(int type, const QString& format, bool allRig
         formatBox->insertItem(0, format);
         formatBox->setCurrentText(format);
     }
-    d_table->notifyChanges();
 }
 
 void TableDialog::setNumericFormat(int type, int prec, bool allRightColumns)
@@ -528,8 +530,6 @@ void TableDialog::setNumericFormat(int type, int prec, bool allRightColumns)
 			d_table->setColNumericFormat(type, prec, i);
 	} else
 		d_table->setColNumericFormat(type, prec, sc);
-
-	d_table->notifyChanges();
 	QApplication::restoreOverrideCursor();
 }
 
@@ -554,7 +554,6 @@ void TableDialog::setDayFormat(const QString& format, bool allRightColumns)
         d_table->setDayFormat(format, sc);
 
 	QApplication::restoreOverrideCursor();
-    d_table->notifyChanges();
 }
 
 void TableDialog::setMonthFormat(const QString& format, bool allRightColumns)
@@ -568,5 +567,4 @@ void TableDialog::setMonthFormat(const QString& format, bool allRightColumns)
         d_table->setMonthFormat(format, sc);
 
 	QApplication::restoreOverrideCursor();
-    d_table->notifyChanges();
 }
